@@ -6,7 +6,7 @@
  *
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: ethna_make_package.php 854 2009-06-15 11:10:58Z mumumu-org $
+ *  @version    $Id$
  */
 require_once 'PEAR.php';
 require_once 'Console/Getopt.php';
@@ -40,8 +40,8 @@ $package = 'Ethna';
 
 // x.0.y -> beta
 // x.1.y -> stable
-$major_version = "2.3";
-$minor_version = "7";
+$major_version = "2.5";
+$minor_version = "0";
 
 if ($state == 'alpha' || $state == 'beta') {
     $version = $major_version . strftime('.%Y%m%d%H');
@@ -60,7 +60,7 @@ $config = array(
     'filelistgenerator' => 'file',
     'ignore' => array('CVS/', '.svn/', 'package.xml', 'ethna_make_package.php', 'ethna_make_package.sh', '*optional_package*', ),
     'changelogoldtonew' => false,
-    'exceptions' => array('README' => 'doc', 'LICENSE' => 'doc', 'CHANGES' => 'doc'),
+    'exceptions' => array('README' => 'doc', 'LICENSE' => 'doc', 'CHANGES' => 'doc',),
     'description' => $description,
     'exceptions' => array('bin/ethna.sh' => 'script', 'bin/ethna.bat' => 'script'),
     'installexceptions' => array('bin/ethna.sh' => '/', 'bin/ethna.bat' => '/'),
@@ -113,8 +113,13 @@ $packagexml->addIgnoreToRelease('bin/ethna.bat');
 $packagexml->generateContents();
 
 if ($is_old_package) {
-    $pkg =& $packagexml->exportCompatiblePackageFile1();
-    $pkg->writePackageFile();
+    if (method_exists($packagexml, 'exportCompatiblePackageFile1')) {
+        $pkg =& $packagexml->exportCompatiblePackageFile1();
+        $pkg->writePackageFile();
+    } else {
+        //  PEAR package version 1 is not supported over PEAR 1.8.0.
+        echo "WARNING: PEAR package version 1 is not supported in this PEAR version.\n";
+    }
 } else {
     $packagexml->writePackageFile();
 }
