@@ -4,7 +4,7 @@
 #
 #   ...:(
 #
-#   $Id: ethna_make_package.sh 521 2008-05-01 16:10:05Z mumumu-org $
+#   $Id: ethna_make_package.sh 461 2007-04-19 14:50:45Z ichii386 $
 #
 tmpdir="/tmp/ethna"
 
@@ -18,6 +18,12 @@ then
     beta=$1
 fi
 
+if [ "$1" = "-a" ]
+then
+    alpha=$1
+    beta=$alpha
+fi
+
 # chdir to basedir
 cwd=`dirname $0`
 basedir="$cwd/../"
@@ -31,18 +37,22 @@ rm -f $basedir/package.xml
 
 rm -fr $targetdir
 mkdir $targetdir
-cp -a . "$targetdir/"
+cp -pR * "$targetdir/"
 
 #  create optional package
 optpkg_dir="$targetdir/misc/optional_package"
+mkdir $optpkg_dir/Smarty/release
 cd $optpkg_dir/Smarty/src
 tar xvfz Smarty*.tar.gz
 cd $optpkg_dir/Smarty/build
+chmod +x ./build
 ./build
 cp $optpkg_dir/Smarty/release/*.tgz $tmpdir
+mkdir $optpkg_dir/simpletest/release
 cd $optpkg_dir/simpletest/src
 tar xvfz simpletest*.tar.gz
 cd $optpkg_dir/simpletest/build
+chmod +x ./build
 ./build
 cp $optpkg_dir/simpletest/release/*.tgz $tmpdir
 rm -rf $optpkg_dir
@@ -56,11 +66,3 @@ cp -f $basedir/package.xml $tmpdir/
 cd $tmpdir
 tar zcvf Ethna-$version.tgz package.xml Ethna-$version
 zip -r Ethna-$version.zip package.xml Ethna-$version
-
-cd $basedir
-php $basedir/bin/ethna_make_package.php $beta -o
-cp -f $basedir/package.xml $tmpdir/
-cd $tmpdir
-tar zcvf Ethna-$version-dev.tgz package.xml Ethna-$version
-zip -r Ethna-$version-dev.zip package.xml Ethna-$version
-
