@@ -5,20 +5,27 @@
  *
  *  @package    Ethna
  *  @author     halt feits <halt.feits@gmail.com>
- *  @version    $Id: Ethna_DB_ADOdb.php 343 2006-10-02 05:34:49Z halt1983 $
+ *  @version    $Id$
  */
 
 /**
  * ADOdb config setting
  */
-define('ADODB_OUTP', 'sprintf'); //disable output error
+define('ADODB_OUTP', 'ethna_adodb_logger'); //disable output error
 
 require_once 'adodb/adodb.inc.php';
 
+function ethna_adodb_logger ($msg, $newline) {
+    $c =& Ethna_Controller::getInstance();
+    $logger =& $c->getLogger();
+    
+    $logger->log(LOG_DEBUG, strip_tags(str_replace("\n", "", $msg)));
+}
+
 /**
  *  Ethna_DB_ADOdb
  *
- *  EthnaΥե졼ADOdb֥Ȥ򰷤ݥ饹
+ *  EthnaのフレームワークでADOdbオブジェクトを扱うための抽象クラス
  *
  *  @package    Ethna
  *  @author     halt feits <halt.feits@gmail.com>
@@ -30,7 +37,7 @@ class Ethna_DB_ADOdb extends Ethna_DB
      *  @access private
      */
 
-    /** @var    object  DB              DB֥ */
+    /** @var    object  DB              DBオブジェクト */
     var $db;
 
     /** @var    string   dsn */
@@ -40,12 +47,12 @@ class Ethna_DB_ADOdb extends Ethna_DB
 
 
     /**
-     *  󥹥ȥ饯
+     *  コンストラクタ
      *
      *  @access public
-     *  @param  object  Ethna_Controller    &$controller    ȥ饪֥
+     *  @param  object  Ethna_Controller    &$controller    コントローラオブジェクト
      *  @param  string  $dsn                                DSN
-     *  @param  bool    $persistent                         ³³
+     *  @param  bool    $persistent                         持続接続設定
      */
     function Ethna_DB_ADOdb(&$controller, $dsn, $persistent)
     {
@@ -56,10 +63,10 @@ class Ethna_DB_ADOdb extends Ethna_DB
 
     //{{{ connect
     /**
-     *  DB³
+     *  DBに接続する
      *
      *  @access public
-     *  @return mixed   0:ｪλ Ethna_Error:顼
+     *  @return mixed   0:正常終了 Ethna_Error:エラー
      */
     function connect()
     {
@@ -84,7 +91,7 @@ class Ethna_DB_ADOdb extends Ethna_DB
 
     //{{{ disconnect
     /**
-     *  DB³Ǥ
+     *  DB接続を切断する
      *
      *  @access public
      */
@@ -97,10 +104,10 @@ class Ethna_DB_ADOdb extends Ethna_DB
 
     //{{{ isValid
     /**
-     *  DB³֤֤
+     *  DB接続状態を返す
      *
      *  @access public
-     *  @return bool    true:(³Ѥ) false:顼/̤³
+     *  @return bool    true:正常(接続済み) false:エラー/未接続
      */
     function isValid()
     {
@@ -114,10 +121,10 @@ class Ethna_DB_ADOdb extends Ethna_DB
 
     //{{{ begin
     /**
-     *  DBȥ󥶥򳫻Ϥ
+     *  DBトランザクションを開始する
      *
      *  @access public
-     *  @return mixed   0:ｪλ Ethna_Error:顼
+     *  @return mixed   0:正常終了 Ethna_Error:エラー
      */
     function begin()
     {
@@ -127,10 +134,10 @@ class Ethna_DB_ADOdb extends Ethna_DB
 
     //{{{ rollback
     /**
-     *  DBȥ󥶥Ǥ
+     *  DBトランザクションを中断する
      *
      *  @access public
-     *  @return mixed   0:ｪλ Ethna_Error:顼
+     *  @return mixed   0:正常終了 Ethna_Error:エラー
      */
     function rollback()
     {
@@ -141,10 +148,10 @@ class Ethna_DB_ADOdb extends Ethna_DB
 
     //{{{ commit
     /**
-     *  DBȥ󥶥λ
+     *  DBトランザクションを終了する
      *
      *  @access public
-     *  @return mixed   0:ｪλ Ethna_Error:顼
+     *  @return mixed   0:正常終了 Ethna_Error:エラー
      */
     function commit()
     {
@@ -155,11 +162,11 @@ class Ethna_DB_ADOdb extends Ethna_DB
 
     //{{{ query
     /**
-     *  ȯԤ
+     *  クエリを発行する
      *
      *  @access public
-     *  @param  string  $query  SQLʸ
-     *  @return mixed   DB_Result:̥֥ Ethna_Error:顼
+     *  @param  string  $query  SQL文
+     *  @return mixed   DB_Result:結果オブジェクト Ethna_Error:エラー
      */
     function &query($query, $inputarr = false)
     {
@@ -169,11 +176,11 @@ class Ethna_DB_ADOdb extends Ethna_DB
     
     //{{{ _query
     /**
-     *  ȯԤ
+     *  クエリを発行する
      *
      *  @access private
-     *  @param  string  $query  SQLʸ
-     *  @return mixed   DB_Result:̥֥ Ethna_Error:顼
+     *  @param  string  $query  SQL文
+     *  @return mixed   DB_Result:結果オブジェクト Ethna_Error:エラー
      */
     function &_query($query, $inputarr = false)
     {
@@ -182,7 +189,7 @@ class Ethna_DB_ADOdb extends Ethna_DB
 
         if ($r === false) {
 
-            $error = Ethna::raiseError('顼 SQL[%s] CODE[%d] MESSAGE[%s]',
+            $error = Ethna::raiseError('エラー SQL[%s] CODE[%d] MESSAGE[%s]',
                 E_DB_QUERY,
                 $query,
                 $this->db->ErrorNo(),
