@@ -6,17 +6,19 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_AppObject.php 451 2007-01-17 07:46:35Z ichii386 $
+ *  @version    $Id$
  */
 
 // {{{ Ethna_AppObject
 /**
- *  ץꥱ󥪥֥ȤΥ١饹
+ *  アプリケーションオブジェクトのベースクラス
  *
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @access     public
  *  @package    Ethna
- *  @todo       ʣơ֥б
+ *  @todo       複数テーブルの対応
+ *  @todo       remove dependency on PEAR::DB
+ *  @todo       quoteidentifier は Ethna_AppSQL に持っていくべき
  */
 class Ethna_AppObject
 {
@@ -25,46 +27,46 @@ class Ethna_AppObject
      *  @access private
      */
 
-    /** @var    object  Ethna_Backend       backend֥ */
+    /** @var    object  Ethna_Backend       backendオブジェクト */
     var $backend;
 
-    /** @var    object  Ethna_Config        ꥪ֥ */
+    /** @var    object  Ethna_Config        設定オブジェクト */
     var $config;
 
-    /** @var    object  Ethna_I18N          i18n֥ */
+    /** @var    object  Ethna_I18N          i18nオブジェクト */
     var $i18n;
 
-    /** @var    object  Ethna_ActionForm    ե४֥ */
+    /** @var    object  Ethna_ActionForm    アクションフォームオブジェクト */
     var $action_form;
 
-    /** @var    object  Ethna_ActionForm    ե४֥(ά) */
+    /** @var    object  Ethna_ActionForm    アクションフォームオブジェクト(省略形) */
     var $af;
 
-    /** @var    object  Ethna_Session       å󥪥֥ */
+    /** @var    object  Ethna_Session       セッションオブジェクト */
     var $session;
 
-    /** @var    string  DBץե */
+    /** @var    string  DB定義プレフィクス */
     var $db_prefix = null;
 
-    /** @var    array   ơ֥ */
+    /** @var    array   テーブル定義。対応するDB上のテーブル名を指定します。*/
     var $table_def = null;
 
-    /** @var    array   ץѥƥ */
+    /** @var    array   プロパティ定義。テーブルのカラム定義を記述します。 */
     var $prop_def = null;
 
-    /** @var    array   ץѥƥ */
+    /** @var    array   プロパティ。各カラムに対応する実際の値です。 */
     var $prop = null;
 
-    /** @var    array   ץѥƥ(Хåå) */
+    /** @var    array   プロパティ(バックアップ) */
     var $prop_backup = null;
 
-    /** @var    int     ץѥƥåͭ(sec) */
+    /** @var    int     プロパティ定義キャッシュ有効期間(sec) */
     var $prop_def_cache_lifetime = 86400;
 
-    /** @var    array   ץ饤ޥꥭ */
+    /** @var    array   プライマリキー定義 */
     var $id_def = null;
 
-    /** @var    int     ֥ID */
+    /** @var    int     オブジェクトID (プライマリーキーの値) */
     var $id = null;
 
     /**#@-*/
@@ -72,14 +74,15 @@ class Ethna_AppObject
 
     // {{{ Ethna_AppObject
     /**
-     *  Ethna_AppObject饹Υ󥹥ȥ饯
+     *  Ethna_AppObjectクラスのコンストラクタ
      *
      *  @access public
-     *  @param  object  Ethna_Backend   &$backend   Ethna_Backend֥
-     *  @param  mixed   $key_type   ̾
-     *  @param  mixed   $key        
-     *  @param  array   $prop       ץѥƥ
-     *  @return mixed   0:ｪλ -1:/ץѥƥ̤ Ethna_Error:顼
+     *  @param  object  Ethna_Backend   &$backend   Ethna_Backendオブジェクト
+     *  @param  mixed   $key_type   レコードを特定するためのカラム名
+     *                              (通常はプライマリーキーのフィールド)
+     *  @param  mixed   $key        レコードを特定するためのカラム値
+     *  @param  array   $prop       プロパティ(レコードの値)一覧
+     *  @return mixed   0:正常終了 -1:キー/プロパティ未指定 Ethna_Error:エラー
      */
     function Ethna_AppObject(&$backend, $key_type = null, $key = null, $prop = null)
     {
@@ -90,39 +93,42 @@ class Ethna_AppObject
         $this->session =& $backend->getSession();
         $ctl =& $backend->getController();
 
-        // DB֥Ȥ
+        // DBオブジェクトの設定
         $db_list = $this->_getDBList();
         if (Ethna::isError($db_list)) {
             return $db_list;
         } else if (is_null($db_list['rw'])) {
             return Ethna::raiseError(
-                "Ethna_AppObjectѤˤϥǡ١꤬ɬפǤ",
+                "Ethna_AppObjectを利用するにはデータベース設定が必要です",
                 E_DB_NODSN);
         }
         $this->my_db_rw =& $db_list['rw'];
         $this->my_db_ro =& $db_list['ro'];
-        // XXX: app objdb typeΤʤƤư٤
+        // XXX: app objはdb typeを知らなくても動くべき
         $this->my_db_type = $this->my_db_rw->getType();
 
-        // ץѥƥư
+        // テーブル定義自動取得
+        // 現在、記述可能なテーブルは常に一つで、primaryはtrue
         if (is_null($this->table_def)) {
             $this->table_def = $this->_getTableDef();
         }
         if (is_string($this->table_def)) {
             $this->table_def = array($this->table_def => array('primary' => true));
         }
+        // プロパティ定義(テーブルのカラム定義)自動取得
+        // データベースから自動取得され、キャッシュされる
         if (is_null($this->prop_def)) {
             $this->prop_def = $this->_getPropDef();
         }
 
-        // ץѥƥɬܥ䴰
+        // プロパティ定義の必須キーを補完
         foreach (array_keys($this->prop_def) as $k) {
             if (isset($this->prop_def[$k]['primary']) == false) {
                 $this->prop_def[$k]['primary'] = false;
             }
         }
 
-        // ֥ȤΥץ饤ޥꥭ
+        // オブジェクトのプライマリキー定義構築
         foreach ($this->prop_def as $k => $v) {
             if ($v['primary'] == false) {
                 continue;
@@ -131,18 +137,20 @@ class Ethna_AppObject
                 $this->id_def = $k;
             } else if (is_array($this->id_def)) {
                 $this->id_def[] = $k;
-            } else {
+            } else {  // scalar の場合
                 $this->id_def = array($this->id_def, $k);
             }
         }
         
-        // å
+        // キー妥当性チェック
         if (is_null($key_type) && is_null($key) && is_null($prop)) {
             // perhaps for adding object
             return 0;
         }
 
-        // ץѥƥ
+        // プロパティ設定
+        // $key_type, $key が指定されたらDBから値を取得し、設定する
+        // $prop が設定された場合はそれを設定する
         if (is_null($prop)) {
             $this->_setPropByDB($key_type, $key);
         } else {
@@ -151,6 +159,7 @@ class Ethna_AppObject
 
         $this->prop_backup = $this->prop;
 
+        //   プライマリーキーの値を設定
         if (is_array($this->id_def)) {
             $this->id = array();
             foreach ($this->id_def as $k) {
@@ -166,10 +175,11 @@ class Ethna_AppObject
 
     // {{{ isValid
     /**
-     *  ͭʥ֥Ȥɤ֤
+     *  有効なオブジェクトかどうかを返す
+     *  プライマリーキーの値が設定されてなければ不正なオブジェクトです。
      *
      *  @access public
-     *  @return bool    true:ͭ false:̵
+     *  @return bool    true:有効 false:無効
      */
     function isValid()
     {
@@ -183,13 +193,13 @@ class Ethna_AppObject
 
     // {{{ isActive
     /**
-     *  ƥ֤ʥ֥Ȥɤ֤
+     *  アクティブなオブジェクトかどうかを返す
      *
-     *  isValid()᥽åɤϥ֥ȼΤͭɤȽꤹΤФ
-     *  isActive()ϥ֥ȤץꥱȤͭɤ֤
+     *  isValid()メソッドはオブジェクト自体が有効かどうかを判定するのに対し
+     *  isActive()はオブジェクトがアプリケーションとして有効かどうかを返す
      *
      *  @access public
-     *  @return bool    true:ƥ false:󥢥ƥ
+     *  @return bool    true:アクティブ false:非アクティブ
      */
     function isActive()
     {
@@ -202,10 +212,10 @@ class Ethna_AppObject
 
     // {{{ getDef
     /**
-     *  ֥ȤΥץѥƥ֤
+     *  オブジェクトのプロパティ定義(カラム定義)を返す
      *
      *  @access public
-     *  @return array   ֥ȤΥץѥƥ
+     *  @return array   オブジェクトのプロパティ定義
      */
     function getDef()
     {
@@ -215,10 +225,10 @@ class Ethna_AppObject
 
     // {{{ getIdDef
     /**
-     *  ץ饤ޥꥭ֤
+     *  プライマリキー定義を返す
      *
      *  @access public
-     *  @return mixed   ץ饤ޥꥭȤʤץѥƥ̾
+     *  @return mixed   プライマリキーとなるプロパティ名
      */
     function getIdDef()
     {
@@ -228,10 +238,10 @@ class Ethna_AppObject
 
     // {{{ getId
     /**
-     *  ֥ID֤
+     *  オブジェクトID(primary keyの値)を返す
      *
      *  @access public
-     *  @return mixed   ֥ID
+     *  @return mixed   オブジェクトID
      */
     function getId()
     {
@@ -241,11 +251,11 @@ class Ethna_AppObject
 
     // {{{ get
     /**
-     *  ֥ȥץѥƥؤΥ(R)
+     *  オブジェクトプロパティへのアクセサ(R)
      *
      *  @access public
-     *  @param  string  $key    ץѥƥ̾
-     *  @return mixed   ץѥƥ
+     *  @param  string  $key    プロパティ名(カラム名)
+     *  @return mixed   プロパティ(カラムの値)
      */
     function get($key)
     {
@@ -262,11 +272,15 @@ class Ethna_AppObject
 
     // {{{ getName
     /**
-     *  ֥ȥץѥƥɽ̾ؤΥ
+     *  オブジェクトプロパティ表示名へのアクセサ
+     *  プロパティ値と、表示用の値が違う場合 (「県」等）に、
+     *  オーバーライドして下さい。
+     *
+     *  表示用の値を返す形で実装します。 
      *
      *  @access public
-     *  @param  string  $key    ץѥƥ̾
-     *  @return string  ץѥƥɽ̾
+     *  @param  string  $key    プロパティ(カラム)名
+     *  @return string  プロパティ(カラム)の表示名
      */
     function getName($key)
     {
@@ -274,13 +288,14 @@ class Ethna_AppObject
     }
     // }}}
 
-    // {{{ getLongName
     /**
-     *  ֥ȥץѥƥɽ̾(ܺ)ؤΥ
+     *  オブジェクトプロパティ表示名(詳細)へのアクセサ
+     *  プロパティ値と、表示用の値が違う場合 (「県」等）に、
+     *  オーバーライドして下さい。
      *
      *  @access public
-     *  @param  string  $key    ץѥƥ̾
-     *  @return string  ץѥƥɽ̾(ܺ)
+     *  @param  string  $key    プロパティ(カラム)名
+     *  @return string  プロパティ(カラム)の表示名(詳細)
      */
     function getLongName($key)
     {
@@ -290,10 +305,11 @@ class Ethna_AppObject
 
     // {{{ getNameObject
     /**
-     *  ץѥƥɽ̾ǼϢ
+     *  プロパティ表示名を格納した連想配列を取得する
+     *  すべての getName メソッドの戻り値を配列として返します。
      *
      *  @access public
-     *  @return array   ץѥƥɽ̾ǼϢ
+     *  @return array   プロパティ表示名を格納した連想配列
      */
     function getNameObject()
     {
@@ -309,11 +325,11 @@ class Ethna_AppObject
 
     // {{{ set
     /**
-     *  ֥ȥץѥƥؤΥ(W)
+     *  オブジェクトプロパティ(カラムに対応した値)を設定します。
      *
      *  @access public
-     *  @param  string  $key    ץѥƥ̾
-     *  @param  string  $value  ץѥƥ
+     *  @param  string  $key    プロパティ(カラム)名
+     *  @param  string  $value  プロパティ値
      */
     function set($key, $value)
     {
@@ -327,17 +343,17 @@ class Ethna_AppObject
 
     // {{{ dump
     /**
-     *  ֥ȥץѥƥηǥפ(ߤCSVΤߥݡ)
+     *  オブジェクトプロパティを指定の形式でダンプする(現在はCSV形式のみサポート)
      *
      *  @access public
-     *  @param  string  $type   ׷("csv"...)
-     *  @return string  ׷(顼ξnull)
+     *  @param  string  $type   ダンプ形式("csv"...)
+     *  @return string  ダンプ結果(エラーの場合はnull)
      */
     function dump($type = "csv")
     {
         $method = "_dump_$type";
         if (method_exists($this, $method) == false) {
-            return Ethna::raiseError("᥽å̤[%s]", E_APP_NOMETHOD, $method);
+            return Ethna::raiseError("Undefined Method [%s]", E_APP_NOMETHOD, $method);
         }
 
         return $this->$method();
@@ -346,22 +362,24 @@ class Ethna_AppObject
 
     // {{{ importForm
     /**
-     *  եͤ饪֥ȥץѥƥ򥤥ݡȤ
+     *  フォーム値からオブジェクトプロパティをインポートする
      *
      *  @access public
-     *  @param  int     $option ݡȥץ(OBJECT_IMPORT_IGNORE_NULL,...)
+     *  @param  int     $option インポートオプション
+     *                  OBJECT_IMPORT_IGNORE_NULL: フォーム値が送信されていない場合はスキップ
+     *                  OBJECT_IMPORT_CONVERT_NULL: フォーム値が送信されていない場合、空文字列に変換
      */
     function importForm($option = null)
     {
         foreach ($this->getDef() as $k => $def) {
             $value = $this->af->get($def['form_name']);
             if (is_null($value)) {
-                // եफͤƤʤο
+                // フォームから値が送信されていない場合の振舞い
                 if ($option == OBJECT_IMPORT_IGNORE_NULL) {
-                    // nullϥå
+                    // nullはスキップ
                     continue;
                 } else if ($option == OBJECT_IMPORT_CONVERT_NULL) {
-                    // ʸѴ
+                    // 空文字列に変換
                     $value = '';
                 }
             }
@@ -372,7 +390,7 @@ class Ethna_AppObject
 
     // {{{ exportForm
     /**
-     *  ֥ȥץѥƥեͤ˥ݡȤ
+     *  オブジェクトプロパティをフォーム値にエクスポートする
      *
      *  @access public
      */
@@ -386,19 +404,21 @@ class Ethna_AppObject
 
     // {{{ add
     /**
-     *  ֥Ȥɲä
+     *  オブジェクトを追加する(INSERT)
      *
      *  @access public
-     *  @return mixed   0:ｪλ Ethna_Error:顼
+     *  @return mixed   0:正常終了 Ethna_Error:エラー
+     *  @todo remove dependency on PEAR::DB
      */
     function add()
     {
-        // next idμ: (pgsqlξΤ)
-        // ǤϤidȤ
+        // primary key 定義が sequence の場合、
+        // next idの取得: (pgsqlの場合のみ)
+        // 取得できた場合はこのidを使う
         foreach (to_array($this->id_def) as $id_def) {
             if (isset($this->prop_def[$id_def]['seq'])
                 && $this->prop_def[$id_def]['seq']) {
-                // NOTE: app objectʳinsertʤȤ
+                // NOTE: このapp object以外からinsertがないことが前提
                 $next_id = $this->my_db_rw->getNextId(
                     $this->prop_def[$id_def]['table'], $id_def);
                 if ($next_id !== null && $next_id >= 0) {
@@ -408,12 +428,14 @@ class Ethna_AppObject
             }
         }
 
+        //    INSERT 文を取得し、実行
         $sql = $this->_getSQL_Add();
         for ($i = 0; $i < 4; $i++) {
             $r =& $this->my_db_rw->query($sql);
+            //   エラーの場合 -> 重複キーエラーの場合はリトライ
             if (Ethna::isError($r)) {
                 if ($r->getCode() == E_DB_DUPENT) {
-                    // ʣ顼Ƚ
+                    // 重複エラーキーの判別
                     $duplicate_key_list = $this->_getDuplicateKeyList();
                     if (Ethna::isError($duplicate_key_list)) {
                         return $duplicate_key_list;
@@ -421,7 +443,7 @@ class Ethna_AppObject
                     if (is_array($duplicate_key_list)
                         && count($duplicate_key_list) > 0) {
                         foreach ($duplicate_key_list as $k) {
-                            return Ethna::raiseNotice('ʣ顼[%s]',
+                            return Ethna::raiseNotice('Duplicate Key Error [%s]',
                                                       E_APP_DUPENT, $k);
                         }
                     }
@@ -434,11 +456,11 @@ class Ethna_AppObject
         }
         if ($i == 4) {
             // cannot be reached
-            return Ethna::raiseError('ʣ顼Ƚ̥顼', E_GENERAL);
+            return Ethna::raiseError('Cannot detect Duplicate key Error', E_GENERAL);
         }
 
-        // last insert idμ: (mysql, sqliteΤ)
-        // primary key  'seq' ե饰(ǽ)ץѥƥ
+        // last insert idの取得: (mysql, sqliteのみ)
+        // primary key の 'seq' フラグがある(最初の)プロパティに入れる
         $insert_id = $this->my_db_rw->getInsertId(); 
         if ($insert_id !== null && $insert_id >= 0) {
             foreach (to_array($this->id_def) as $id_def) {
@@ -450,7 +472,7 @@ class Ethna_AppObject
             }
         }
 
-        // ID
+        // ID(Primary Key)の値を設定
         if (is_array($this->id_def)) {
             $this->id = array();
             foreach ($this->id_def as $k) {
@@ -462,7 +484,7 @@ class Ethna_AppObject
             trigger_error("primary key is missing", E_USER_ERROR);
         }
 
-        // Хåå/å幹
+        // バックアップ/キャッシュ更新
         $this->prop_backup = $this->prop;
         $this->_clearPropCache();
 
@@ -472,19 +494,21 @@ class Ethna_AppObject
 
     // {{{ update
     /**
-     *  ֥Ȥ򹹿
+     *  オブジェクトを更新する(UPDATE)
      *
      *  @access public
-     *  @return mixed   0:ｪλ Ethna_Error:顼
+     *  @return mixed   0:正常終了 Ethna_Error:エラー
+     *  @todo remove dependency on PEAR::DB
      */
     function update()
     {
         $sql = $this->_getSQL_Update();
-        for ($i = 0; $i < 4; $i++) {
+        //   エラーの場合 -> 重複キーエラーの場合はリトライ(4回)
+        for ($i = 0; $i < 4; $i++) {  //  magic number
             $r =& $this->my_db_rw->query($sql);
             if (Ethna::isError($r)) {
                 if ($r->getCode() == E_DB_DUPENT) {
-                    // ʣ顼Ƚ
+                    // 重複エラーキーの判別
                     $duplicate_key_list = $this->_getDuplicateKeyList();
                     if (Ethna::isError($duplicate_key_list)) {
                         return $duplicate_key_list;
@@ -492,7 +516,7 @@ class Ethna_AppObject
                     if (is_array($duplicate_key_list)
                         && count($duplicate_key_list) > 0) {
                         foreach ($duplicate_key_list as $k) {
-                            return Ethna::raiseNotice('ʣ顼[%s]',
+                            return Ethna::raiseNotice('Duplicate Key Error [%s]',
                                                       E_APP_DUPENT, $k);
                         }
                     }
@@ -505,7 +529,7 @@ class Ethna_AppObject
         }
         if ($i == 4) {
             // cannot be reached
-            return Ethna::raiseError('ʣ顼Ƚ̥顼', E_GENERAL);
+            return Ethna::raiseError('Cannot detect Duplicate key Error', E_GENERAL);
         }
 
         $affected_rows = $this->my_db_rw->affectedRows();
@@ -513,7 +537,7 @@ class Ethna_AppObject
             $this->backend->log(LOG_DEBUG, "update query with 0 updated rows");
         }
 
-        // Хåå/å幹
+        // バックアップ/キャッシュ更新
         $this->prop_backup = $this->prop;
         $this->_clearPropCache();
 
@@ -523,19 +547,21 @@ class Ethna_AppObject
 
     // {{{ replace
     /**
-     *  ֥Ȥִ
+     *  オブジェクトを置換する
      *
-     *  MySQLREPLACEʸưԤ(add()ǽʣ顼ȯ
-     *  update()Ԥ)
+     *  MySQLのREPLACE文に相当する動作を行う(add()で重複エラーが発生したら
+     *  update()を行う)
      *
      *  @access public
-     *  @return mixed   0:ｪλ >0:֥ID(ɲû) Ethna_Error:顼
+     *  @return mixed   0:正常終了 >0:オブジェクトID(追加時) Ethna_Error:エラー
+     *  @todo remove dependency on PEAR::DB
      */
     function replace()
     {
         $sql = $this->_getSQL_Select($this->getIdDef(), $this->getId());
 
-        for ($i = 0; $i < 3; $i++) {
+        //   重複機ーエラーの場合はリトライ(4回) 
+        for ($i = 0; $i < 3; $i++) {  // magic number
             $r = $this->my_db_rw->query($sql);
             if (Ethna::isError($r)) {
                 return $r;
@@ -561,10 +587,11 @@ class Ethna_AppObject
 
     // {{{ remove
     /**
-     *  ֥Ȥ
+     *  オブジェクト(レコード)を削除する
      *
      *  @access public
-     *  @return mixed   0:ｪλ Ethna_Error:顼
+     *  @return mixed   0:正常終了 Ethna_Error:エラー
+     *  @todo remove dependency on PEAR::DB
      */
     function remove()
     {
@@ -574,7 +601,7 @@ class Ethna_AppObject
             return $r;
         }
 
-        // ץѥƥ/Хåå/å奯ꥢ
+        // プロパティ/バックアップ/キャッシュクリア
         $this->id = $this->prop = $this->prop_backup = null;
         $this->_clearPropCache();
 
@@ -584,20 +611,23 @@ class Ethna_AppObject
 
     // {{{ searchId
     /**
-     *  ֥ID򸡺
+     *  オブジェクトID(プライマリーキーの値)を検索する
      *
      *  @access public
-     *  @param  array   $filter     
-     *  @param  array   $order      ̥Ⱦ
-     *  @param  int     $offset     ̼եå
-     *  @param  int     $count      ̼
-     *  @return mixed   array(0 => ˥ޥå,
-     *                  1 => $offset, $countˤꤵ줿Υ֥ID)
-     *                  Ethna_Error:顼
+     *  @param  array   $filter     WHERE検索条件(カラム名をキー、値には実際の条件値か、Ethna_AppSearchObjectを指定)
+     *  @param  array   $order      検索結果ソート条件
+     *                              (カラム名をキー。値には、昇順の場合は OBJECT_SORT_ASC, 降順の場合は　OBJECT_SORT_DESC)
+     *  @param  int     $offset     検索結果取得オフセット
+     *  @param  int     $count      検索結果取得数
+     *  @return mixed   array(0 => 検索条件にマッチした件数,
+     *                  1 => $offset, $countにより指定された件数のオブジェクトID一覧)
+     *                  Ethna_Error:エラー
+     *  TODO: remove dependency on PEAR::DB
      */
     function searchId($filter = null, $order = null, $offset = null, $count = null)
     {
-        if (is_null($offset) == false || is_null($count) == false) {
+       //   プライマリーキー件数検索
+       if (is_null($offset) == false || is_null($count) == false) {
             $sql = $this->_getSQL_SearchLength($filter);
             $r =& $this->my_db_ro->query($sql);
             if (Ethna::isError($r)) {
@@ -619,7 +649,7 @@ class Ethna_AppObject
         for ($i = 0; $i < $n; $i++) {
             $row = $this->my_db_ro->fetchRow($r, DB_FETCHMODE_ASSOC);
 
-            // ץ饤ޥꥭ1ʤ饹顼ͤѴ
+            // プライマリキーが1カラムならスカラー値に変換
             if (is_array($this->id_def) == false) {
                 $row = $row[$this->id_def];
             }
@@ -635,21 +665,24 @@ class Ethna_AppObject
 
     // {{{ searchProp
     /**
-     *  ֥ȥץѥƥ򸡺
+     *  オブジェクトプロパティ(レコード)を検索する
      *
      *  @access public
-     *  @param  array   $keys       ץѥƥ
-     *  @param  array   $filter     
-     *  @param  array   $order      ̥Ⱦ
-     *  @param  int     $offset     ̼եå
-     *  @param  int     $count      ̼
-     *  @return mixed   array(0 => ˥ޥå,
-     *                  1 => $offset, $countˤꤵ줿Υ֥ȥץѥƥ)
-     *                  Ethna_Error:顼
+     *  @param  array   $keys       取得するプロパティ(カラム名)
+     *  @param  array   $filter     WHERE検索条件(カラム名をキー、値には実際の条件値か、Ethna_AppSearchObjectを指定)
+     *  @param  array   $order      検索結果ソート条件
+     *                              (カラム名をキー。値には、昇順の場合は OBJECT_SORT_ASC, 降順の場合は　OBJECT_SORT_DESC)
+     *  @param  int     $offset     検索結果取得オフセット
+     *  @param  int     $count      検索結果取得数
+     *  @return mixed   array(0 => 検索条件にマッチした件数,
+     *                  1 => $offset, $countにより指定された件数のオブジェクトプロパティ一覧)
+     *                  Ethna_Error:エラー
+     *  TODO: remove dependency on PEAR::DB
      */
     function searchProp($keys = null, $filter = null, $order = null,
                         $offset = null, $count = null)
     {
+        //   プライマリーキー件数検索
         if (is_null($offset) == false || is_null($count) == false) {
             $sql = $this->_getSQL_SearchLength($filter);
             $r =& $this->my_db_ro->query($sql);
@@ -683,15 +716,15 @@ class Ethna_AppObject
 
     // {{{ _setDefault
     /**
-     *  ֥ȤΥץꥱǥեȥץѥƥꤹ
+     *  オブジェクトのアプリケーションデフォルトプロパティを設定する
      *
-     *  󥹥ȥ饯ˤꤵ줿˥ޥå륨ȥ꤬ʤä
-     *  ǥեȥץѥƥ򤳤ꤹ뤳Ȥ
+     *  コンストラクタにより指定されたキーにマッチするエントリがなかった場合の
+     *  デフォルトプロパティをここで設定することが出来る
      *
      *  @access protected
-     *  @param  mixed   $key_type   ̾
-     *  @param  mixed   $key        
-     *  @return int     0:ｪλ
+     *  @param  mixed   $key_type   検索キー名
+     *  @param  mixed   $key        検索キー
+     *  @return int     0:正常終了
      */
     function _setDefault($key_type, $key)
     {
@@ -701,11 +734,12 @@ class Ethna_AppObject
 
     // {{{ _setPropByDB
     /**
-     *  ֥ȥץѥƥDB
+     *  オブジェクトプロパティをDBから取得する
      *
      *  @access private
-     *  @param  mixed   $key_type   ̾
-     *  @param  mixed   $key        
+     *  @param  mixed   $key_type   検索キー名
+     *  @param  mixed   $key        検索キー
+     *  TODO: depend on PEAR::DB
      */
     function _setPropByDB($key_type, $key)
     {
@@ -725,7 +759,7 @@ class Ethna_AppObject
             }
         }
 
-        // åå
+        // キャッシュチェック
         $class_name = strtolower(get_class($this));
         if (is_array($_ETHNA_APP_OBJECT_CACHE) == false
             || array_key_exists($class_name, $_ETHNA_APP_OBJECT_CACHE) == false) {
@@ -737,10 +771,10 @@ class Ethna_AppObject
             return;
         }
 
-        // SQLʸ
+        // SQL文構築
         $sql = $this->_getSQL_Select($key_type, $key);
 
-        // ץѥƥ
+        // プロパティ取得
         $r =& $this->my_db_ro->query($sql);
         if (Ethna::isError($r)) {
             return;
@@ -758,24 +792,24 @@ class Ethna_AppObject
         }
         $this->prop = $this->my_db_ro->fetchRow($r, DB_FETCHMODE_ASSOC);
 
-        // å奢åץǡ
+        // キャッシュアップデート
         $_ETHNA_APP_OBJECT_CACHE[$class_name][$cache_key] = $this->prop;
     }
     // }}}
 
     // {{{ _setPropByValue
     /**
-     *  󥹥ȥ饯ǻꤵ줿ץѥƥꤹ
+     *  コンストラクタで指定されたプロパティを設定する
      *
      *  @access private
-     *  @param  array   $prop   ץѥƥ
+     *  @param  array   $prop   プロパティ一覧
      */
     function _setPropByValue($prop)
     {
         $def = $this->getDef();
         foreach ($def as $key => $value) {
             if ($value['primary'] && isset($prop[$key]) == false) {
-                // ץ饤ޥꥭϾάԲ
+                // プライマリキーは省略不可
                 trigger_error("primary key is not identical", E_USER_ERROR);
             }
             $this->prop[$key] = $prop[$key];
@@ -785,10 +819,10 @@ class Ethna_AppObject
 
     // {{{ _getPrimaryTable
     /**
-     *  ֥ȤΥץ饤ޥơ֥
+     *  オブジェクトのプライマリテーブルを取得する
      *
      *  @access private
-     *  @return string  ֥ȤΥץ饤ޥơ֥̾
+     *  @return string  オブジェクトのプライマリテーブル名
      */
     function _getPrimaryTable()
     {
@@ -801,16 +835,17 @@ class Ethna_AppObject
 
     // {{{ _getDuplicateKeyList
     /**
-     *  ʣ
+     *  重複キーを取得する
      *
      *  @access private
-     *  @return mixed   0:ʣʤ Ethna_Error:顼 array:ʣΥץѥƥ̾
+     *  @return mixed   0:重複なし Ethna_Error:エラー array:重複キーのプロパティ名一覧
+     *  TODO: depend on PEAR::DB
      */
     function _getDuplicateKeyList()
     {
         $duplicate_key_list = array();
 
-        // ꤵƤץ饤ޥꥭNULLޤޤϸʤ
+        // 現在設定されているプライマリキーにNULLが含まれる場合は検索しない
         $check_pkey = true;
         foreach (to_array($this->id_def) as $k) {
             if (isset($this->prop[$k]) == false || is_null($this->prop[$k])) {
@@ -819,7 +854,7 @@ class Ethna_AppObject
             }
         }
 
-        // ץ饤ޥꥭmulti columnsˤʤΤ̰
+        // プライマリキーはmulti columnsになり得るので別扱い
         if ($check_pkey) {
             $sql = $this->_getSQL_Duplicate($this->id_def);
             $r =& $this->my_db_rw->query($sql);
@@ -831,7 +866,7 @@ class Ethna_AppObject
             }
         }
 
-        // ˡ
+        // ユニークキー
         foreach ($this->prop_def as $k => $v) {
             if ($v['primary'] == true || $v['key'] == false) {
                 continue;
@@ -855,18 +890,18 @@ class Ethna_AppObject
 
     // {{{ _getSQL_Select
     /**
-     *  ֥ȥץѥƥSQLʸۤ
+     *  オブジェクトプロパティを取得するSQL文を構築する
      *
      *  @access private
-     *  @param  array   $key_type   Ȥʤץѥƥ̾
-     *  @param  array   $key        $key_typeб륭
-     *  @return string  SELECTʸ
+     *  @param  array   $key_type   検索キーとなるプロパティ(カラム)名一覧
+     *  @param  array   $key        $key_typeに対応するキー一覧
+     *  @return string  SELECT文
      */
     function _getSQL_Select($key_type, $key)
     {
         $key_type = to_array($key_type);
         if (is_null($key)) {
-            // add()
+            // add()前
             $key = array();
             for ($i = 0; $i < count($key_type); $i++) {
                 $key[$i] = null;
@@ -875,7 +910,7 @@ class Ethna_AppObject
             $key = to_array($key);
         }
 
-        // SQL
+        // SQLエスケープ
         Ethna_AppSQL::escapeSQL($key, $this->my_db_type);
 
         $tables = implode(',',
@@ -883,7 +918,7 @@ class Ethna_AppObject
         $columns = implode(',',
             $this->my_db_ro->quoteIdentifier(array_keys($this->prop_def)));
 
-        // 
+        // 検索条件
         $condition = null;
         for ($i = 0; $i < count($key_type); $i++) {
             if (is_null($condition)) {
@@ -903,10 +938,10 @@ class Ethna_AppObject
 
     // {{{ _getSQL_Add
     /**
-     *  ֥ȤɲäSQLʸۤ
+     *  オブジェクトと追加するSQL文を構築する
      *
      *  @access private
-     *  @return string  ֥Ȥɲä뤿INSERTʸ
+     *  @return string  オブジェクトを追加するためのINSERT文
      */
     function _getSQL_Add()
     {
@@ -936,17 +971,17 @@ class Ethna_AppObject
 
     // {{{ _getSQL_Update
     /**
-     *  ֥ȥץѥƥ򹹿SQLʸۤ
+     *  オブジェクトプロパティを更新するSQL文を構築する
      *
      *  @access private
-     *  @return ֥ȥץѥƥ򹹿뤿UPDATEʸ
+     *  @return オブジェクトプロパティを更新するためのUPDATE文
      */
     function _getSQL_Update()
     {
         $tables = implode(',',
             $this->my_db_rw->quoteIdentifier(array_keys($this->table_def)));
 
-        // SET繽
+        // SET句構築
         $set_list = "";
         $prop_arg_list = $this->prop;
         Ethna_AppSQL::escapeSQL($prop_arg_list, $this->my_db_type);
@@ -959,7 +994,7 @@ class Ethna_AppObject
                                  $prop_arg_list[$k]);
         }
 
-        // (primary key)
+        // 検索条件(primary key)
         $condition = null;
         foreach (to_array($this->id_def) as $k) {
             if (is_null($condition)) {
@@ -981,17 +1016,17 @@ class Ethna_AppObject
 
     // {{{ _getSQL_Remove
     /**
-     *  ֥ȤSQLʸۤ
+     *  オブジェクトを削除するSQL文を構築する
      *
      *  @access private
-     *  @return string  ֥Ȥ뤿DELETEʸ
+     *  @return string  オブジェクトを削除するためのDELETE文
      */
     function _getSQL_Remove()
     {
         $tables = implode(',',
             $this->my_db_rw->quoteIdentifier(array_keys($this->table_def)));
 
-        // (primary key)
+        // 検索条件(primary key)
         $condition = null;
         foreach (to_array($this->id_def) as $k) {
             if (is_null($condition)) {
@@ -1017,11 +1052,11 @@ class Ethna_AppObject
 
     // {{{ _getSQL_Duplicate
     /**
-     *  ֥ȥץѥƥΥˡåԤSQLʸۤ
+     *  オブジェクトプロパティのユニークチェックを行うSQL文を構築する
      *
      *  @access private
-     *  @param  mixed   $key    ˡåԤץѥƥ̾
-     *  @return string  ˡåԤSELECTʸ
+     *  @param  mixed   $key    ユニークチェックを行うプロパティ名
+     *  @return string  ユニークチェックを行うためのSELECT文
      */
     function _getSQL_Duplicate($key)
     {
@@ -1031,7 +1066,7 @@ class Ethna_AppObject
             $this->my_db_ro->quoteIdentifier(array_keys($this->prop_def)));
 
         $condition = null;
-        // (ꤵƤץ饤ޥꥭϸоݤ)
+        // 検索条件(現在設定されているプライマリキーは検索対象から除く)
         if (is_null($this->id) == false) {
             $primary_value = to_array($this->getId());
             $n = 0;
@@ -1069,25 +1104,32 @@ class Ethna_AppObject
 
     // {{{ _getSQL_SearchLength
     /**
-     *  ֥ȸ(offset, count)SQLʸۤ
+     *  オブジェクト検索総数(offset, count除外)を取得するSQL文を構築する
      *
      *  @access private
-     *  @param  array   $filter     
-     *  @return string  뤿SELECTʸ
-     *  @todo   my_db_typeλȤѻ
+     *  @param  array   $filter     WHERE検索条件(カラム名をキー、値には実際の条件値か、Ethna_AppSearchObjectを指定)
+     *  @return string  検索総数を取得するためのSELECT文
+     *  @todo   my_db_typeの参照を廃止
      */
     function _getSQL_SearchLength($filter)
     {
-        // ơ֥
+        // テーブル名をクォートした上で連結。
         $tables = implode(',',
             $this->my_db_ro->quoteIdentifier(array_keys($this->table_def)));
+
+        // プライマリーキー以外の検索条件が含まれていた
+        // 場合は、追加テーブルがあるとみなし、
+        // その解釈は _SQLPlugin_SearchTable に任せる
         if ($this->_isAdditionalField($filter)) {
             $tables .= " " . $this->_SQLPlugin_SearchTable();
         }
 
         $id_def = to_array($this->id_def);
+
+        //  テーブル名.プライマリーキー名
+        //  複数あった場合ははじめのものを使う
         $column_id = $this->my_db_ro->quoteIdentifier($this->_getPrimaryTable())
-            . "." . $this->my_db_ro->quoteIdentifier($id_def[0]);
+             . "." . $this->my_db_ro->quoteIdentifier($id_def[0]);
         $id_count = $this->my_db_ro->quoteIdentifier('id_count');
         $condition = $this->_getSQL_SearchCondition($filter);
 
@@ -1105,18 +1147,19 @@ class Ethna_AppObject
 
     // {{{ _getSQL_SearchId
     /**
-     *  ֥IDԤSQLʸۤ
+     *  オブジェクトID(プライマリーキー)検索を行うSQL文を構築する
      *
      *  @access private
-     *  @param  array   $filter     
-     *  @param  array   $order      ̥Ⱦ
-     *  @param  int     $offset     ̼եå
-     *  @param  int     $count      ̼
-     *  @return string  ֥ȸԤSELECTʸ
+     *  @param  array   $filter     WHERE検索条件(カラム名をキー、値には実際の条件値か、Ethna_AppSearchObjectを指定)
+     *  @param  array   $order      検索結果ソート条件
+     *                              (カラム名をキー。値には、昇順の場合は OBJECT_SORT_ASC, 降順の場合は　OBJECT_SORT_DESC)
+     *  @param  int     $offset     検索結果取得オフセット
+     *  @param  int     $count      検索結果取得数
+     *  @return string  オブジェクト検索を行うSELECT文
      */
     function _getSQL_SearchId($filter, $order, $offset, $count)
     {
-        // ơ֥
+        // テーブル
         $tables = implode(',',
             $this->my_db_ro->quoteIdentifier(array_keys($this->table_def)));
         if ($this->_isAdditionalField($filter)
@@ -1163,19 +1206,20 @@ class Ethna_AppObject
 
     // {{{ _getSQL_SearchProp
     /**
-     *  ֥ȥץѥƥԤSQLʸۤ
+     *  オブジェクトプロパティ検索を行うSQL文を構築する
      *
      *  @access private
-     *  @param  array   $keys       ץѥƥ
-     *  @param  array   $filter     
-     *  @param  array   $order      ̥Ⱦ
-     *  @param  int     $offset     ̼եå
-     *  @param  int     $count      ̼
-     *  @return string  ֥ȸԤSELECTʸ
+     *  @param  array   $keys       取得プロパティ(カラム名)一覧
+     *  @param  array   $filter     WHERE検索条件(カラム名をキー、値には実際の条件値か、Ethna_AppSearchObjectを指定)
+     *  @param  array   $order      検索結果ソート条件
+     *                              (カラム名をキー。値には、昇順の場合は OBJECT_SORT_ASC, 降順の場合は　OBJECT_SORT_DESC)
+     *  @param  int     $offset     検索結果取得オフセット
+     *  @param  int     $count      検索結果取得数
+     *  @return string  オブジェクト検索を行うSELECT文
      */
     function _getSQL_SearchProp($keys, $filter, $order, $offset, $count)
     {
-        // ơ֥
+        // テーブル
         $tables = implode(',',
             $this->my_db_ro->quoteIdentifier(array_keys($this->table_def)));
         if ($this->_isAdditionalField($filter)
@@ -1184,7 +1228,12 @@ class Ethna_AppObject
         }
         $p_table = $this->_getPrimaryTable();
 
-        // ɲåץѥƥ
+        //  検索用追加プロパティ
+        //  プライマリーキー以外の検索キーが含まれていた
+        //  場合は、その解釈を _SQLPlugin_SearchPropDef に任せる
+        //
+        //  これによって、複数のテーブルの条件を指定することが
+        //  できる(一応. ダサいけど)
         if ($this->_isAdditionalField($filter)
             || $this->_isAdditionalField($order)) {
             $search_prop_def = $this->_SQLPlugin_SearchPropDef();
@@ -1193,7 +1242,7 @@ class Ethna_AppObject
         }
         $def = array_merge($this->getDef(), $search_prop_def);
 
-        // 
+        // カラム
         $column = "";
         $keys = $keys === null ? array_keys($def) : to_array($keys);
         foreach ($keys as $key) {
@@ -1201,12 +1250,13 @@ class Ethna_AppObject
                 $column .= ", ";
             }
             $t = isset($def[$key]['table']) ? $def[$key]['table'] : $p_table;
+            //   テーブル名.カラム名
             $column .= sprintf("%s.%s",
                                $this->my_db_ro->quoteIdentifier($t),
                                $this->my_db_ro->quoteIdentifier($key));
         }
 
-        // WHERE ξ
+        // WHERE の条件
         $condition = $this->_getSQL_SearchCondition($filter);
 
         // ORDER BY
@@ -1241,11 +1291,11 @@ class Ethna_AppObject
 
     // {{{ _getSQL_SearchCondition
     /**
-     *  ֥ȸSQLξʸۤ
+     *  オブジェクト検索SQLの条件文を構築する
      *
      *  @access private
-     *  @param  array   $filter     
-     *  @return string  ֥ȸξʸ(顼ʤnull)
+     *  @param  array   $filter     WHERE検索条件(カラム名をキー、値には実際の条件値か、Ethna_AppSearchObjectを指定)
+     *  @return string  オブジェクト検索の条件文(エラーならnull)
      */
     function _getSQL_SearchCondition($filter)
     {
@@ -1255,7 +1305,12 @@ class Ethna_AppObject
 
         $p_table = $this->_getPrimaryTable();
 
-        // ɲåץѥƥ
+        //  検索用追加プロパティ
+        //  プライマリーキー以外の検索キーが含まれていた
+        //  場合は、その解釈を _SQLPlugin_SearchPropDef に任せる
+        //
+        //  これによって、複数のテーブルの条件を指定することが
+        //  できる(一応. ダサいけど)
         if ($this->_isAdditionalField($filter)) {
             $search_prop_def = $this->_SQLPlugin_SearchPropDef();
         } else {
@@ -1278,13 +1333,16 @@ class Ethna_AppObject
 
             $t = isset($prop_def[$k]['table']) ? $prop_def[$k]['table'] : $p_table;
 
+            // 細かい条件を指定するには、Ethna_AppSearchObject
+            // を使う必要がある  文字列の場合は LIKE, 数値の場合
+            // は = 条件しか指定できないからである。
             if (is_object($v)) {
-                // Ethna_AppSearchObjectꤵƤ
+                // Ethna_AppSearchObjectが指定されている場合
                 $condition .= $v->toString(
                     $this->my_db_ro->quoteIdentifier($t)
                     .'.'. $this->my_db_ro->quoteIdentifier($k));
             } else if (is_array($v) && count($v) > 0 && is_object($v[0])) {
-                // Ethna_AppSearchObjectǻꤵƤ
+                // Ethna_AppSearchObjectが配列で指定されている場合
                 $n = 0;
                 foreach ($v as $so) {
                     if ($n > 0) {
@@ -1296,14 +1354,14 @@ class Ethna_AppObject
                     $n++;
                 }
             } else if ($prop_def[$k]['type'] == VAR_TYPE_STRING) {
-                // ά(ʸ)
+                // 省略形(文字列)
                 Ethna_AppSQL::escapeSQL($v, $this->my_db_type);
                 $condition .= Ethna_AppSQL::getCondition(
                     $this->my_db_ro->quoteIdentifier($t)
                     .'.'. $this->my_db_ro->quoteIdentifier($k),
                     $v, OBJECT_CONDITION_LIKE);
             } else {
-                // ά()
+                // 省略形(数値)
                 Ethna_AppSQL::escapeSQL($v, $this->my_db_type);
                 $condition .= Ethna_AppSQL::getCondition(
                     $this->my_db_ro->quoteIdentifier($t)
@@ -1318,7 +1376,7 @@ class Ethna_AppObject
 
     // {{{ _SQLPlugin_SearchTable
     /**
-     *  ֥ȸSQLץ饰(ɲåơ֥)
+     *  オブジェクト検索SQLプラグイン(追加テーブル)
      *
      *  sample:
      *  <code>
@@ -1326,7 +1384,7 @@ class Ethna_AppObject
      *  </code>
      *
      *  @access protected
-     *  @return string  ơ֥JOINSQLʸ
+     *  @return string  テーブルJOINのSQL文
      */
     function _SQLPlugin_SearchTable()
     {
@@ -1336,7 +1394,7 @@ class Ethna_AppObject
 
     // {{{ _SQLPlugin_SearchPropDef
     /**
-     *  ֥ȸSQLץ饰(ɲþ)
+     *  オブジェクト検索SQLプラグイン(追加条件定義)
      *
      *  sample:
      *  <code>
@@ -1350,7 +1408,7 @@ class Ethna_AppObject
      *  </code>
      *
      *  @access protected
-     *  @return array   ɲþ
+     *  @return array   追加条件定義
      */
     function _SQLPlugin_SearchPropDef()
     {
@@ -1360,10 +1418,10 @@ class Ethna_AppObject
 
     // {{{ _dump_csv
     /**
-     *  ֥ȥץѥƥCSVǥפ
+     *  オブジェクトプロパティをCSV形式でダンプする
      *
      *  @access protected
-     *  @return string  ׷
+     *  @return string  ダンプ結果
      */
     function _dump_csv()
     {
@@ -1384,11 +1442,12 @@ class Ethna_AppObject
 
     // {{{ _isAdditionalField
     /**
-     *  (|Ⱦ)եɤɲåեɤޤޤ뤫ɤ֤
+     *  (検索条件|ソート条件)フィールドにプライマリーキー以外
+     *  の追加フィールドが含まれるかどうかを返す
      *
      *  @access private
-     *  @param  array   $field  (|Ⱦ)
-     *  @return bool    true:ޤޤ false:ޤޤʤ
+     *  @param  array   $field  (検索条件|ソート条件)定義
+     *  @return bool    true:含まれる false:含まれない
      */
     function _isAdditionalField($field)
     {
@@ -1414,7 +1473,7 @@ class Ethna_AppObject
 
     // {{{ _clearPropCache
     /**
-     *  åǡ
+     *  キャッシュデータを削除する
      *
      *  @access private
      */
@@ -1435,7 +1494,7 @@ class Ethna_AppObject
 
     // {{{ _getDBList
     /**
-     *  DB֥(read only/read-write)
+     *  DBオブジェクト(read only/read-write)を取得する
      *
      *  @access protected
      *  @return array   array('ro' => {read only db object}, 'rw' => {read-write db object})
@@ -1450,8 +1509,8 @@ class Ethna_AppObject
         }
         foreach ($db_list as $elt) {
             if ($this->db_prefix) {
-                // Υץեꤵ줿DB³
-                // (ơ֥뤴ȤDBۤʤʤ)
+                // 特定のプレフィクスが指定されたDB接続を利用
+                // (テーブルごとにDBが異なる場合など)
                 if (strncmp($this->db_prefix,
                             $elt['key'],
                             strlen($this->db_prefix)) != 0) {
@@ -1480,13 +1539,13 @@ class Ethna_AppObject
 
     // {{{ _getTableDef
     /**
-     *  ơ֥
+     *  テーブル定義を取得する
      *
-     *  (饹̾ơ֥̾Υ롼Ѥ
-     *  Υ᥽åɤ򥪡С饤ɤޤ)
+     *  (クラス名→テーブル名のルールを変えたい場合は
+     *  このメソッドをオーバーライドします)
      *
      *  @access protected
-     *  @return array   ơ֥
+     *  @return array   テーブル定義
      */
     function _getTableDef()
     {
@@ -1496,20 +1555,23 @@ class Ethna_AppObject
         }
         $table = $match[2];
 
-        // PHP 4Ͼ˾ʸ֤...ΤPHP 5
+        // PHP 4は常に小文字を返す...のでPHP 5専用
         $table = preg_replace('/^([A-Z])/e', "strtolower('\$1')", $table);
         $table = preg_replace('/([A-Z])/e', "'_' . strtolower('\$1')", $table);
 
+        //   JOIN には対応していないので、記述可能なテーブルは
+        //   常に一つ、かつ primary は trueになる
         return array($table => array('primary' => true));
     }
     // }}}
 
     // {{{ _getPropDef
     /**
-     *  ץѥƥ
+     *  プロパティ定義を取得します。キャッシュされている場合は、
+     *  そこから取得します。
      *
      *  @access protected
-     *  @return array   ץѥƥ
+     *  @return array   プロパティ定義
      */
     function _getPropDef()
     {
@@ -1582,7 +1644,7 @@ class Ethna_AppObject
 
     // {{{ _fieldNameToFormName
     /**
-     *  ǡ١ե̾бե̾
+     *  データベースフィールド名に対応するフォーム名を取得する
      *
      *  @access protected
      */
