@@ -6,12 +6,12 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Backend.php 465 2007-07-04 13:33:09Z ichii386 $
+ *  @version    $Id$
  */
 
 // {{{ Ethna_Backend
 /**
- *  Хåɽ饹
+ *  バックエンド処理クラス
  *
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @access     public
@@ -23,63 +23,63 @@ class Ethna_Backend
      *  @access     private
      */
 
-    /** @var    object  Ethna_Controller    controller֥ */
+    /** @var    object  Ethna_Controller    controllerオブジェクト */
     var $controller;
 
-    /** @var    object  Ethna_Controller    controller֥($controllerξά) */
+    /** @var    object  Ethna_Controller    controllerオブジェクト($controllerの省略形) */
     var $ctl;
 
-    /** @var    object  Ethna_ClassFactory  饹եȥꥪ֥ */
+    /** @var    object  Ethna_ClassFactory  クラスファクトリオブジェクト */
     var $class_factory;
 
-    /** @var    object  Ethna_Config        ꥪ֥ */
+    /** @var    object  Ethna_Config        設定オブジェクト */
     var $config;
 
-    /** @var    object  Ethna_I18N          i18n֥ */
+    /** @var    object  Ethna_I18N          i18nオブジェクト */
     var $i18n;
 
-    /** @var    object  Ethna_ActionError   󥨥顼֥ */
+    /** @var    object  Ethna_ActionError   アクションエラーオブジェクト */
     var $action_error;
 
-    /** @var    object  Ethna_ActionError   󥨥顼֥($action_errorξά) */
+    /** @var    object  Ethna_ActionError   アクションエラーオブジェクト($action_errorの省略形) */
     var $ae;
 
-    /** @var    object  Ethna_ActionForm    ե४֥ */
+    /** @var    object  Ethna_ActionForm    アクションフォームオブジェクト */
     var $action_form;
 
-    /** @var    object  Ethna_ActionForm    ե४֥($action_formξά) */
+    /** @var    object  Ethna_ActionForm    アクションフォームオブジェクト($action_formの省略形) */
     var $af;
 
-    /** @var    object  Ethna_ActionClass   󥯥饹֥ */
+    /** @var    object  Ethna_ActionClass   アクションクラスオブジェクト */
     var $action_class;
 
-    /** @var    object  Ethna_ActionClass   󥯥饹֥($action_classξά) */
+    /** @var    object  Ethna_ActionClass   アクションクラスオブジェクト($action_classの省略形) */
     var $ac;
 
-    /** @var    object  Ethna_Session       å󥪥֥ */
+    /** @var    object  Ethna_Session       セッションオブジェクト */
     var $session;
 
-    /** @var    object  Ethna_Plugin        ץ饰󥪥֥ */
+    /** @var    object  Ethna_Plugin        プラグインオブジェクト */
     var $plugin;
 
-    /** @var    array   Ethna_DB֥ȤǼ */
+    /** @var    array   Ethna_DBオブジェクトを格納した配列 */
     var $db_list;
 
-    /** @var    object  Ethna_Logger        ֥ */
+    /** @var    object  Ethna_Logger        ログオブジェクト */
     var $logger;
 
     /**#@-*/
 
 
     /**
-     *  Ethna_Backend饹Υ󥹥ȥ饯
+     *  Ethna_Backendクラスのコンストラクタ
      *
      *  @access public
-     *  @param  object  Ethna_Controller    &$controller    ȥ饪֥
+     *  @param  object  Ethna_Controller    &$controller    コントローラオブジェクト
      */
     function Ethna_Backend(&$controller)
     {
-        // ֥Ȥ
+        // オブジェクトの設定
         $this->controller =& $controller;
         $this->ctl =& $this->controller;
 
@@ -102,10 +102,10 @@ class Ethna_Backend
     }
 
     /**
-     *  controller֥ȤؤΥ(R)
+     *  controllerオブジェクトへのアクセサ(R)
      *
      *  @access public
-     *  @return object  Ethna_Controller    controller֥
+     *  @return object  Ethna_Controller    controllerオブジェクト
      */
     function &getController()
     {
@@ -113,10 +113,10 @@ class Ethna_Backend
     }
 
     /**
-     *  ꥪ֥ȤؤΥ(R)
+     *  設定オブジェクトへのアクセサ(R)
      *
      *  @access public
-     *  @return object  Ethna_Config        ꥪ֥
+     *  @return object  Ethna_Config        設定オブジェクト
      */
     function &getConfig()
     {
@@ -124,10 +124,10 @@ class Ethna_Backend
     }
 
     /**
-     *  ץꥱID֤
+     *  アプリケーションIDを返す
      *
      *  @access public
-     *  @return string  ץꥱID
+     *  @return string  アプリケーションID
      */
     function getAppId()
     {
@@ -135,10 +135,10 @@ class Ethna_Backend
     }
 
     /**
-     *  I18N֥ȤΥ(R)
+     *  I18Nオブジェクトのアクセサ(R)
      *
      *  @access public
-     *  @return object  Ethna_I18N  i18n֥
+     *  @return object  Ethna_I18N  i18nオブジェクト
      */
     function &getI18N()
     {
@@ -146,10 +146,10 @@ class Ethna_Backend
     }
 
     /**
-     *  󥨥顼֥ȤΥ(R)
+     *  アクションエラーオブジェクトのアクセサ(R)
      *
      *  @access public
-     *  @return object  Ethna_ActionError   󥨥顼֥
+     *  @return object  Ethna_ActionError   アクションエラーオブジェクト
      */
     function &getActionError()
     {
@@ -157,10 +157,10 @@ class Ethna_Backend
     }
 
     /**
-     *  ե४֥ȤΥ(R)
+     *  アクションフォームオブジェクトのアクセサ(R)
      *
      *  @access public
-     *  @return object  Ethna_ActionForm    ե४֥
+     *  @return object  Ethna_ActionForm    アクションフォームオブジェクト
      */
     function &getActionForm()
     {
@@ -168,7 +168,7 @@ class Ethna_Backend
     }
 
     /**
-     *  ե४֥ȤΥ(W)
+     *  アクションフォームオブジェクトのアクセサ(W)
      *
      *  @access public
      */
@@ -179,10 +179,10 @@ class Ethna_Backend
     }
 
     /**
-     *  ¹Υ󥯥饹֥ȤΥ(R)
+     *  実行中のアクションクラスオブジェクトのアクセサ(R)
      *
      *  @access public
-     *  @return mixed   Ethna_ActionClass:󥯥饹 null:󥯥饹̤
+     *  @return mixed   Ethna_ActionClass:アクションクラス null:アクションクラス未定
      */
     function &getActionClass()
     {
@@ -190,7 +190,7 @@ class Ethna_Backend
     }
 
     /**
-     *  ¹Υ󥯥饹֥ȤΥ(W)
+     *  実行中のアクションクラスオブジェクトのアクセサ(W)
      *
      *  @access public
      */
@@ -201,10 +201,10 @@ class Ethna_Backend
     }
 
     /**
-     *  ֥ȤΥ(R)
+     *  ログオブジェクトのアクセサ(R)
      *
      *  @access public
-     *  @return object  Ethna_Logger    ֥
+     *  @return object  Ethna_Logger    ログオブジェクト
      */
     function &getLogger()
     {
@@ -212,10 +212,10 @@ class Ethna_Backend
     }
 
     /**
-     *  å󥪥֥ȤΥ(R)
+     *  セッションオブジェクトのアクセサ(R)
      *
      *  @access public
-     *  @return object  Ethna_Session   å󥪥֥
+     *  @return object  Ethna_Session   セッションオブジェクト
      */
     function &getSession()
     {
@@ -223,10 +223,10 @@ class Ethna_Backend
     }
 
     /**
-     *  ץ饰󥪥֥ȤΥ(R)
+     *  プラグインオブジェクトのアクセサ(R)
      *
      *  @access public
-     *  @return object  Ethna_Plugin    ץ饰󥪥֥
+     *  @return object  Ethna_Plugin    プラグインオブジェクト
      */
     function &getPlugin()
     {
@@ -234,10 +234,10 @@ class Ethna_Backend
     }
 
     /**
-     *  ޥ͡㥪֥ȤؤΥ(R)
+     *  マネージャオブジェクトへのアクセサ(R)
      *
      *  @access public
-     *  @return object  Ethna_AppManager    ޥ͡㥪֥
+     *  @return object  Ethna_AppManager    マネージャオブジェクト
      */
     function &getManager($type, $weak = false)
     {
@@ -246,10 +246,10 @@ class Ethna_Backend
     }
 
     /**
-     *  ֥ȤؤΥ(R)
+     *  オブジェクトへのアクセサ(R)
      *
      *  @access public
-     *  @return mixed   $keyб륪֥(or null)
+     *  @return mixed   $keyに対応するオブジェクト(or null)
      */
     function &getObject($key)
     {
@@ -260,10 +260,10 @@ class Ethna_Backend
     }
 
     /**
-     *  ץꥱΥ١ǥ쥯ȥ
+     *  アプリケーションのベースディレクトリを取得する
      *
      *  @access public
-     *  @return string  ١ǥ쥯ȥΥѥ̾
+     *  @return string  ベースディレクトリのパス名
      */
     function getBasedir()
     {
@@ -271,10 +271,10 @@ class Ethna_Backend
     }
 
     /**
-     *  ץꥱΥƥץ졼ȥǥ쥯ȥ
+     *  アプリケーションのテンプレートディレクトリを取得する
      *
      *  @access public
-     *  @return string  ƥץ졼ȥǥ쥯ȥΥѥ̾
+     *  @return string  テンプレートディレクトリのパス名
      */
     function getTemplatedir()
     {
@@ -282,10 +282,10 @@ class Ethna_Backend
     }
 
     /**
-     *  ץꥱǥ쥯ȥ
+     *  アプリケーションの設定ディレクトリを取得する
      *
      *  @access public
-     *  @return string  ǥ쥯ȥΥѥ̾
+     *  @return string  設定ディレクトリのパス名
      */
     function getEtcdir()
     {
@@ -293,10 +293,10 @@ class Ethna_Backend
     }
 
     /**
-     *  ץꥱΥƥݥǥ쥯ȥ
+     *  アプリケーションのテンポラリディレクトリを取得する
      *
      *  @access public
-     *  @return string  ƥݥǥ쥯ȥΥѥ̾
+     *  @return string  テンポラリディレクトリのパス名
      */
     function getTmpdir()
     {
@@ -304,10 +304,10 @@ class Ethna_Backend
     }
 
     /**
-     *  ץꥱΥƥץ졼ȥեĥҤ
+     *  アプリケーションのテンプレートファイル拡張子を取得する
      *
      *  @access public
-     *  @return string  ƥץ졼ȥեγĥ
+     *  @return string  テンプレートファイルの拡張子
      */
     function getTemplateext()
     {
@@ -315,11 +315,11 @@ class Ethna_Backend
     }
 
     /**
-     *  Ϥ
+     *  ログを出力する
      *
      *  @access public
-     *  @param  int     $level      ٥(LOG_DEBUG, LOG_NOTICE...)
-     *  @param  string  $message    å(printf)
+     *  @param  int     $level      ログレベル(LOG_DEBUG, LOG_NOTICE...)
+     *  @param  string  $message    ログメッセージ(printf形式)
      */
     function log($level, $message)
     {
@@ -332,11 +332,11 @@ class Ethna_Backend
     }
 
     /**
-     *  Хåɽ¹Ԥ
+     *  バックエンド処理を実行する
      *
      *  @access public
-     *  @param  string  $action_name    ¹Ԥ륢̾
-     *  @return mixed   (string):Forward̾(nullʤforwardʤ) Ethna_Error:顼
+     *  @param  string  $action_name    実行するアクションの名称
+     *  @return mixed   (string):Forward名(nullならforwardしない) Ethna_Error:エラー
      */
     function perform($action_name)
     {
@@ -346,7 +346,7 @@ class Ethna_Backend
         $this->action_class =& new $action_class_name($this);
         $this->ac =& $this->action_class;
 
-        // μ¹
+        // アクションの実行
         $forward_name = $this->ac->authenticate();
         if ($forward_name === false) {
             return null;
@@ -367,12 +367,12 @@ class Ethna_Backend
     }
 
     /**
-     *  DB֥Ȥ֤
+     *  DBオブジェクトを返す
      *
      *  @access public
-     *  @param  string  $db_key DB
-     *  @return mixed   Ethna_DB:DB֥ null:DSNʤ Ethna_Error:顼
-     *  @todo   newʤclass factoryѤ
+     *  @param  string  $db_key DBキー
+     *  @return mixed   Ethna_DB:DBオブジェクト null:DSN設定なし Ethna_Error:エラー
+     *  @todo   この中でnewしないでclass factoryを利用する
      */
     function &getDB($db_key = "")
     {
@@ -390,7 +390,7 @@ class Ethna_Backend
         $dsn = $this->controller->getDSN($db_key);
 
         if ($dsn == "") {
-            // DB³
+            // DB接続不要
             return $null;
         }
 
@@ -420,10 +420,10 @@ class Ethna_Backend
     }
 
     /**
-     *  DB֥()
+     *  DBオブジェクト(全て)を取得する
      *
      *  @access public
-     *  @return mixed   array:Ethna_DB֥Ȥΰ Ethan_Error:(줫İʾ³)顼
+     *  @return mixed   array:Ethna_DBオブジェクトの一覧 Ethan_Error:(いずれか一つ以上の接続で)エラー
      */
     function getDBList()
     {
@@ -448,7 +448,7 @@ class Ethna_Backend
     }
 
     /**
-     *  DBͥǤ
+     *  DBコネクションを切断する
      *
      *  @access public
      */
@@ -463,21 +463,21 @@ class Ethna_Backend
     }
 
     /**
-     *  ꤵ줿DBб(DB֥ȤǼ뤿)ѿ̾
+     *  指定されたDBキーに対応する(当該DBオブジェクトを格納するための)メンバ変数名を取得する
      *
-     *  ľ⤦פʤΤǤߴݻΤ˰ĤƤ֤Ǥ
-     *  (Ethna_AppManager饹ʤɤǡ$this->dbȤƤս꤬ʤ餺
-     *  Τ)
+     *  正直もう要らないのですが、後方互換性維持のために一応残してある状態です
+     *  (Ethna_AppManagerクラスなどで、$this->dbとかしている箇所が少なからずあ
+     *  るので)
      *
      *  @access private
-     *  @param  string  $db_key DB
-     *  @return mixed   string:ѿ̾ Ethna_Error:DB
+     *  @param  string  $db_key DBキー
+     *  @return mixed   string:メンバ変数名 Ethna_Error:不正なDB種別
      */
     function &_getDBVarname($db_key = "")
     {
         $r = $this->controller->getDBType($db_key);
         if (is_null($r)) {
-            return Ethna::raiseError("̤DB[%s]", E_DB_INVALIDTYPE, $db_key);
+            return Ethna::raiseError("Undefined DB Type [%s]", E_DB_INVALIDTYPE, $db_key);
         }
 
         if ($db_key == "") {
