@@ -6,16 +6,16 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_ClassFactory.php 432 2006-11-28 04:52:54Z ichii386 $
+ *  @version    $Id$
  */
 
 // {{{ Ethna_ClassFactory
 /**
- *  Ethnaե졼Υ֥ȥ
+ *  Ethnaフレームワークのオブジェクト生成ゲートウェイ
  *
- *  DIƥʤȤȤͤޤEthnaǤϤ٤ñʤΤ
- *  αƤޤץꥱ٥DIϥե륿
- *  ȤäƼ¸뤳Ȥޤ
+ *  DIコンテナか、ということも考えましたがEthnaではこの程度の単純なものに
+ *  留めておきます。アプリケーションレベルDIしたい場合はフィルタチェインを
+ *  使って実現することも出来ます。
  *
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @access     public
@@ -27,33 +27,33 @@ class Ethna_ClassFactory
      *  @access private
      */
 
-    /** @var    object  Ethna_Controller    controller֥ */
+    /** @var    object  Ethna_Controller    controllerオブジェクト */
     var $controller;
 
-    /** @var    object  Ethna_Controller    controller֥(ά) */
+    /** @var    object  Ethna_Controller    controllerオブジェクト(省略形) */
     var $ctl;
     
-    /** @var    array   饹 */
+    /** @var    array   クラス定義 */
     var $class = array();
 
-    /** @var    array   Ѥߥ֥ȥå */
+    /** @var    array   生成済みオブジェクトキャッシュ */
     var $object = array();
 
-    /** @var    array   Ѥߥץꥱޥ͡㥪֥ȥå */
+    /** @var    array   生成済みアプリケーションマネージャオブジェクトキャッシュ */
     var $manager = array();
 
-    /** @var    array   ᥽åɰå */
+    /** @var    array   メソッド一覧キャッシュ */
     var $method_list = array();
 
     /**#@-*/
 
 
     /**
-     *  Ethna_ClassFactory饹Υ󥹥ȥ饯
+     *  Ethna_ClassFactoryクラスのコンストラクタ
      *
      *  @access public
-     *  @param  object  Ethna_Controller    &$controller    controller֥
-     *  @param  array                       $class          饹
+     *  @param  object  Ethna_Controller    &$controller    controllerオブジェクト
+     *  @param  array                       $class          クラス定義
      */
     function Ethna_ClassFactory(&$controller, $class)
     {
@@ -63,29 +63,38 @@ class Ethna_ClassFactory
     }
 
     /**
-     *  typeб륢ץꥱޥ͡㥪֥Ȥ֤
+     *  typeに対応するアプリケーションマネージャオブジェクトを返す
+     *  注意： typeは大文字小文字を区別しない
+     *         (PHP自体が、クラス名の大文字小文字を区別しないため)
      *
      *  @access public
-     *  @return object  Ethna_AppManager    ޥ͡㥪֥
+     *  @param  string  $type   アプリケーションマネージャー名
+     *  @param  bool    $weak   オブジェクトが未生成の場合の強制生成フラグ(default: false)
+     *  @return object  Ethna_AppManager    マネージャオブジェクト
      */
     function &getManager($type, $weak = false)
     {
         $obj = null;
 
-        // check if object class exists
+        //  すでにincludeされていなければ、includeを試みる
+        //  ここで返されるクラス名は、AppObjectの命名規約によるもの
+        //
+        //  これは、AppObject のファイル中にAppManagerが含まれる場合が
+        //  あるため必要なルーチンである
         $obj_class_name = $this->controller->getObjectClassName($type);
         if (class_exists($obj_class_name) === false) {
-            // try include.
             $this->_include($obj_class_name);
         }
 
-        // check if manager class exists
+        //  すでにincludeされていなければ、includeを試みる
+        //  ここで返されるクラス名は、AppManagerの命名規約によるもの
         $class_name = $this->controller->getManagerClassName($type);
         if (class_exists($class_name) === false
             && $this->_include($class_name) === false) {
-            return $obj;
+            return $obj;  //  include 失敗。戻り値はNULL。
         }
 
+        //  メソッド情報を集める 
         if (isset($this->method_list[$class_name]) == false) {
             $this->method_list[$class_name] = get_class_methods($class_name);
             for ($i = 0; $i < count($this->method_list[$class_name]); $i++) {
@@ -93,21 +102,33 @@ class Ethna_ClassFactory
             }
         }
 
-        // see if this should be singlton or not
+        //  PHPのクラス名は大文字小文字を区別しないので、
+        //  同じクラス名と見做されるものを指定した場合には
+        //  同じインスタンスが返るようにする
+        $type = strtolower($type);
+
+        //  以下のルールに従って、キャッシュが利用可能かを判定する
+        //  利用可能と判断した場合、キャッシュされていればそれを返す
+        //
+        //  1. メソッドに getInstance があればキャッシュを利用可能と判断する
+        //     この場合、シングルトンかどうかは getInstance 次第
+        //  2. weak が true であれば、キャッシュは利用不能と判断してオブジェクトを再生成
+        //  3. weak が false であれば、キャッシュは利用可能と判断する(デフォルト) 
         if ($this->_isCacheAvailable($class_name, $this->method_list[$class_name], $weak)) {
             if (isset($this->manager[$type]) && is_object($this->manager[$type])) {
                 return $this->manager[$type];
             }
         }
 
-        // see if we have helper methods
+        //  インスタンス化のヘルパ(getInstance)があればそれを使う
         if (in_array("getinstance", $this->method_list[$class_name])) {
-            $obj =& call_user_func(array($class_name, 'getInstance'));
+            $obj = call_user_func(array($class_name, 'getInstance'));
         } else {
             $backend =& $this->controller->getBackend();
             $obj =& new $class_name($backend);
         }
 
+        //  生成したオブジェクトはとりあえずキャッシュする
         if (isset($this->manager[$type]) == false || is_object($this->manager[$type]) == false) {
             $this->manager[$type] =& $obj;
         }
@@ -116,12 +137,15 @@ class Ethna_ClassFactory
     }
 
     /**
-     *  饹б륪֥Ȥ֤/饹̤ξAppObjectõ
+     *  クラスキーに対応するオブジェクトを返す/クラスキーが未定義の場合はAppObjectを探す
+     *  クラスキーとは、[Appid]_Controller#class に定められたもの。
      *
      *  @access public
-     *  @param  string  $key    饹
-     *  @param  bool    $weak   ֥Ȥ̤ξζե饰(default: false)
-     *  @return object  줿֥(顼ʤnull)
+     *  @param  string  $key    [Appid]_Controller#class に定められたクラスキー
+     *                          このキーは大文字小文字を区別する 
+     *                          (配列のキーとして使われているため)
+     *  @param  bool    $ext    オブジェクトが未生成の場合の強制生成フラグ(default: false)
+     *  @return object  生成されたオブジェクト(エラーならnull)
      */
     function &getObject($key, $ext = false)
     {
@@ -140,20 +164,23 @@ class Ethna_ClassFactory
             list($weak) = $ext;
         }
 
-        // try to include if not defined
+        //  すでにincludeされていなければ、includeを試みる
         if (class_exists($class_name) == false) {
             if ($this->_include($class_name) == false) {
-                return $object;
+                return $object;  //  include 失敗。返り値はnull
             }
         }
 
-        // handle app object first
+        //  AppObject をはじめに扱う 
+        //  AppObject はキャッシュされないことに注意
         if (isset($this->class[$key]) == false) {
             $backend =& $this->controller->getBackend();
             $object =& new $class_name($backend, $key_type, $key_value, $prop);
             return $object;
         }
 
+        //  Ethna_Controllerで定義されたクラスキーの場合
+        //  はメソッド情報を集める 
         if (isset($this->method_list[$class_name]) == false) {
             $this->method_list[$class_name] = get_class_methods($class_name);
             for ($i = 0; $i < count($this->method_list[$class_name]); $i++) {
@@ -161,23 +188,31 @@ class Ethna_ClassFactory
             }
         }
 
-        // see if this should be singlton or not
+        //  以下のルールに従って、キャッシュが利用可能かを判定する
+        //  利用可能と判断した場合、キャッシュされていればそれを返す
+        //
+        //  1. メソッドに getInstance があればキャッシュを利用可能と判断する
+        //     この場合、シングルトンかどうかは getInstance 次第
+        //  2. weak が true であれば、キャッシュは利用不能と判断してオブジェクトを再生成
+        //  3. weak が false であれば、キャッシュは利用可能と判断する(デフォルト) 
         if ($this->_isCacheAvailable($class_name, $this->method_list[$class_name], $weak)) {
             if (isset($this->object[$key]) && is_object($this->object[$key])) {
                 return $this->object[$key];
             }
         }
 
-        // see if we have helper methods
+        //  インスタンス化のヘルパがあればそれを使う
         $method = sprintf('_getObject_%s', ucfirst($key));
         if (method_exists($this, $method)) {
             $object =& $this->$method($class_name);
         } else if (in_array("getinstance", $this->method_list[$class_name])) {
-            $object =& call_user_func(array($class_name, 'getInstance'));
+            $object = call_user_func(array($class_name, 'getInstance'));
         } else {
             $object =& new $class_name();
         }
 
+        //  クラスキーに定められたクラスのインスタンスは
+        //  とりあえずキャッシュする
         if (isset($this->object[$key]) == false || is_object($this->object[$key]) == false) {
             $this->object[$key] =& $object;
         }
@@ -186,11 +221,11 @@ class Ethna_ClassFactory
     }
 
     /**
-     *  饹б륯饹֤̾
+     *  クラスキーに対応するクラス名を返す
      *
      *  @access public
-     *  @param  string  $key    饹
-     *  @return string  饹̾
+     *  @param  string  $key    クラスキー
+     *  @return string  クラス名
      */
     function getObjectName($key)
     {
@@ -202,11 +237,11 @@ class Ethna_ClassFactory
     }
 
     /**
-     *  ֥᥽å(backend)
+     *  オブジェクト生成メソッド(backend)
      *
      *  @access protected
-     *  @param  string  $class_name     饹̾
-     *  @return object  줿֥(顼ʤnull)
+     *  @param  string  $class_name     クラス名
+     *  @return object  生成されたオブジェクト(エラーならnull)
      */
     function &_getObject_Backend($class_name)
     {
@@ -215,11 +250,11 @@ class Ethna_ClassFactory
     }
 
     /**
-     *  ֥᥽å(config)
+     *  オブジェクト生成メソッド(config)
      *
      *  @access protected
-     *  @param  string  $class_name     饹̾
-     *  @return object  줿֥(顼ʤnull)
+     *  @param  string  $class_name     クラス名
+     *  @return object  生成されたオブジェクト(エラーならnull)
      */
     function &_getObject_Config($class_name)
     {
@@ -228,11 +263,11 @@ class Ethna_ClassFactory
     }
 
     /**
-     *  ֥᥽å(i18n)
+     *  オブジェクト生成メソッド(i18n)
      *
      *  @access protected
-     *  @param  string  $class_name     饹̾
-     *  @return object  줿֥(顼ʤnull)
+     *  @param  string  $class_name     クラス名
+     *  @return object  生成されたオブジェクト(エラーならnull)
      */
     function &_getObject_I18n($class_name)
     {
@@ -241,11 +276,11 @@ class Ethna_ClassFactory
     }
 
     /**
-     *  ֥᥽å(logger)
+     *  オブジェクト生成メソッド(logger)
      *
      *  @access protected
-     *  @param  string  $class_name     饹̾
-     *  @return object  줿֥(顼ʤnull)
+     *  @param  string  $class_name     クラス名
+     *  @return object  生成されたオブジェクト(エラーならnull)
      */
     function &_getObject_Logger($class_name)
     {
@@ -254,11 +289,11 @@ class Ethna_ClassFactory
     }
 
     /**
-     *  ֥᥽å(plugin)
+     *  オブジェクト生成メソッド(plugin)
      *
      *  @access protected
-     *  @param  string  $class_name     饹̾
-     *  @return object  줿֥(顼ʤnull)
+     *  @param  string  $class_name     クラス名
+     *  @return object  生成されたオブジェクト(エラーならnull)
      */
     function &_getObject_Plugin($class_name)
     {
@@ -267,11 +302,11 @@ class Ethna_ClassFactory
     }
 
     /**
-     *  ֥᥽å(renderer)
+     *  オブジェクト生成メソッド(renderer)
      *
      *  @access protected
-     *  @param  string  $class_name     饹̾
-     *  @return object  줿֥(顼ʤnull)
+     *  @param  string  $class_name     クラス名
+     *  @return object  生成されたオブジェクト(エラーならnull)
      */
     function &_getObject_Renderer($class_name)
     {
@@ -280,11 +315,11 @@ class Ethna_ClassFactory
     }
 
     /**
-     *  ֥᥽å(session)
+     *  オブジェクト生成メソッド(session)
      *
      *  @access protected
-     *  @param  string  $class_name     饹̾
-     *  @return object  줿֥(顼ʤnull)
+     *  @param  string  $class_name     クラス名
+     *  @return object  生成されたオブジェクト(エラーならnull)
      */
     function &_getObject_Session($class_name)
     {
@@ -293,11 +328,11 @@ class Ethna_ClassFactory
     }
 
     /**
-     *  ֥᥽å(sql)
+     *  オブジェクト生成メソッド(sql)
      *
      *  @access protected
-     *  @param  string  $class_name     饹̾
-     *  @return object  줿֥(顼ʤnull)
+     *  @param  string  $class_name     クラス名
+     *  @return object  生成されたオブジェクト(エラーならnull)
      */
     function &_getObject_Sql($class_name)
     {
@@ -306,7 +341,7 @@ class Ethna_ClassFactory
     }
 
     /**
-     *  ꤵ줿饹ꤵեinclude
+     *  指定されたクラスから想定されるファイルをincludeする
      *
      *  @access protected
      */
@@ -366,7 +401,7 @@ class Ethna_ClassFactory
     }
 
     /**
-     *  ꤵ줿饹åѲǽɤå
+     *  指定されたクラスがキャッシュを利用可能かどうかをチェックする
      *
      *  @access protected
      */
