@@ -6,21 +6,22 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Error.php 394 2006-11-09 01:05:55Z halt1983 $
+ *  @version    $Id$
  */
 
 // {{{ ethna_error_handler
 /**
- *  顼Хåؿ
+ *  エラーコールバック関数
  *
- *  @param  int     $errno      顼٥
- *  @param  string  $errstr     顼å
- *  @param  string  $errfile    顼ȯսΥե̾
- *  @param  string  $errline    顼ȯսιֹ
+ *  @param  int     $errno      エラーレベル
+ *  @param  string  $errstr     エラーメッセージ
+ *  @param  string  $errfile    エラー発生箇所のファイル名
+ *  @param  string  $errline    エラー発生箇所の行番号
  */
 function ethna_error_handler($errno, $errstr, $errfile, $errline)
 {
-    if ($errno === E_STRICT || ($errno & error_reporting()) === 0) {
+    if ($errno === E_STRICT || $errno === E_DEPRECATED
+    || ($errno & error_reporting()) === 0) {
         return;
     }
 
@@ -40,6 +41,8 @@ function ethna_error_handler($errno, $errstr, $errfile, $errline)
         $php_errno = 'Parse error'; break;
     case E_NOTICE:
     case E_USER_NOTICE:
+    case E_STRICT:
+    case E_DEPRECATED:
         $php_errno = 'Notice'; break;
     default:
         $php_errno = 'Unknown error'; break;
@@ -87,36 +90,59 @@ function ethna_error_handler($errno, $errstr, $errfile, $errline)
 set_error_handler('ethna_error_handler');
 // }}}
 
+// {{{ ethna_exception_handler
+    //  TODO: Implement ethna_exception_handler function.
+// }}}
+
 // {{{ Ethna_Error
 /**
- *  顼饹
+ *  エラークラス
  *
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @access     public
  *  @package    Ethna
  */
-class Ethna_Error extends PEAR_Error
+class Ethna_Error
 {
     /**#@+
      *  @access private
      */
 
-    /** @var    object  Ethna_I18N  i18n֥ */
+    /** @var    object  Ethna_I18N  i18nオブジェクト */
     var $i18n;
 
-    /** @var    object  Ethna_Logger    logger֥ */
+    /** @var    object  Ethna_Logger    loggerオブジェクト */
     var $logger;
 
+    /** @var    string  エラーメッセージ */
+    var $message;
+
+    /** @var    integer エラーコード */
+    var $code;
+
+    /** @var    integer エラーモード */
+    var $mode;
+    
+    /** @var    array   エラーモード依存のオプション */
+    var $options;
+
+    /** @var    string  ユーザー定義もしくはデバッグ関連の追加情報を記した文字列。 */
+    var $userinfo;
+
     /**#@-*/
 
     /**
-     *  Ethna_Error饹Υ󥹥ȥ饯
+     *  Ethna_Errorクラスのコンストラクタ
+     *  $userinfo は第5引数に設定すること。 
      *
      *  @access public
-     *  @param  int     $level              顼٥
-     *  @param  string  $message            顼å
-     *  @param  int     $code               顼
-     *  @param  array   $userinfo           顼ɲþ(顼ɰʹߤƤΰ)
+     *  @param  string  $message            エラーメッセージ
+     *  @param  int     $code               エラーコード
+     *  @param  int     $mode               エラーモード(Ethna_Errorはコールバックを
+     *                                      常に使用するので実質無視される)
+     *  @param  array   $options            エラーモード依存のオプション
+     *  @param  array   $userinfo           エラー追加情報($options より後の全ての引数)
+     *  @see http://pear.php.net/manual/ja/core.pear.pear-error.pear-error.php
      */
     function Ethna_Error($message = null, $code = null, $mode = null, $options = null)
     {
@@ -125,40 +151,57 @@ class Ethna_Error extends PEAR_Error
             $this->i18n =& $controller->getI18N();
         }
 
-        // $optionsʹߤΰ->$userinfo
+        // $options 以降の引数 -> $userinfo
         if (func_num_args() > 4) {
             $userinfo = array_slice(func_get_args(), 4);
             if (count($userinfo) == 1) {
                 if (is_array($userinfo[0])) {
-                    $userinfo = $userinfo[0];
+                    $this->userinfo = $userinfo[0];
                 } else if (is_null($userinfo[0])) {
-                    $userinfo = array();
+                    $this->userinfo = array();
                 }
+            } else {
+                $this->userinfo = $userinfo[0];
             }
         } else {
-            $userinfo = array();
+            $this->userinfo = array();
         }
 
-        // å
+        // メッセージ補正処理 ($message)
         if (is_null($message)) {
-            // $codeå
+            // $codeからメッセージを取得する
             $message = $controller->getErrorMessage($code);
             if (is_null($message)) {
                 $message = 'unknown error';
             }
         }
+        $this->message = $message;
 
-        parent::PEAR_Error($message, $code, $mode, $options, $userinfo);
+        //  その他メンバ変数設定
+        $this->code = $code;
+        $this->mode = $mode;
+        $this->options = $options; 
+        $this->level = ($this->options === NULL) ? E_USER_NOTICE : $options;
 
-        // Ethnaե졼Υ顼ϥɥ(PEAR_ErrorΥХåȤϰۤʤ)
+        //  Ethnaフレームワークのエラーハンドラ(callback)
         Ethna::handleError($this);
     }
 
     /**
-     *  levelؤΥ(R)
+     * エラーオブジェクトに関連付けられたエラーコードを返します。
+     *
+     * @return integer - エラー番号
+     */
+    function getCode()
+    {
+        return $this->code;
+    }
+
+    /**
+     *  levelへのアクセサ(R)
      *
      *  @access public
-     *  @return int     顼٥
+     *  @return int     エラーレベル
      */
     function getLevel()
     {
@@ -166,14 +209,14 @@ class Ethna_Error extends PEAR_Error
     }
 
     /**
-     *  messageؤΥ(R)
+     *  messageへのアクセサ(R)
      *
-     *  PEAR_Error::getMessage()򥪡С饤ɤưʲνԤ
-     *  - 顼åi18n
-     *  - $userinfoȤϤ줿ǡˤvsprintf()
+     *  以下の処理を行う
+     *  - エラーメッセージのi18n処理
+     *  - $userinfoとして渡されたデータによるvsprintf()処理
      *
      *  @access public
-     *  @return string  顼å
+     *  @return string  エラーメッセージ
      */
     function getMessage()
     {
@@ -187,14 +230,13 @@ class Ethna_Error extends PEAR_Error
     }
 
     /**
-     *  顼ɲþؤΥ(R)
+     *  エラー追加情報へのアクセサ(R)
      *
-     *  PEAR_Error::getUserInfo()򥪡С饤ɤơθġ
-     *  ȥؤΥ򥵥ݡ
+     *  エラー追加情報配列の個々のエントリへのアクセスをサポート
      *
      *  @access public
-     *  @param  int     $n      顼ɲþΥǥå(ά)
-     *  @return mixed   message
+     *  @param  int     $n      エラー追加情報のインデックス(省略可)
+     *  @return mixed   message引数
      */
     function getUserInfo($n = null)
     {
@@ -210,12 +252,10 @@ class Ethna_Error extends PEAR_Error
     }
 
     /**
-     *  顼ɲþؤΥ(W)
-     *
-     *  PEAR_Error::addUserInfo()򥪡С饤
+     *  エラー追加情報へのアクセサ(W)
      *
      *  @access public
-     *  @param  string  $info   ɲä륨顼
+     *  @param  string  $info   追加するエラー情報
      */
     function addUserInfo($info)
     {
@@ -223,4 +263,5 @@ class Ethna_Error extends PEAR_Error
     }
 }
 // }}}
+
 ?>
