@@ -6,12 +6,12 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_InfoManager.php 723 2009-02-05 16:36:07Z mumumu-org $
+ *  @version    $Id$
  */
 
 // {{{ Ethna_InfoManager
 /**
- *  Ethnaޥ͡㥯饹
+ *  Ethnaマネージャクラス
  *
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @access     public
@@ -23,64 +23,71 @@ class Ethna_InfoManager extends Ethna_AppManager
      *  @access private
      */
     
-    /** @var    object  Ethna_Controller    ȥ饪֥ */
+    /** @var    object  Ethna_Controller    コントローラオブジェクト */
     var $ctl;
 
-    /** @var    object  Ethna_ClassFactory  饹եȥꥪ֥ */
+    /** @var    object  Ethna_ClassFactory  クラスファクトリオブジェクト */
     var $class_factory;
 
-    /** @var    array   󥹥ץȲϷ̥åե */
+    /** @var    array   アクションスクリプト解析結果キャッシュファイル */
     var $cache_class_list_file;
 
-    /** @var    array   󥹥ץȲϷ̥å */
+    /** @var    array   アクションスクリプト解析結果キャッシュ */
     var $cache_class_list;
 
-    /** @var    array   [°]DBװ */
+    /** @var    array   [属性]DBタイプ一覧 */
     var $db_type_list = array(
         DB_TYPE_RW      => array('name' => 'DB_TYPE_RW'),
         DB_TYPE_RO      => array('name' => 'DB_TYPE_RO'),
         DB_TYPE_MISC    => array('name' => 'DB_TYPE_MISC'),
     );
 
-    /** @var    array   [°]ե෿ */
-    var $form_type_list = array(
-        FORM_TYPE_TEXT      => array('name' => 'ƥȥܥå'),
-        FORM_TYPE_PASSWORD  => array('name' => 'ѥ'),
-        FORM_TYPE_TEXTAREA  => array('name' => 'ƥȥꥢ'),
-        FORM_TYPE_SELECT    => array('name' => '쥯ȥܥå'),
-        FORM_TYPE_RADIO     => array('name' => '饸ܥ'),
-        FORM_TYPE_CHECKBOX  => array('name' => 'åܥå'),
-        FORM_TYPE_SUBMIT    => array('name' => 'եܥ'),
-        FORM_TYPE_FILE      => array('name' => 'ե'),
-    );
-
-    /** @var    array   [°]ѿ */
-    var $var_type_list = array(
-        VAR_TYPE_INT        => array('name' => ''),
-        VAR_TYPE_FLOAT      => array('name' => 'ư'),
-        VAR_TYPE_STRING     => array('name' => 'ʸ'),
-        VAR_TYPE_DATETIME   => array('name' => ''),
-        VAR_TYPE_BOOLEAN    => array('name' => ''),
-        VAR_TYPE_FILE       => array('name' => 'ե'),
-    );
+    /** @var    array   [属性]フォーム型一覧 */
+    var $form_type_list;
+ 
+    /** @var    array   [属性]変数型一覧 */
+    var $var_type_list;
 
     /**#@-*/
 
     /**
-     *  Ethna_InfoManagerΥ󥹥ȥ饯
+     *  Ethna_InfoManagerのコンストラクタ
      *
      *  @access public
-     *  @param  object  Ethna_Backend   &$backend   Ethna_Backend֥
+     *  @param  object  Ethna_Backend   &$backend   Ethna_Backendオブジェクト
      */
     function Ethna_InfoManager(&$backend)
     {
+        $this->form_type_list = array(
+                                    FORM_TYPE_TEXT => array('name' => _et('TextBox')),
+                                    FORM_TYPE_PASSWORD  => array('name' => _et('Password')),
+                                    FORM_TYPE_TEXTAREA  => array('name' => _et('TextArea')),
+                                    FORM_TYPE_SELECT    => array('name' => _et('SelectBox')),
+                                    FORM_TYPE_RADIO     => array('name' => _et('RadioButton')),
+                                    FORM_TYPE_CHECKBOX  => array('name' => _et('CheckBox')),
+                                    FORM_TYPE_SUBMIT    => array('name' => _et('SubmitButton')),
+                                    FORM_TYPE_FILE      => array('name' => _et('File')),
+                                );
+
+        $this->var_type_list = array(
+                                    VAR_TYPE_INT        => array('name' => _et('Integer')),
+                                    VAR_TYPE_FLOAT      => array('name' => _et('Float')),
+                                    VAR_TYPE_STRING     => array('name' => _et('String')),
+                                    VAR_TYPE_DATETIME   => array('name' => _et('Datetime')),
+                                    VAR_TYPE_BOOLEAN    => array('name' => _et('Boolean')),
+                                    VAR_TYPE_FILE       => array('name' => _et('File')),
+                               );
+
         parent::Ethna_AppManager($backend);
         $this->ctl =& Ethna_Controller::getInstance();
         $this->class_factory =& $this->ctl->getClassFactory();
 
-        // 󥹥ץȲϷ̥å
-        $this->cache_class_list_file = sprintf('%s/ethna_info_class_list', $this->ctl->getDirectory('tmp'));
-        if (file_exists($this->cache_class_list_file) && filesize($this->cache_class_list_file) > 0) {
+        // アクションスクリプト解析結果キャッシュ取得
+        $this->cache_class_list_file = sprintf('%s/ethna_info_class_list',
+                                               $this->ctl->getDirectory('tmp')
+                                       );
+        if (file_exists($this->cache_class_list_file)
+         && filesize($this->cache_class_list_file) > 0) {
             $fp = fopen($this->cache_class_list_file, 'r');
             $s = fread($fp, filesize($this->cache_class_list_file));
             fclose($fp);
@@ -89,50 +96,50 @@ class Ethna_InfoManager extends Ethna_AppManager
     }
 
     /**
-     *  Ѥߥ
+     *  定義済みアクション一覧を取得する
      *
      *  @access public
-     *  @return array   
+     *  @return array   アクション一覧
      */
     function getActionList()
     {
         $r = array();
 
-        // 󥹥ץȤϤ
+        // アクションスクリプトを解析する
         $class_list = $this->_analyzeActionList();
 
-        // ȥ
+        // アクション定義エントリ一覧
         list($manifest_action_list, $manifest_class_list) = $this->_getActionList_Manifest($class_list);
 
-        // άȥ
+        // アクション定義省略エントリ一覧
         $implicit_action_list = $this->_getActionList_Implicit($class_list, $manifest_action_list, $manifest_class_list);
 
         $r = array_merge($manifest_action_list, $implicit_action_list);
         ksort($r);
 
-        // 䴰
+        // アクション定義情報補完
         $r = $this->_addActionList($r);
 
         return $r;
     }
 
     /**
-     *  Ѥ
+     *  定義済み遷移先一覧を取得する
      *
      *  @access public
-     *  @return array   
+     *  @return array   遷移先一覧
      */
     function getForwardList()
     {
         $r = array();
 
-        // ƥץ졼/ӥ塼ץȤϤ
+        // テンプレート/ビュースクリプトを解析する
         $forward_list = $this->_analyzeForwardList();
 
-        // ӥ塼ȥ
+        // ビュー定義エントリ一覧
         $manifest_forward_list = $this->_getForwardList_Manifest();
 
-        // ӥ塼άȥ
+        // ビュー定義省略エントリ一覧
         $implicit_forward_list = $this->_getForwardList_Implicit($forward_list, $manifest_forward_list);
 
         $r = array_merge($manifest_forward_list, $implicit_forward_list);
@@ -142,11 +149,11 @@ class Ethna_InfoManager extends Ethna_AppManager
     }
 
     /**
-     *  ǥ쥯ȥʲΥ󥹥ץȤϤ
+     *  ディレクトリ以下のアクションスクリプトを解析する
      *
      *  @access private
-     *  @param  string  $action_dir     оݤΥǥ쥯ȥ
-     *  @return array   󥯥饹
+     *  @param  string  $action_dir     解析対象のディレクトリ
+     *  @return array   アクションクラス定義一覧
      */
     function _analyzeActionList($action_dir = null)
     {
@@ -184,7 +191,7 @@ class Ethna_InfoManager extends Ethna_AppManager
 
             $key = substr($file, $prefix_len);
             
-            // åå
+            // キャッシュチェック
             include_once $file;
             if ($this->cache_class_list[$key]['.mtime'] >= filemtime($file)) {
                 $class_list = $this->cache_class_list[$key];
@@ -204,7 +211,7 @@ class Ethna_InfoManager extends Ethna_AppManager
         }
 
         if ($cache_update) {
-            // åե빹
+            // キャッシュファイル更新
             $fp = fopen($this->cache_class_list_file, 'w');
             fwrite($fp, serialize($r));
             fclose($fp);
@@ -214,11 +221,11 @@ class Ethna_InfoManager extends Ethna_AppManager
     }
 
     /**
-     *  󥹥ץȤϤ
+     *  アクションスクリプトを解析する
      *
      *  @access private
-     *  @param  string  $script ե̾
-     *  @return array   󥯥饹
+     *  @param  string  $script ファイル名
+     *  @return array   アクションクラス定義一覧
      */
     function _analyzeActionScript($script)
     {
@@ -235,7 +242,7 @@ class Ethna_InfoManager extends Ethna_AppManager
         }
         fclose($fp);
 
-        // ȡʬ䤷ƥ饹
+        // トークンに分割してクラス定義情報を取得
         $token_list = token_get_all($source);
         $state = 'T_OUT';
         $nest = 0;
@@ -261,7 +268,7 @@ class Ethna_InfoManager extends Ethna_AppManager
             }
 
             if ($token[0] == T_CLASS) {
-                // 饹
+                // クラス定義開始
                 $i += 2;
                 $class_name = $token_list[$i][1];       // should be T_STRING
                 if ($this->_isSubclassOf($class_name, 'Ethna_ActionClass')) {
@@ -305,12 +312,12 @@ class Ethna_InfoManager extends Ethna_AppManager
     }
 
     /**
-     *  ꤵ줿饹̾ѾƤ뤫ɤ֤
+     *  指定されたクラス名を継承しているかどうかを返す
      *
      *  @access private
-     *  @param  string  $class_name     åоݤΥ饹̾
-     *  @param  string  $parent_name    ƥ饹̾
-     *  @return bool    true:ѾƤ false:ʤ
+     *  @param  string  $class_name     チェック対象のクラス名
+     *  @param  string  $parent_name    親クラス名
+     *  @return bool    true:継承している false:いない
      */
     function _isSubclassOf($class_name, $parent_name)
     {
@@ -324,11 +331,11 @@ class Ethna_InfoManager extends Ethna_AppManager
     }
 
     /**
-     *  ȥŪƤ륢
+     *  コントローラに明示的に定義されているアクション一覧を取得する
      *
      *  @access private
-     *  @param  array   Ƥ륯饹
-     *  @return array   array(, 饹)
+     *  @param  array   定義されているクラス一覧
+     *  @return array   array(アクション一覧, クラス一覧)
      */
     function _getActionList_Manifest($class_list)
     {
@@ -341,7 +348,7 @@ class Ethna_InfoManager extends Ethna_AppManager
             $action = $this->ctl->_getAction($action_name);
 
             $elt = array();
-            // _analyzeActionList()Ǽ饹ǡбط
+            // _analyzeActionList()で取得したクラス定義データから対応関係を取得
             foreach ($class_list as $file => $elts) {
                 foreach ($elts as $class_name => $def) {
                     if ($def['type'] == 'action_class' && strcasecmp($class_name, $action['class_name']) == 0) {
@@ -356,7 +363,7 @@ class Ethna_InfoManager extends Ethna_AppManager
                 }
             }
 
-            // ̤å
+            // 未定義チェック
             if (isset($elt['action_class']) == false) {
                 $elt['action_class'] = $action['class_name'];
                 if (class_exists($action['class_name']) == false) {
@@ -377,13 +384,13 @@ class Ethna_InfoManager extends Ethna_AppManager
     }
 
     /**
-     *  ۤƤ륢
+     *  暗黙に定義されているアクション一覧を取得する
      *
      *  @access private
-     *  @param  array   $class_list             Ƥ륯饹
-     *  @param  array   $manifest_action_list   ŪѤߤΥ
-     *  @param  array   $manifest_class_list    ŪѤߤΥ饹
-     *  @return array   array:
+     *  @param  array   $class_list             定義されているクラス一覧
+     *  @param  array   $manifest_action_list   明示的に定義済みのアクション一覧
+     *  @param  array   $manifest_class_list    明示的に定義済みのクラス一覧
+     *  @return array   array:アクション一覧
      */
     function _getActionList_Implicit($class_list, $manifest_action_list, $manifest_class_list)
     {
@@ -395,7 +402,7 @@ class Ethna_InfoManager extends Ethna_AppManager
                     continue;
                 }
 
-                // 饹̾饢̾
+                // クラス名からアクション名を取得
                 if ($def['type'] == 'action_class') {
                     $action_name = $this->ctl->actionClassToName($class_name);
                     if (array_key_exists($action_name, $manifest_action_list)) {
@@ -422,16 +429,16 @@ class Ethna_InfoManager extends Ethna_AppManager
     }
     
     /**
-     *  䴰
+     *  アクション定義一覧を補完する
      *
      *  @access private
-     *  @param  array   $action_list    
-     *  @return array   Υ
+     *  @param  array   $action_list    取得したアクション一覧
+     *  @return array   修正後のアクション一覧
      */
     function _addActionList($action_list)
     {
         foreach ($action_list as $action_name => $action) {
-            // ե˥եɲ
+            // アクションフォームにフォーム定義情報を追加
             $form_name = $action['action_form'];
             if (class_exists($form_name) == false) {
                 continue;
@@ -447,7 +454,8 @@ class Ethna_InfoManager extends Ethna_AppManager
                 $form[$name]['filter'] = str_replace(",", "\n", $def['filter']);
                 $form[$name]['form_type'] = $this->getAttrName('form_type', $def['form_type']);
                 $form[$name]['type_is_array'] = is_array($def['type']);
-                $form[$name]['type'] = $this->getAttrName('var_type', is_array($def['type']) ? $def['type'][0] : $def['type']);
+                $form[$name]['type'] = $this->getAttrName('var_type', is_array($def['type'])
+                                     ? $def['type'][0] : $def['type']);
             }
             $action['action_form_info']['form'] = $form;
             $action_list[$action_name] = $action;
@@ -457,11 +465,11 @@ class Ethna_InfoManager extends Ethna_AppManager
     }
 
     /**
-     *  ǥ쥯ȥʲΥƥץ졼ȤϤ
+     *  ディレクトリ以下のテンプレートを解析する
      *
      *  @access private
-     *  @param  string  $action_dir     оݤΥǥ쥯ȥ
-     *  @return array   
+     *  @param  string  $action_dir     解析対象のディレクトリ
+     *  @return array   遷移定義一覧
      */
     function _analyzeForwardList($template_dir = null)
     {
@@ -510,10 +518,10 @@ class Ethna_InfoManager extends Ethna_AppManager
     }
 
     /**
-     *  ȥŪƤ
+     *  コントローラに明示的に定義されている遷移先一覧を取得する
      *
      *  @access private
-     *  @return array   ӥ塼
+     *  @return array   ビュー一覧
      */
     function _getForwardList_Manifest()
     {
@@ -558,12 +566,12 @@ class Ethna_InfoManager extends Ethna_AppManager
     }
 
     /**
-     *  ۤƤӥ塼
+     *  暗黙に定義されているビュー一覧を取得する
      *
      *  @access private
-     *  @param  array   $forward_list           Ƥ̾
-     *  @param  array   $manifest_forward_list  ŪѤߤΥӥ塼
-     *  @return array   array:ӥ塼
+     *  @param  array   $forward_list           定義されている遷移名一覧
+     *  @param  array   $manifest_forward_list  明示的に定義済みのビュー一覧
+     *  @return array   array:ビュー一覧
      */
     function _getForwardList_Implicit($forward_list, $manifest_forward_list)
     {
@@ -593,10 +601,10 @@ class Ethna_InfoManager extends Ethna_AppManager
     }
 
     /**
-     *  Ethna
+     *  Ethnaの設定一覧を取得する
      *
      *  @access public
-     *  @return array   Ǽ
+     *  @return array   設定一覧を格納した配列
      *  @todo   respect access controll
      */
     function getConfiguration()
@@ -605,27 +613,27 @@ class Ethna_InfoManager extends Ethna_AppManager
 
         // core
         $elts = array();
-        $elts['ץꥱID'] = $this->ctl->getAppId();
-        $elts['ץꥱURL'] = $this->ctl->getURL();
-        $elts['EthnaС'] = ETHNA_VERSION;
-        $elts['Ethna١ǥ쥯ȥ'] = ETHNA_BASE;
+        $elts[_et('Application ID')] = $this->ctl->getAppId();
+        $elts[_et('Application URL')] = $this->ctl->getURL();
+        $elts[_et('Ethna Version')] = ETHNA_VERSION;
+        $elts[_et('Ethna Base Directory')] = ETHNA_BASE;
         $r['Core'] = $elts;
 
         // class
         $elts = array();
-        $elts['Хå'] = $this->class_factory->getObjectName('backend');
-        $elts['饹եȥ'] = $this->class_factory->getObjectName('class');
-        $elts[''] = $this->class_factory->getObjectName('config');
+        $elts[_et('Backend')] = $this->class_factory->getObjectName('backend');
+        $elts[_et('ClassFactory')] = $this->class_factory->getObjectName('class');
+        $elts[_et('Config')] = $this->class_factory->getObjectName('config');
         $elts['DB'] = $this->class_factory->getObjectName('db');
-        $elts['顼'] = $this->class_factory->getObjectName('error');
-        $elts['ե'] = $this->class_factory->getObjectName('form');
-        $elts[''] = $this->class_factory->getObjectName('logger');
+        $elts[_et('Error')] = $this->class_factory->getObjectName('error');
+        $elts[_et('Form')] = $this->class_factory->getObjectName('form');
+        $elts[_et('Log')] = $this->class_factory->getObjectName('logger');
         $elts['i18n'] = $this->class_factory->getObjectName('i18n');
-        $elts['ץ饰'] = $this->class_factory->getObjectName('plugin');
-        $elts['å'] = $this->class_factory->getObjectName('session');
+        $elts[_et('Plugin')] = $this->class_factory->getObjectName('plugin');
+        $elts[_et('Session')] = $this->class_factory->getObjectName('session');
         $elts['SQL'] = $this->class_factory->getObjectName('sql');
-        $elts['ӥ塼'] = $this->class_factory->getObjectName('view');
-        $r['饹'] = $elts;
+        $elts[_et('View')] = $this->class_factory->getObjectName('view');
+        $r[_et('Class')] = $elts;
 
         // DB
         $elts = array();
@@ -639,7 +647,7 @@ class Ethna_InfoManager extends Ethna_AppManager
             $elts[$tmp] = $this->getAttrName('db_type', $db);
             $db_list[$key] = $tmp;
         }
-        $r['DB'] = $elts;
+        $r[_et('DB Type')] = $elts;
 
         // DSN
         $elts = array();
@@ -657,37 +665,37 @@ class Ethna_InfoManager extends Ethna_AppManager
 
         // directory
         $elts = array();
-        $elts['ץꥱ'] = $this->ctl->getBasedir();
-        $elts[''] = $this->ctl->getActiondir();
-        $elts['ӥ塼'] = $this->ctl->getViewdir();
-        $elts['ե륿'] = $this->ctl->getDirectory('filter');
-        $elts['ץ饰'] = $this->ctl->getDirectory('plugin');
-        $elts['ƥץ졼'] = $this->ctl->getTemplatedir();
-        $elts['ƥץ졼ȥå'] = $this->ctl->getDirectory('template_c');
-        $elts['Smartyץ饰'] = implode(',', $this->ctl->getDirectory('plugins'));
-        $elts['ե'] = $this->ctl->getDirectory('etc');
-        $elts[''] = $this->ctl->getDirectory('locale');
-        $elts[''] = $this->ctl->getDirectory('log');
-        $elts['ե'] = $this->ctl->getDirectory('tmp');
-        $r['ǥ쥯ȥ'] = $elts;
+        $elts[_et('Application')] = $this->ctl->getBasedir();
+        $elts[_et('Action')] = $this->ctl->getActiondir();
+        $elts[_et('View')] = $this->ctl->getViewdir();
+        $elts[_et('Filter')] = $this->ctl->getDirectory('filter');
+        $elts[_et('Plugin')] = $this->ctl->getDirectory('plugin');
+        $elts[_et('Template')] = $this->ctl->getTemplatedir();
+        $elts[_et('Template Cache')] = $this->ctl->getDirectory('template_c');
+        $elts[_et('Smarty Plugin')] = implode(',', $this->ctl->getDirectory('plugins'));
+        $elts[_et('Configuration File')] = $this->ctl->getDirectory('etc');
+        $elts[_et('Locale')] = $this->ctl->getDirectory('locale');
+        $elts[_et('Logging')] = $this->ctl->getDirectory('log');
+        $elts[_et('Temporary File')] = $this->ctl->getDirectory('tmp');
+        $r[_et('Directory')] = $elts;
 
         // ext
         $elts = array();
-        $elts['ƥץ졼'] = $this->ctl->getExt('tpl');
-        $elts['PHPץ'] = $this->ctl->getExt('php');
-        $r['ĥ'] = $elts;
+        $elts[_et('Template')] = $this->ctl->getExt('tpl');
+        $elts[_et('PHP Script')] = $this->ctl->getExt('php');
+        $r[_et('File Extention')] = $elts;
 
         // filter
         $elts = array();
         $n = 1;
         foreach ($this->ctl->filter as $filter) {
-            $key = sprintf("ե륿(%d)", $n);
+            $key = sprintf(_et('Filter(%d)'), $n);
             if (class_exists($filter)) {
                 $elts[$key] = $filter;
                 $n++;
             }
         }
-        $r['ե륿'] = $elts;
+        $r[_et('Filter')] = $elts;
 
         // manager
         $elts = array();
@@ -695,16 +703,16 @@ class Ethna_InfoManager extends Ethna_AppManager
             $name = sprintf('$%s', $key);
             $elts[$name] = $this->ctl->getManagerClassName($manager);
         }
-        $r['ץꥱޥ͡'] = $elts;
+        $r[_et('Application Manager')] = $elts;
 
         return $r;
     }
 
     /**
-     *  ץ饰ΰ
+     *  プラグインの一覧を取得する
      *
      *  @access public
-     *  @return array   Ǽ
+     *  @return array   設定一覧を格納した配列
      *  @todo   respect access controll
      */
     function getPluginList()
@@ -730,4 +738,5 @@ class Ethna_InfoManager extends Ethna_AppManager
     }
 }
 // }}}
+
 ?>
