@@ -6,16 +6,16 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_MailSender.php 718 2009-02-04 15:48:40Z mumumu-org $
+ *  @version    $Id$
  */
 
-/** ᡼ƥץ졼ȥ: ľ */
+/** メールテンプレートタイプ: 直接送信 */
 define('MAILSENDER_TYPE_DIRECT', 0);
 
 
 // {{{ Ethna_MailSender
 /**
- *  ᡼饹
+ *  メール送信クラス
  *
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @access     public
@@ -27,32 +27,32 @@ class Ethna_MailSender
      *  @access private
      */
 
-    /** @var    array   ᡼ƥץ졼 */
+    /** @var    array   メールテンプレート定義 */
     var $def = array(
     );
 
-    /** @var    string  ᡼ƥץ졼ȥǥ쥯ȥ */
+    /** @var    string  メールテンプレートディレクトリ */
     var $mail_dir = 'mail';
 
-    /** @var    int     ᡼륿 */
+    /** @var    int     送信メールタイプ */
     var $type;
 
-    /** @var    string  ץ */
+    /** @var    string  送信オプション */
     var $option = '';
 
-    /** @var    object  Ethna_Backend   backend֥ */
+    /** @var    object  Ethna_Backend   backendオブジェクト */
     var $backend;
 
-    /** @var    object  Ethna_Config    ꥪ֥ */
+    /** @var    object  Ethna_Config    設定オブジェクト */
     var $config;
 
     /**#@-*/
 
     /**
-     *  Ethna_MailSender饹Υ󥹥ȥ饯
+     *  Ethna_MailSenderクラスのコンストラクタ
      *
      *  @access public
-     *  @param  object  Ethna_Backend   &$backend       backend֥
+     *  @param  object  Ethna_Backend   &$backend       backendオブジェクト
      */
     function Ethna_MailSender(&$backend)
     {
@@ -61,10 +61,10 @@ class Ethna_MailSender
     }
 
     /**
-     *  ᡼륪ץꤹ
+     *  メールオプションを設定する
      *
      *  @access public
-     *  @param  string  $option ᡼ץ
+     *  @param  string  $option メール送信オプション
      */
     function setOption($option)
     {
@@ -72,43 +72,44 @@ class Ethna_MailSender
     }
 
     /**
-     *  ᡼
+     *  メールを送信する
      *
-     *  $attach λˡ:
-     *  - ¸ΥեźդȤ
+     *  $attach の指定方法:
+     *  - 既存のファイルを添付するとき
      *  <code>
      *  array('filename' => '/tmp/hoge.xls', 'content-type' => 'application/vnd.ms-excel')
      *  </code>
-     *  - ʸ̾դźդȤ
+     *  - 文字列に名前を付けて添付するとき
      *  <code>
      *  array('name' => 'foo.txt', 'content' => 'this is foo.')
      *  </code>
-     *  'content-type' ά 'application/octet-stream' Ȥʤ롣
-     *  ʣźդȤϾź0ϤޤդĤ롣
+     *  'content-type' 省略時は 'application/octet-stream' となる。
+     *  複数添付するときは上の配列を添字0から始まるふつうの配列に入れる。
      *
      *  @access public
-     *  @param  string  $to         ᡼襢ɥ쥹 (nullΤȤƤ return )
-     *  @param  string  $template   ᡼ƥץ졼̾ or 
-     *  @param  array   $macro      ƥץ졼ȥޥ or $templateMAILSENDER_TYPE_DIRECTΤȤϥ᡼)
-     *  @param  array   $attach     źեե
+     *  @param  string  $to         メール送信先アドレス (nullのときは送信せずに内容を return する)
+     *  @param  string  $template   メールテンプレート名 or タイプ
+     *  @param  array   $macro      テンプレートマクロ or $templateがMAILSENDER_TYPE_DIRECTのときはメール送信内容)
+     *  @param  array   $attach     添付ファイル
      */
     function send($to, $template, $macro, $attach = null)
     {
-        // ᡼Ƥ
+        // メール内容を作成
         if ($template === MAILSENDER_TYPE_DIRECT) {
             $mail = $macro;
         } else {
             $renderer =& $this->getTemplateEngine();
 
-            // ܾ
-            $renderer->setProp("env_datetime", strftime('%Yǯ%m%d %H%Mʬ%S'));
+            // 基本情報設定
+            $env_datetime = _et('%Y/%m/%d %H:%M:%S');
+            $renderer->setProp("env_datetime", strftime($env_datetime));
             $renderer->setProp("env_useragent", $_SERVER["HTTP_USER_AGENT"]);
             $renderer->setProp("env_remoteaddr", $_SERVER["REMOTE_ADDR"]);
 
-            // ǥեȥޥ
+            // デフォルトマクロ設定
             $macro = $this->_setDefaultMacro($macro);
 
-            // 桼
+            // ユーザ定義情報設定
             if (is_array($macro)) {
                 foreach ($macro as $key => $value) {
                     $renderer->setProp($key, $value);
@@ -126,11 +127,11 @@ class Ethna_MailSender
             return $mail;
         }
 
-        // ᡼ƤإåʸʬΥ
+        // メール内容をヘッダと本文に分離
         $mail = str_replace("\r\n", "\n", $mail);
         list($header, $body) = $this->_parse($mail);
 
-        // źեե (multipart)
+        // 添付ファイル (multipart)
         if ($attach !== null) {
             $attach = isset($attach[0]) ? $attach : array($attach);
             $boundary = Ethna_Util::getRandom(); 
@@ -174,7 +175,7 @@ class Ethna_MailSender
             $body .= "--$boundary--";
         }
 
-        // إå
+        // ヘッダ
         if (isset($header['mime-version']) === false) {
             $header['mime-version'] = array('Mime-Version', '1.0');
         }
@@ -201,13 +202,17 @@ class Ethna_MailSender
             $header_line .= $value[0] . ": " . $value[1];
         }
 
-        // ԥɤ CRLF 
+        // 改行コードを CRLF に
         if (strtoupper(substr(PHP_OS, 0, 3)) == 'WIN') {
             $body = str_replace("\n", "\r\n", $body);
         }
-        $header_line = str_replace("\n", "\r\n", $header_line);
+        $wa_config = 'mail_func_workaround';
+        if ($this->config->get($wa_config) == false
+         && isset($this->options[$wa_config]) == false) {
+            $header_line = str_replace("\n", "\r\n", $header_line);
+        }
 
-        // 
+        // 送信
         foreach (to_array($to) as $rcpt) {
             if (is_string($this->option)) {
                 mail($rcpt, $header['subject'][1], $body, $header_line, $this->option);
@@ -218,11 +223,11 @@ class Ethna_MailSender
     }
 
     /**
-     *  ץꥱͭΥޥꤹ
+     *  アプリケーション固有のマクロを設定する
      *
      *  @access protected
-     *  @param  array   $macro  桼ޥ
-     *  @return array   ץꥱͭѤߥޥ
+     *  @param  array   $macro  ユーザ定義マクロ
+     *  @return array   アプリケーション固有処理済みマクロ
      */
     function _setDefaultMacro($macro)
     {
@@ -230,11 +235,11 @@ class Ethna_MailSender
     }
 
     /**
-     *  ƥץ졼ȥ᡼Υإå
+     *  テンプレートメールのヘッダ情報を取得する
      *
      *  @access private
-     *  @param  string  $mail   ᡼ƥץ졼
-     *  @return array   إå, ʸ
+     *  @param  string  $mail   メールテンプレート
+     *  @return array   ヘッダ, 本文
      */
     function _parse($mail)
     {
@@ -260,10 +265,10 @@ class Ethna_MailSender
     }
 
     /**
-     *  ᡼եޥåѥ饪֥ȼ
+     *  メールフォーマット用レンダラオブジェクト取得する
      *
      *  @access public
-     *  @return object  Ethna_Renderer  饪֥
+     *  @return object  Ethna_Renderer  レンダラオブジェクト
      */
     function &getRenderer()
     {
@@ -272,10 +277,10 @@ class Ethna_MailSender
     }
 
     /**
-     *  ᡼եޥåѥ饪֥ȼ
+     *  メールフォーマット用レンダラオブジェクト取得する
      *
      *  @access public
-     *  @return object  Ethna_Renderer  饪֥
+     *  @return object  Ethna_Renderer  レンダラオブジェクト
      */
     function &getTemplateEngine()
     {
