@@ -6,7 +6,7 @@
  *  @author     ICHII Takashi <ichii386@schweetheart.jp>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_PearWrapper.php 455 2007-01-24 02:56:59Z ichii386 $
+ *  @version    $Id$
  */
 
 require_once 'PEAR.php';
@@ -454,7 +454,7 @@ class Ethna_PearWrapper
         $config =& PEAR_Config::singleton();
         $packagefile =& new PEAR_PackageFile($config);
         $info =& $packagefile->fromTgzFile($filename, PEAR_VALIDATE_NORMAL);
-        if (Ethna::isError($info)) {
+        if (PEAR::isError($info)) {
             return $info;
         }
         $info_array = $info->toArray();
@@ -648,8 +648,9 @@ class Ethna_PearWrapper
     {
         $short_args = $long_args = null;
         PEAR_Command::getGetOptArgs($cmd_str, $short_args, $long_args);
-        $opt_arg = Console_GetOpt::getOpt2($opt_array, $short_args, $long_args);
-        if (PEAR::isError($opt_arg)) return array();
+        $opt = new Ethna_Getopt();
+        $opt_arg = $opt->getopt($opt_array, $short_args, $long_args);
+        if (Ethna::isError($opt_arg)) return array();
         $opts = array();
         foreach ($opt_arg[0] as $tmp) {
             list($opt, $val) = $tmp;
@@ -658,11 +659,11 @@ class Ethna_PearWrapper
                 $cmd_opts = $cmd_obj->getOptions($cmd_str);
                 foreach ($cmd_opts as $o => $d) {
                     if (isset($d['shortopt']) && $d['shortopt'] == $opt) {
-                        $opts[$o] = $value;
+                        $opts[$o] = $val;
                     }
                 }
             } else {
-                if (substr($opt, 0, 2) == '--') $opts[substr($opt, 2)] = $value;
+                if (substr($opt, 0, 2) == '--') $opts[substr($opt, 2)] = $val;
             }
         }
         return $opts;
