@@ -6,12 +6,12 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Session.php 417 2006-11-17 09:03:53Z cocoitiban $
+ *  @version    $Id$
  */
 
 // {{{ Ethna_Session
 /**
- *  å󥯥饹
+ *  セッションクラス
  *
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @access     public
@@ -23,29 +23,29 @@ class Ethna_Session
      *  @access private
      */
 
-    /** @var    object  Ethna_Logger    logger֥ */
+    /** @var    object  Ethna_Logger    loggerオブジェクト */
     var $logger;
 
-    /** @var    string  å̾ */
+    /** @var    string  セッション名 */
     var $session_name;
 
-    /** @var    string  åǡ¸ǥ쥯ȥ */
+    /** @var    string  セッションデータ保存ディレクトリ */
     var $session_save_dir;
 
-    /** @var    bool    å󳫻ϥե饰 */
+    /** @var    bool    セッション開始フラグ */
     var $session_start = false;
 
-    /** @var    bool    ƿ̾åե饰 */
+    /** @var    bool    匿名セッションフラグ */
     var $anonymous = false;
 
     /**#@-*/
 
     /**
-     *  Ethna_Session饹Υ󥹥ȥ饯
+     *  Ethna_Sessionクラスのコンストラクタ
      *
      *  @access public
-     *  @param  string  $appid      ץꥱID(å̾Ȥƻ)
-     *  @param  string  $save_dir   åǡ¸ǥ쥯ȥ
+     *  @param  string  $appid      アプリケーションID(セッション名として使用)
+     *  @param  string  $save_dir   セッションデータを保存するディレクトリ
      */
     function Ethna_Session($appid, $save_dir, $logger)
     {
@@ -77,7 +77,7 @@ class Ethna_Session
     }
 
     /**
-     *  å
+     *  セッションを復帰する
      *
      *  @access public
      */
@@ -104,10 +104,10 @@ class Ethna_Session
     }
 
     /**
-     *  åå
+     *  セッションの正当性チェック
      *
      *  @access public
-     *  @return bool    true:ʥå false:ʥå
+     *  @return bool    true:正当なセッション false:不当なセッション
      */
     function isValid()
     {
@@ -133,11 +133,11 @@ class Ethna_Session
     }
 
     /**
-     *  å򳫻Ϥ
+     *  セッションを開始する
      *
      *  @access public
-     *  @param  int     $lifetime   åͭ(ñ, 0ʤ饻å󥯥å)
-     *  @return bool    true:ｪλ false:顼
+     *  @param  int     $lifetime   セッション有効期間(秒単位, 0ならセッションクッキー)
+     *  @return bool    true:正常終了 false:エラー
      */
     function start($lifetime = 0, $anonymous = false)
     {
@@ -157,18 +157,19 @@ class Ethna_Session
         session_set_cookie_params($lifetime);
         session_id(Ethna_Util::getRandom());
         session_start();
-        $_SESSION['REMOTE_ADDR'] = $_SERVER['REMOTE_ADDR'];
+        $_SESSION['REMOTE_ADDR'] = isset($_SERVER['REMOTE_ADDR']) ? $_SERVER['REMOTE_ADDR']: false;
         $_SESSION['__anonymous__'] = $anonymous;
+        $this->anonymous = $anonymous;
         $this->session_start = true;
 
         return true;
     }
 
     /**
-     *  å˴
+     *  セッションを破棄する
      *
      *  @access public
-     *  @return bool    true:ｪλ false:顼
+     *  @return bool    true:正常終了 false:エラー
      */
     function destroy()
     {
@@ -184,10 +185,10 @@ class Ethna_Session
     }
 
     /**
-     *  åID
+     *  セッションIDを再生成する
      *
      *  @access public
-     *  @return bool    true:ｪλ false:顼
+     *  @return bool    true:正常終了 false:エラー
      */
     function regenerateId($lifetime = 0, $anonymous = false)
     {
@@ -210,11 +211,11 @@ class Ethna_Session
     }
 
     /**
-     *  åͤؤΥ(R)
+     *  セッション値へのアクセサ(R)
      *
      *  @access public
-     *  @param  string  $name   
-     *  @return mixed   (null:å󤬳ϤƤʤ)
+     *  @param  string  $name   キー
+     *  @return mixed   取得した値(null:セッションが開始されていない)
      */
     function get($name)
     {
@@ -229,12 +230,12 @@ class Ethna_Session
     }
 
     /**
-     *  åͤؤΥ(W)
+     *  セッション値へのアクセサ(W)
      *
      *  @access public
-     *  @param  string  $name   
-     *  @param  string  $value  
-     *  @return bool    true:ｪλ false:顼(å󤬳ϤƤʤ)
+     *  @param  string  $name   キー
+     *  @param  string  $value  値
+     *  @return bool    true:正常終了 false:エラー(セッションが開始されていない)
      */
     function set($name, $value)
     {
@@ -249,11 +250,11 @@ class Ethna_Session
     }
 
     /**
-     *  åͤ˴
+     *  セッションの値を破棄する
      *
      *  @access public
-     *  @param  string  $name   
-     *  @return bool    true:ｪλ false:顼(å󤬳ϤƤʤ)
+     *  @param  string  $name   キー
+     *  @return bool    true:正常終了 false:エラー(セッションが開始されていない)
      */
     function remove($name)
     {
@@ -267,11 +268,11 @@ class Ethna_Session
     }
 
     /**
-     *  å󤬳ϤƤ뤫ɤ֤
+     *  セッションが開始されているかどうかを返す
      *
      *  @access public
-     *  @param  string  $anonymous  ƿ̾åֳϡפȤߤʤɤ(default: false)
-     *  @return bool    true:ϺѤ false:ϤƤʤ
+     *  @param  string  $anonymous  匿名セッションを「開始」とみなすかどうか(default: false)
+     *  @return bool    true:開始済み false:開始されていない
      */
     function isStart($anonymous = false)
     {
@@ -287,10 +288,10 @@ class Ethna_Session
     }
 
     /**
-     *  ƿ̾å󤫤ɤ֤
+     *  匿名セッションかどうかを返す
      *
      *  @access public
-     *  @return bool    true:ƿ̾å false:ƿ̾å/å󳫻ϤƤʤ
+     *  @return bool    true:匿名セッション false:非匿名セッション/セッション開始されていない
      */
     function isAnonymous()
     {
@@ -298,13 +299,13 @@ class Ethna_Session
     }
 
     /**
-     *  å¸줿IPɥ쥹ȥIPɥ쥹
-     *  ƱͥåȥϰϤɤȽ̤(16bit mask)
+     *  セッションに保存されたIPアドレスとアクセス元のIPアドレスが
+     *  同一ネットワーク範囲かどうかを判別する(16bit mask)
      *
      *  @access private
-     *  @param  string  $src_ip     å󳫻ϻΥIPɥ쥹
-     *  @param  string  $dst_ip     ߤΥIPɥ쥹
-     *  @return bool    true:ｪλ false:IPɥ쥹
+     *  @param  string  $src_ip     セッション開始時のアクセス元IPアドレス
+     *  @param  string  $dst_ip     現在のアクセス元IPアドレス
+     *  @return bool    true:正常終了 false:不正なIPアドレス
      */
     function _validateRemoteAddr($src_ip, $dst_ip)
     {
