@@ -5,7 +5,7 @@
  *  @author     Takuya Ookubo <sfio@sakura.ai.to>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_UnitTestManager.php 471 2007-07-12 11:27:25Z mumumu-org $
+ *  @version    $Id$
  */
 
 require_once('simpletest/unit_tester.php');
@@ -13,7 +13,7 @@ require_once('Ethna_UnitTestCase.php');
 require_once('Ethna_UnitTestReporter.php');
 
 /**
- *  Ethna˥åȥƥȥޥ͡㥯饹
+ *  Ethnaユニットテストマネージャクラス
  *
  *  @author     Takuya Ookubo <sfio@sakura.ai.to>
  *  @access     public
@@ -21,30 +21,94 @@ require_once('Ethna_UnitTestReporter.php');
  */
 class Ethna_UnitTestManager extends Ethna_AppManager
 {
-    /** @var    object  Ethna_Controller    ȥ饪֥ */
+    /** @var    object  Ethna_Controller    コントローラオブジェクト */
     var $ctl;
 
-    /** @var    array                       ̥ƥȥ */
+    /** @var    array                       一般テストケース定義 */
     var $testcase = array();
 
     /**
-     *  Ethna_UnitTestManagerΥ󥹥ȥ饯
+     *  Ethna_UnitTestManagerのコンストラクタ
      *
      *  @access public
-     *  @param  object  Ethna_Backend   &$backend   Ethna_Backend֥
+     *  @param  object  Ethna_Backend   &$backend   Ethna_Backendオブジェクト
      */
     function Ethna_UnitTestManager(&$backend)
     {
         parent::Ethna_AppManager($backend);
         $this->ctl =& Ethna_Controller::getInstance();
         $this->class_factory =& $this->ctl->getClassFactory();
+        $this->testcase = array_merge($this->testcase, $this->_getTestCaseList()); 
     }
 
     /**
-     *  Ѥߥ
+     *  action, view 以外のテストケースの一覧を取得する
+     *
+     *  @access private
+     *  @param  テストケースが含まれているディレクトリ名
+     */
+    function _getTestCaseList($test_dir = NULL)
+    {
+        $r = array();
+
+        if (is_null($test_dir)) {
+            $test_dir = $this->ctl->getTestdir();
+        }
+        $base = $this->ctl->getBasedir();
+
+        //  テストディレクトリはユーザが変更できる
+        //  ため、実行時の変更のタイミング次第では
+        //  WARNING が出る可能性があるのをケアする
+        if (!is_dir($test_dir)) {
+            return array();
+        }
+
+        $child_dir_list = array();
+
+        $dh = opendir($test_dir);
+        if ($dh == false) {
+            return;
+        }
+
+        $ext = $this->ctl->getExt('php');
+        while (($file = readdir($dh)) !== false) {
+            if ($file == "." || $file == "..") {
+                continue;
+            }
+            $file = $test_dir . $file;
+
+            if (is_dir($file)) {
+                $child_dir_list[] = $file;
+                continue;
+            }
+
+            if (preg_match("/\.$ext\$/", $file) == 0) {
+                continue;
+            }
+
+            $file = str_replace($this->ctl->getTestdir(), '', $file);
+
+            $key = ereg_replace("^(.*)Test\.$ext", '\1', $file);
+            $key = str_replace('/', '', $key);
+
+            $r[$key] = str_replace($base . '/', '', $this->ctl->getTestdir() . $file);
+        }
+
+        closedir($dh);
+
+        foreach ($child_dir_list as $child_dir) {
+            $tmp = $this->_getTestCaseList($child_dir . "/");
+            $r = array_merge($r, $tmp);
+        }
+
+        return $r;
+    }
+
+    /**
+     *  定義済みアクション一覧を取得する
      *
      *  @access public
-     *  @return array   
+     *  @return array   アクション一覧
      */
     function _getActionList()
     {
@@ -53,17 +117,17 @@ class Ethna_UnitTestManager extends Ethna_AppManager
     }
 
     /**
-     *  饹̾ӥ塼̾
+     *  クラス名からビュー名を取得する
      *
      *  @access public
-     *  @param  string  $class_name     ӥ塼饹̾
-     *  @return string  ̾
+     *  @param  string  $class_name     ビュークラス名
+     *  @return string  アクション名
      */
     function viewClassToName($class_name)
     {
         $prefix = sprintf("%s_View_", $this->ctl->getAppId());
         if (preg_match("/$prefix(.*)/", $class_name, $match) == 0) {
-            // ʥ饹̾
+            // 不明なクラス名
             return null;
         }
         $target = $match[1];
@@ -74,12 +138,12 @@ class Ethna_UnitTestManager extends Ethna_AppManager
     }
 
     /**
-     *  ꤵ줿饹̾ѾƤ뤫ɤ֤
+     *  指定されたクラス名を継承しているかどうかを返す
      *
      *  @access private
-     *  @param  string  $class_name     åоݤΥ饹̾
-     *  @param  string  $parent_name    ƥ饹̾
-     *  @return bool    true:ѾƤ false:ʤ
+     *  @param  string  $class_name     チェック対象のクラス名
+     *  @param  string  $parent_name    親クラス名
+     *  @return bool    true:継承している false:いない
      */
     function _isSubclassOf($class_name, $parent_name)
     {
@@ -93,11 +157,11 @@ class Ethna_UnitTestManager extends Ethna_AppManager
     }
 
     /**
-     *  ӥ塼ץȤϤ
+     *  ビュースクリプトを解析する
      *
      *  @access private
-     *  @param  string  $script ե̾
-     *  @return array   ӥ塼饹
+     *  @param  string  $script ファイル名
+     *  @return array   ビュークラス定義一覧
      */
     function __analyzeViewScript($script)
     {
@@ -113,13 +177,13 @@ class Ethna_UnitTestManager extends Ethna_AppManager
         }
         fclose($fp);
 
-        // ȡʬ䤷ƥ饹
+        // トークンに分割してクラス定義情報を取得
         $token_list = token_get_all($source);
         for ($i = 0; $i < count($token_list); $i++) {
             $token = $token_list[$i];
 
             if ($token[0] == T_CLASS) {
-                // 饹
+                // クラス定義開始
                 $i += 2;
                 $class_name = $token_list[$i][1];       // should be T_STRING
                 if ($this->_isSubclassOf($class_name, 'Ethna_ViewClass')) {
@@ -140,11 +204,11 @@ class Ethna_UnitTestManager extends Ethna_AppManager
     }
 
     /**
-     *  ǥ쥯ȥʲΥӥ塼ץȤϤ
+     *  ディレクトリ以下のビュースクリプトを解析する
      *
      *  @access private
-     *  @param  string  $action_dir     оݤΥǥ쥯ȥ
-     *  @return array   ӥ塼饹
+     *  @param  string  $action_dir     解析対象のディレクトリ
+     *  @return array   ビュークラス定義一覧
      */
     function __analyzeViewList($view_dir = null)
     {
@@ -184,26 +248,26 @@ class Ethna_UnitTestManager extends Ethna_AppManager
     }
 
     /**
-     *  Ѥߥӥ塼
+     *  定義済みビュー一覧を取得する
      *
      *  @access public
-     *  @return array   ӥ塼
+     *  @return array   ビュー一覧
      */
     function _getViewList()
     {
         $im =& new Ethna_InfoManager($this->backend);
-//        $view_class_list = array_keys($im->getForwardList());
+        //$view_class_list = array_keys($im->getForwardList());
 
         $r = array();
 
-        // ƥץ졼/ӥ塼ץȤϤ
+        // テンプレート/ビュースクリプトを解析する
         $forward_list = $im->_analyzeForwardList();
         $view_list = $this->__analyzeViewList();
 
-        // ӥ塼ȥ
+        // ビュー定義エントリ一覧
         $manifest_forward_list = $im->_getForwardList_Manifest($forward_list);
 
-        // ӥ塼άȥ
+        // ビュー定義省略エントリ一覧
         $implicit_forward_list = $im->_getForwardList_Implicit($forward_list, $manifest_forward_list);
 
         $r = array_merge($view_list, $manifest_forward_list, $implicit_forward_list);
@@ -213,7 +277,7 @@ class Ethna_UnitTestManager extends Ethna_AppManager
     }
 
     /**
-     *  ƥȥ饹
+     *  アクションテストクラスを取得する
      *
      *  @access private
      *  @return array
@@ -222,7 +286,7 @@ class Ethna_UnitTestManager extends Ethna_AppManager
     {
         $action_class_list = array_keys($this->_getActionList());
 
-        // ƥȤ¸ߤ륢
+        // テストの存在するアクション
         foreach ($action_class_list as $key => $action_name) {
             $action_class = $this->ctl->getDefaultActionClass($action_name, false).'_TestCase';
             if (!class_exists($action_class)) {
@@ -234,7 +298,7 @@ class Ethna_UnitTestManager extends Ethna_AppManager
     }
 
     /**
-     *  ӥ塼ƥȥ饹
+     *  ビューテストクラスを取得する
      *
      *  @access private
      *  @return array
@@ -243,7 +307,7 @@ class Ethna_UnitTestManager extends Ethna_AppManager
     {
         $view_class_list = array_keys($this->_getViewList());
 
-        // ƥȤ¸ߤӥ塼
+        // テストの存在するビュー
         foreach ($view_class_list as $key => $view_name) {
             $view_class = $this->ctl->getDefaultViewClass($view_name, false).'_TestCase';
             if (!class_exists($view_class)) {
@@ -255,10 +319,10 @@ class Ethna_UnitTestManager extends Ethna_AppManager
     }
 
     /**
-     *  ˥åȥƥȤ¹Ԥ
+     *  ユニットテストを実行する
      *
      *  @access private
-     *  @return mixed   0:ｪλ Ethna_Error:顼
+     *  @return mixed   0:正常終了 Ethna_Error:エラー
      */
     function run()
     {
@@ -267,7 +331,7 @@ class Ethna_UnitTestManager extends Ethna_AppManager
 
         $test =& new GroupTest("Ethna UnitTest");
 
-        // 
+        // アクション
         foreach ($action_class_list as $action_name) {
             $action_class = $this->ctl->getDefaultActionClass($action_name, false).'_TestCase';
             $action_form = $this->ctl->getDefaultFormClass($action_name, false).'_TestCase';
@@ -276,14 +340,14 @@ class Ethna_UnitTestManager extends Ethna_AppManager
             $test->addTestCase(new $action_form($this->ctl));
         }
 
-        // ӥ塼
+        // ビュー
         foreach ($view_class_list as $view_name) {
             $view_class = $this->ctl->getDefaultViewClass($view_name, false).'_TestCase';
 
             $test->addTestCase(new $view_class($this->ctl));
         }
 
-        // 
+        // 一般
         foreach ($this->testcase as $class_name => $file_name) {
             $dir = $this->ctl->getBasedir().'/';
             include_once $dir . $file_name;
@@ -291,14 +355,15 @@ class Ethna_UnitTestManager extends Ethna_AppManager
             $test->addTestCase(new $testcase_name($this->ctl));
         }
 
-        // ActionFormΥХåå
+        // ActionFormのバックアップ
         $af =& $this->ctl->getActionForm();
 
-        //Ϥˤ碌ڤؤ
-        $reporter = new Ethna_UnitTestReporter();
+        //出力したい形式にあわせて切り替える
+        $cli_enc = $this->ctl->getClientEncoding();
+        $reporter = new Ethna_UnitTestReporter($cli_enc);
         $test->run($reporter);
 
-        // ActionFormΥꥹȥ
+        // ActionFormのリストア
         $this->ctl->action_form =& $af;
         $this->backend->action_form =& $af;
         $this->backend->af =& $af;
