@@ -6,15 +6,15 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Util.php 468 2007-07-07 07:52:30Z mumumu-org $
+ *  @version    $Id$
  */
 
 // {{{ to_array
 /**
- *  Х桼ƥƥؿ: 顼ͤǿ1Ȥ֤
+ *  グローバルユーティリティ関数: スカラー値を要素数1の配列として返す
  *
- *  @param  mixed   $v  Ȥư
- *  @return array   Ѵ줿
+ *  @param  mixed   $v  配列として扱う値
+ *  @return array   配列に変換された値
  */
 function to_array($v)
 {
@@ -28,10 +28,10 @@ function to_array($v)
 
 // {{{ is_error
 /**
- *  Х桼ƥƥؿ: ꤵ줿եܤ˥顼뤫ɤ֤
+ *  グローバルユーティリティ関数: 指定されたフォーム項目にエラーがあるかどうかを返す
  *
- *  @param  string  $name   ե̾
- *  @return bool    true:顼ͭ false:顼̵
+ *  @param  string  $name   フォーム項目名
+ *  @return bool    true:エラー有り false:エラー無し
  */
 function is_error($name = null)
 {
@@ -47,11 +47,11 @@ function is_error($name = null)
 
 // {{{ file_exists_ex
 /**
- *  Х桼ƥƥؿ: include_path򸡺Ĥfile_exists()
+ *  グローバルユーティリティ関数: include_pathを検索しつつfile_exists()する
  *
- *  @param  string  $path               ե̾
- *  @param  bool    $use_include_path   include_pathå뤫ɤ
- *  @return bool    true:ͭ false:̵
+ *  @param  string  $path               ファイル名
+ *  @param  bool    $use_include_path   include_pathをチェックするかどうか
+ *  @return bool    true:有り false:無し
  */
 function file_exists_ex($path, $use_include_path = true)
 {
@@ -80,14 +80,14 @@ function file_exists_ex($path, $use_include_path = true)
 
 // {{{ is_absolute_path
 /**
- *  Х桼ƥƥؿ: Хѥɤ֤
+ *  グローバルユーティリティ関数: 絶対パスかどうかを返す
  *
- *  @param  string  $path               ե̾
- *  @return bool    true: false:
+ *  @param  string  $path               ファイル名
+ *  @return bool    true:絶対 false:相対
  */
 function is_absolute_path($path)
 {
-    if (OS_WINDOWS) {
+    if (ETHNA_OS_WINDOWS) {
         if (preg_match('/^[a-z]:/i', $path) && $path{2} == DIRECTORY_SEPARATOR) {
             return true;
         }
@@ -102,7 +102,7 @@ function is_absolute_path($path)
 
 // {{{ Ethna_Util
 /**
- *  桼ƥƥ饹
+ *  ユーティリティクラス
  *
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @access     public
@@ -112,10 +112,10 @@ class Ethna_Util
 {
     // {{{ isDuplicatePost
     /**
-     *  POSTΥˡåԤ
+     *  POSTのユニークチェックを行う
      *
      *  @access public
-     *  @return bool    true:2ܰʹߤPOST false:1ܤPOST
+     *  @return bool    true:2回目以降のPOST false:1回目のPOST
      */
     function isDuplicatePost()
     {
@@ -154,10 +154,10 @@ class Ethna_Util
 
     // {{{ clearDuplicatePost
     /**
-     *  POSTΥˡåե饰򥯥ꥢ
+     *  POSTのユニークチェックフラグをクリアする
      *
      *  @acccess public
-     *  @return mixed   0:ｪλ Ethna_Error:顼
+     *  @return mixed   0:正常終了 Ethna_Error:エラー
      */
     function clearDuplicatePost()
     {
@@ -176,7 +176,7 @@ class Ethna_Util
                             $uniqid);
         if (file_exists($filename)) {
             if (unlink($filename) == false) {
-                return Ethna::raiseWarning("ե񤭹ߥ顼[%s]", E_APP_WRITE, $filename);
+                return Ethna::raiseWarning("File Write Error [%s]", E_APP_WRITE, $filename);
             }
         }
 
@@ -186,10 +186,10 @@ class Ethna_Util
 
     // {{{ isCsrfSafeValid
     /**
-     *  CSRFå
+     *  CSRFをチェックする
      *
      *  @access public
-     *  @return bool    true:POST false:POST
+     *  @return bool    true:正常なPOST false:不正なPOST
      */
     function isCsrfSafe()
     {
@@ -208,10 +208,10 @@ class Ethna_Util
 
     // {{{ setCsrfID
     /**
-     *  CSRFå
+     *  CSRFをチェックする
      *
      *  @access public
-     *  @return bool    true:
+     *  @return bool    true:成功
      */
     function setCsrfID()
     {
@@ -230,11 +230,11 @@ class Ethna_Util
 
     // {{{ checkMailAddress
     /**
-     *  ᡼륢ɥ쥹ɤå
+     *  メールアドレスが正しいかどうかをチェックする
      *
      *  @access public
-     *  @param  string  $mailaddress    å᡼륢ɥ쥹
-     *  @return bool    true: ᡼륢ɥ쥹 false: ʷ
+     *  @param  string  $mailaddress    チェックするメールアドレス
+     *  @return bool    true: 正しいメールアドレス false: 不正な形式
      */
     function checkMailAddress($mailaddress)
     {
@@ -248,12 +248,12 @@ class Ethna_Util
 
     // {{{ explodeCSV
     /**
-     *  CSVʸʬ䤹
+     *  CSV形式の文字列を配列に分割する
      *
      *  @access public
-     *  @param  string  $csv        CSVʸ(1ʬ)
-     *  @param  string  $delimiter  եɤζڤʸ
-     *  @return mixed   (array):ʬ Ethna_Error:顼(Է³)
+     *  @param  string  $csv        CSV形式の文字列(1行分)
+     *  @param  string  $delimiter  フィールドの区切り文字
+     *  @return mixed   (array):分割結果 Ethna_Error:エラー(行継続)
      */
     function explodeCSV($csv, $delimiter = ",")
     {
@@ -317,7 +317,7 @@ class Ethna_Util
                             $field .= $line_end;
 
                             // request one more line
-                            return Ethna::raiseNotice('CSVʬ䥨顼(Է³)', E_UTIL_CSV_CONTINUE);
+                            return Ethna::raiseNotice('CSV Split Error (line continue)', E_UTIL_CSV_CONTINUE);
                         }
                     }
                 }
@@ -344,12 +344,12 @@ class Ethna_Util
 
     // {{{ escapeCSV
     /**
-     *  CSV׽Ԥ
+     *  CSVエスケープ処理を行う
      *
      *  @access public
-     *  @param  string  $csv        оݤʸ(CSVγ)
-     *  @param  bool    $escape_nl  ʸ(\r/\n)Υץե饰
-     *  @return string  CSVפ줿ʸ
+     *  @param  string  $csv        エスケープ対象の文字列(CSVの各要素)
+     *  @param  bool    $escape_nl  改行文字(\r/\n)のエスケープフラグ
+     *  @return string  CSVエスケープされた文字列
      */
     function escapeCSV($csv, $escape_nl = false)
     {
@@ -368,11 +368,11 @@ class Ethna_Util
 
     // {{{ escapeHtml
     /**
-     *  ǤHTMLפ֤
+     *  配列の要素を全てHTMLエスケープして返す
      *
      *  @access public
-     *  @param  array   $target     HTMLоݤȤʤ
-     *  @return array   פ줿
+     *  @param  array   $target     HTMLエスケープ対象となる配列
+     *  @return array   エスケープされた配列
      */
     function escapeHtml($target)
     {
@@ -382,11 +382,11 @@ class Ethna_Util
     }
 
     /**
-     *  ǤHTMLפ֤
+     *  配列の要素を全てHTMLエスケープして返す
      *
      *  @access public
-     *  @param  mixed   $vars   HTMLоݤȤʤ
-     *  @param  mixed   $retval HTMLоݤȤʤ
+     *  @param  mixed   $vars   HTMLエスケープ対象となる配列
+     *  @param  mixed   $retval HTMLエスケープ対象となる子要素
      */
     function _escapeHtml(&$vars, &$retval)
     {
@@ -403,11 +403,11 @@ class Ethna_Util
 
     // {{{ encode_MIME
     /**
-     *  ʸMIME󥳡ɤ
+     *  文字列をMIMEエンコードする
      *
      *  @access public
-     *  @param  string  $string     MIME󥳡ɤʸ
-     *  @return 󥳡ɺѤߤʸ
+     *  @param  string  $string     MIMEエンコードする文字列
+     *  @return エンコード済みの文字列
      */
     function encode_MIME($string)
     {
@@ -426,13 +426,13 @@ class Ethna_Util
 
     // {{{ getDirectLinkList
     /**
-     *  Google󥯥ꥹȤ֤
+     *  Google風リンクリストを返す
      *
      *  @access public
-     *  @param  int     $total      
-     *  @param  int     $offset     ɽեå
-     *  @param  int     $count      ɽ
-     *  @return array   󥯾Ǽ
+     *  @param  int     $total      検索総件数
+     *  @param  int     $offset     表示オフセット
+     *  @param  int     $count      表示件数
+     *  @return array   リンク情報を格納した配列
      */
     function getDirectLinkList($total, $offset, $count)
     {
@@ -490,11 +490,11 @@ class Ethna_Util
 
     // {{{ getEra
     /**
-     *  Ǥǯ֤
+     *  元号制での年を返す
      *
      *  @access public
      *  @param  int     $t      unix time
-     *  @return string  (ʾnull)
+     *  @return string  元号(不明な場合はnull)
      */
     function getEra($t)
     {
@@ -502,9 +502,11 @@ class Ethna_Util
         $year = $tm['tm_year'] + 1900;
 
         if ($year >= 1989) {
-            return array('ʿ', $year - 1988);
+            $heisei_str = _et('Heisei');
+            return array($heisei_str, $year - 1988);
         } else if ($year >= 1926) {
-            return array('', $year - 1925);
+            $showa_str = _et('Showa');
+            return array($showa_str, $year - 1925);
         }
 
         return null;
@@ -513,11 +515,11 @@ class Ethna_Util
 
     // {{{ getImageExtName
     /**
-     *  getimagesize()֤᡼פбĥҤ֤
+     *  getimagesize()の返すイメージタイプに対応する拡張子を返す
      *
      *  @access public
-     *  @param  int     $type   getimagesize()ؿ֤᡼
-     *  @return string  $typeбĥ
+     *  @param  int     $type   getimagesize()関数の返すイメージタイプ
+     *  @return string  $typeに対応する拡張子
      */
     function getImageExtName($type)
     {
@@ -546,13 +548,13 @@ class Ethna_Util
 
     // {{{ getRandom
     /**
-     *  ʥϥåͤ
+     *  ランダムなハッシュ値を生成する
      *
-     *  褷ƹ®ǤϤʤΤѤ򤱤뤳
+     *  決して高速ではないので乱用は避けること
      *
      *  @access public
-     *  @param  int     $length ϥåͤĹ(64)
-     *  @return string  ϥå
+     *  @param  int     $length ハッシュ値の長さ(〜64)
+     *  @return string  ハッシュ値
      */
     function getRandom($length = 64)
     {
@@ -564,12 +566,20 @@ class Ethna_Util
             $srand = true;
         }
 
+        // open_basedir がオンで、かつ /proc が許可されているか？
+        // open_basedir が空なら許可されていると看做す
+        $devfile = '/proc/net/dev';
+        $open_basedir_conf = ini_get('open_basedir');
+        $devfile_enabled = (empty($open_basedir_conf) 
+                        || (preg_match('#:/proc#', $open_basedir_conf) > 0
+                        ||  preg_match('#^/proc#', $open_basedir_conf) > 0));
+
         $value = "";
         for ($i = 0; $i < 2; $i++) {
             // for Linux
-            if (file_exists('/proc/net/dev')) {
+            if ($devfile_enabled && file_exists($devfile)) {
                 $rx = $tx = 0;
-                $fp = fopen('/proc/net/dev', 'r');
+                $fp = fopen($devfile, 'r');
                 if ($fp != null) {
                     $header = true;
                     while (feof($fp) === false) {
@@ -604,13 +614,13 @@ class Ethna_Util
 
     // {{{ get2dArray
     /**
-     *  1m x n˺ƹ
+     *  1次元配列をm x nに再構成する
      *
      *  @access public
-     *  @param  array   $array  оݤ1
-     *  @param  int     $m      ǿ
-     *  @param  int     $order  $mXȸYȸ(0:X 1:Y)
-     *  @return array   m x n˺ƹ줿
+     *  @param  array   $array  処理対象の1次元配列
+     *  @param  int     $m      軸の要素数
+     *  @param  int     $order  $mをX軸と見做すかY軸と見做すか(0:X軸 1:Y軸)
+     *  @return array   m x nに再構成された配列
      */
     function get2dArray($array, $m, $order)
     {
@@ -624,10 +634,10 @@ class Ethna_Util
             $elts = array();
             for ($j = 0; $j < $m; $j++) {
                 if ($order == 0) {
-                    // ¤($m ġ̵)
+                    // 横並び(横：$m列 縦：無制限)
                     $key = $i*$m+$j;
                 } else {
-                    // ¤(̵ ġ$m)
+                    // 縦並び(横：無制限 縦：$m行)
                     $key = $i+$n*$j;
                 }
                 if (array_key_exists($key, $array) == false) {
@@ -644,13 +654,13 @@ class Ethna_Util
 
     // {{{ isAbsolute
     /**
-     *  ѥ̾Хѥɤ֤
+     *  パス名が絶対パスかどうかを返す
      *
      *  port from File in PEAR (for BC)
      *
      *  @access public
      *  @param  string  $path
-     *  @return bool    true:Хѥ false:Хѥ
+     *  @return bool    true:絶対パス false:相対パス
      */
     function isAbsolute($path)
     {
@@ -671,7 +681,7 @@ class Ethna_Util
 
     // {{{ isRootDir
     /**
-     *  ѥ̾롼ȥǥ쥯ȥ꤫ɤ֤
+     *  パス名がルートディレクトリかどうかを返す
      *
      *  @access public
      *  @param  string  $path
@@ -695,9 +705,9 @@ class Ethna_Util
      *  mkdir -p
      *
      *  @access public
-     *  @param  string  $dir    ǥ쥯ȥ
-     *  @param  int     $mode   ѡߥå
-     *  @return bool    true: false:
+     *  @param  string  $dir    作成するディレクトリ
+     *  @param  int     $mode   パーミッション
+     *  @return bool    true:成功 false:失敗
      *  @static
      */
     function mkdir($dir, $mode)
@@ -723,7 +733,7 @@ class Ethna_Util
 
     // {{{ chmod
     /**
-     *  եΥѡߥåѹ
+     *  ファイルのパーミッションを変更する
      */
     function chmod($file, $mode)
     {
@@ -737,12 +747,12 @@ class Ethna_Util
 
     // {{{ purgeDir
     /**
-     *  ǥ쥯ȥƵŪ˺
-     *  (ǼԤƤǤǤΤϤ٤ƾä)
+     *  ディレクトリを再帰的に削除する
+     *  (途中で失敗しても中断せず、削除できるものはすべて消す)
      *
      *  @access public
-     *  @param  string  $file   եޤϥǥ쥯ȥ
-     *  @return bool    true: false:
+     *  @param  string  $file   削除するファイルまたはディレクトリ
+     *  @return bool    true:成功 false:失敗
      *  @static
      */
     function purgeDir($dir)
@@ -776,11 +786,11 @@ class Ethna_Util
 
     // {{{ purgeTmp
     /**
-     *  ƥݥǥ쥯ȥΥե
+     *  テンポラリディレクトリのファイルを削除する
      *
      *  @access public
-     *  @param  string  $prefix     եΥץե
-     *  @param  int     $timeout    о(á60*60*1ʤ1)
+     *  @param  string  $prefix     ファイルのプレフィクス
+     *  @param  int     $timeout    削除対象閾値(秒−60*60*1なら1時間)
      */
     function purgeTmp($prefix, $timeout)
     {
@@ -808,22 +818,22 @@ class Ethna_Util
 
     // {{{ lockFile
     /**
-     *  եå
+     *  ファイルをロックする
      *
      *  @access public
-     *  @param  string  $file       åե̾
-     *  @param  int     $mode       å⡼('r', 'rw')
-     *  @param  int     $timeout    åԤॢ(á0ʤ̵)
-     *  @return int     åϥɥ(falseʤ饨顼)
+     *  @param  string  $file       ロックするファイル名
+     *  @param  int     $mode       ロックモード('r', 'rw')
+     *  @param  int     $timeout    ロック待ちタイムアウト(秒−0なら無限)
+     *  @return int     ロックハンドル(falseならエラー)
      */
     function lockFile($file, $mode, $timeout = 0)
     {
         if (file_exists($file) === false) {
             touch($file);
         }
-        $lh = fopen($file, 'r');
+        $lh = fopen($file, $mode);
         if ($lh == null) {
-            return Ethna::raiseError("եɤ߹ߥ顼[%s]", E_APP_READ, $file);
+            return Ethna::raiseError("File Read Error [%s]", E_APP_READ, $file);
         }
 
         $lock_mode = $mode == 'r' ? LOCK_SH : LOCK_EX;
@@ -837,7 +847,7 @@ class Ethna_Util
         }
         if ($timeout > 0 && $i == $timeout) {
             // timed out
-            return Ethna::raiseError("եå顼[%s]", E_APP_LOCK, $file);
+            return Ethna::raiseError("File lock get error [%s]", E_APP_LOCK, $file);
         }
 
         return $lh;
@@ -846,10 +856,10 @@ class Ethna_Util
 
     // {{{ unlockFile
     /**
-     *  եΥå
+     *  ファイルのロックを解除する
      *
      *  @access public
-     *  @param  int     $lh     åϥɥ
+     *  @param  int     $lh     ロックハンドル
      */
     function unlockFile($lh)
     {
@@ -859,11 +869,11 @@ class Ethna_Util
 
     // {{{ formatBacktrace
     /**
-     *  Хåȥ졼եޥåȤ֤
+     *  バックトレースをフォーマットして返す
      *
      *  @access public
-     *  @param  array   $bt     debug_backtrace()ؿǼХåȥ졼
-     *  @return string  ʸ˥եޥåȤ줿Хåȥ졼
+     *  @param  array   $bt     debug_backtrace()関数で取得したバックトレース
+     *  @return string  文字列にフォーマットされたバックトレース
      */
     function formatBacktrace($bt) 
     {
@@ -881,7 +891,7 @@ class Ethna_Util
                 continue;
             }
 
-            // Υ
+            // 引数のダンプ
             foreach ($elt['args'] as $arg) {
                 $r .= Ethna_Util::_formatBacktrace($arg);
             }
@@ -891,13 +901,13 @@ class Ethna_Util
     }
 
     /**
-     *  Хåȥ졼եޥåȤ֤
+     *  バックトレース引数をフォーマットして返す
      *
      *  @access private
-     *  @param  string  $arg    Хåȥ졼ΰ
-     *  @param  int     $level  Хåȥ졼Υͥȥ٥
-     *  @param  int     $wrap   ԥե饰
-     *  @return string  ʸ˥եޥåȤ줿Хåȥ졼
+     *  @param  string  $arg    バックトレースの引数
+     *  @param  int     $level  バックトレースのネストレベル
+     *  @param  int     $wrap   改行フラグ
+     *  @return string  文字列にフォーマットされたバックトレース
      */
     function _formatBacktrace($arg, $level = 0, $wrap = true)
     {
