@@ -6,12 +6,12 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_ViewClass.php,v 1.33 2006/11/27 08:52:31 ichii386 Exp $
+ *  @version    $Id$
  */
 
 // {{{ Ethna_ViewClass
 /**
- *  view饹
+ *  viewクラス
  *
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @access     public
@@ -23,62 +23,69 @@ class Ethna_ViewClass
      *  @access private
      */
 
-    /** @var    object  Ethna_Backend       backend֥ */
+    /** @var    object  Ethna_Controller    Controllerオブジェクト */
+    var $ctl;
+
+    /** @var    object  Ethna_Backend       backendオブジェクト */
     var $backend;
 
-    /** @var    object  Ethna_Config        ꥪ֥    */
+    /** @var    object  Ethna_Config        設定オブジェクト    */
     var $config;
 
-    /** @var    object  Ethna_I18N          i18n֥ */
+    /** @var    object  Ethna_I18N          i18nオブジェクト */
     var $i18n;
 
-    /** @var    object  Ethna_Logger    ֥ */
+    /** @var    object  Ethna_Logger    ログオブジェクト */
     var $logger;
 
-    /** @var    object  Ethna_Plugin    ץ饰󥪥֥ */
+    /** @var    object  Ethna_Plugin    プラグインオブジェクト */
     var $plugin;
 
-    /** @var    object  Ethna_ActionError   󥨥顼֥ */
+    /** @var    object  Ethna_ActionError   アクションエラーオブジェクト */
     var $action_error;
 
-    /** @var    object  Ethna_ActionError   󥨥顼֥(ά) */
+    /** @var    object  Ethna_ActionError   アクションエラーオブジェクト(省略形) */
     var $ae;
 
-    /** @var    object  Ethna_ActionForm    ե४֥ */
+    /** @var    object  Ethna_ActionForm    アクションフォームオブジェクト */
     var $action_form;
 
-    /** @var    object  Ethna_ActionForm    ե४֥(ά) */
+    /** @var    object  Ethna_ActionForm    アクションフォームオブジェクト(省略形) */
     var $af;
 
-    /** @var    array   ե४֥(helper) */
+    /** @var    array   アクションフォームオブジェクト(helper) */
     var $helper_action_form = array();
 
-    /** @var    array   helperhtmlattributeˤϤʥѥ᡼ΰ */
+    /** @var    array   helperでhtmlのattributeにはしないパラメータの一覧 */
     var $helper_parameter_keys = array('default', 'option', 'separator');
 
-    /** @var    object  Ethna_Session       å󥪥֥ */
+    /** @var    object  Ethna_Session       セッションオブジェクト */
     var $session;
 
-    /** @var    string  ̾ */
+    /** @var    string  遷移名 */
     var $forward_name;
 
-    /** @var    string  ƥץ졼ȥե̾ */
+    /** @var    string  遷移先テンプレートファイル名 */
     var $forward_path;
 
+    /** @var    boolean  配列フォームを呼んだカウンタをリセットするか否か */
+    var $reset_counter = false;
+
     /**#@-*/
 
     // {{{ Ethna_ViewClass
     /**
-     *  Ethna_ViewClassΥ󥹥ȥ饯
+     *  Ethna_ViewClassのコンストラクタ
      *
      *  @access public
-     *  @param  object  Ethna_Backend   $backend    backend֥
-     *  @param  string  $forward_name   ӥ塼˴ϢդƤ̾
-     *  @param  string  $forward_path   ӥ塼˴ϢդƤƥץ졼ȥե̾
+     *  @param  object  Ethna_Backend   $backend    backendオブジェクト
+     *  @param  string  $forward_name   ビューに関連付けられている遷移名
+     *  @param  string  $forward_path   ビューに関連付けられているテンプレートファイル名
      */
     function Ethna_ViewClass(&$backend, $forward_name, $forward_path)
     {
         $c =& $backend->getController();
+        $this->ctl =& $c;
         $this->backend =& $backend;
         $this->config =& $this->backend->getConfig();
         $this->i18n =& $this->backend->getI18N();
@@ -104,10 +111,10 @@ class Ethna_ViewClass
 
     // {{{ preforward
     /**
-     *  ɽ
+     *  画面表示前処理
      *
-     *  ƥץ졼ȤꤹͤǥƥȤ˰¸ʤΤ
-     *  ꤹ(:쥯ȥܥå)
+     *  テンプレートに設定する値でコンテキストに依存しないものは
+     *  ここで設定する(例:セレクトボックス等)
      *
      *  @access public
      */
@@ -118,10 +125,10 @@ class Ethna_ViewClass
 
     // {{{ forward
     /**
-     *  ̾б̤Ϥ
+     *  遷移名に対応する画面を出力する
      *
-     *  üʲ̤ɽä˥С饤ɤɬפ̵
-     *  (preforward()ΤߥС饤ɤɤ)
+     *  特殊な画面を表示する場合を除いて特にオーバーライドする必要は無い
+     *  (preforward()のみオーバーライドすれば良い)
      *
      *  @access public
      */
@@ -135,37 +142,49 @@ class Ethna_ViewClass
 
     // {{{ addActionFormHelper
     /**
-     *  helperե४֥Ȥꤹ
+     *  helperアクションフォームオブジェクトを設定する
      *
+     *  @param  string $action アクション名
+     *  @param  boolean $dynamic_helper 動的フォームヘルパを呼ぶか否か
      *  @access public
      */
-    function addActionFormHelper($action)
+    function addActionFormHelper($action, $dynamic_helper = false)
     {
+        //
+        //  既に追加されている場合は処理をしない
+        //
         if (isset($this->helper_action_form[$action])
             && is_object($this->helper_action_form[$action])) {
             return;
         }
 
+        //    現在のアクションと等しければ、対応する
+        //    アクションフォームを設定
         $ctl =& Ethna_Controller::getInstance();
         if ($action === $ctl->getCurrentActionName()) {
             $this->helper_action_form[$action] =& $this->af;
-            return;
+        } else {
+            //    アクションが異なる場合
+            $form_name = $ctl->getActionFormName($action);
+            if ($form_name === null) {
+                $this->logger->log(LOG_WARNING,
+                    'action form for the action [%s] not found.', $action);
+                return;
+            }
+            $this->helper_action_form[$action] =& new $form_name($ctl);
         }
 
-        $form_name = $ctl->getActionFormName($action);
-        if ($form_name === null) {
-            $this->logger->log(LOG_WARNING,
-                'action form for the action [%s] not found.', $action);
-            return;
+        //   動的フォームを設定するためのヘルパメソッドを呼ぶ
+        if ($dynamic_helper) {
+            $af =& $this->helper_action_form[$action];
+            $af->setFormDef_ViewHelper();
         }
-
-        $this->helper_action_form[$action] =& new $form_name($ctl);
     }
     // }}}
 
     // {{{ clearActionFormHelper
     /**
-     *  helperե४֥Ȥ
+     *  helperアクションフォームオブジェクトを削除する
      *
      *  @access public
      */
@@ -177,18 +196,18 @@ class Ethna_ViewClass
 
     // {{{ _getHelperActionForm
     /**
-     *  ե४֥(helper)
-     *  $action === null  $name ꤵƤȤϡ$name
-     *  ޤΤõ
+     *  アクションフォームオブジェクト(helper)を取得する
+     *  $action === null で $name が指定されているときは、$nameの定義を
+     *  含むものを探す
      *
      *  @access protected
-     *  @param  string  action  륢̾
-     *  @param  string  name    Ƥ뤳ȤԤե̾
-     *  @return object  Ethna_ActionFormޤϷѾ֥
+     *  @param  string  action  取得するアクション名
+     *  @param  string  name    定義されていることを期待するフォーム名
+     *  @return object  Ethna_ActionFormまたは継承オブジェクト
      */
     function &_getHelperActionForm($action = null, $name = null)
     {
-        // $action ꤵƤ
+        // $action が指定されている場合
         if ($action !== null) {
             if (isset($this->helper_action_form[$action])
                 && is_object($this->helper_action_form[$action])) {
@@ -201,13 +220,13 @@ class Ethna_ViewClass
             }
         }
 
-        // ǽ $this->af Ĵ٤
+        // 最初に $this->af を調べる
         $def = $this->af->getDef($name);
         if ($def !== null) {
             return $this->af;
         }
 
-        // $this->helper_action_form Ĵ٤
+        // $this->helper_action_form を順に調べる
         foreach (array_keys($this->helper_action_form) as $action) {
             if (is_object($this->helper_action_form[$action]) === false) {
                 continue;
@@ -219,16 +238,28 @@ class Ethna_ViewClass
             }
         }
 
-        // դʤä
+        // 見付からなかった
         $this->logger->log(LOG_WARNING,
             'action form defining form [%s] not found', $name);
         return null;
     }
     // }}}
 
+    // {{{ resetFormCounter
+    /**
+     *  フォームヘルパ用、内部フォームカウンタをリセットする
+     *
+     *  @access public
+     */
+    function resetFormCounter()
+    {
+        $this->reset_counter = true;
+    }
+    // }}}
+
     // {{{ getFormName
     /**
-     *  ꤵ줿եܤбե̾(w/ )
+     *  指定されたフォーム項目に対応するフォーム名(w/ レンダリング)を取得する
      *
      *  @access public
      */
@@ -250,8 +281,8 @@ class Ethna_ViewClass
 
     // {{{ getFormSubmit
     /**
-     *  submitܥ(襢Ǽ褦
-     *  ƤʤȤˡsubmitܥΤ˻Ȥ)
+     *  submitボタンを取得する(送信先アクションで受け取るよう
+     *  定義されていないときに、たんにsubmitボタンを作るのに使う)
      *
      *  @access public
      */
@@ -266,10 +297,10 @@ class Ethna_ViewClass
 
     // {{{ getFormInput
     /**
-     *  ꤵ줿եܤбեॿ
+     *  指定されたフォーム項目に対応するフォームタグを取得する
      *
      *  @access public
-     *  @todo   JavaScriptб
+     *  @todo   JavaScript対応
      */
     function getFormInput($name, $action, $params)
     {
@@ -287,9 +318,14 @@ class Ethna_ViewClass
             $def['form_type'] = FORM_TYPE_TEXT;
         }
 
-        // եबƤФ줿¸륫
-        if (is_array($def['type'])) {
+        // 配列フォームが何回呼ばれたかを保存するカウンタ
+        if (isset($def['type']) && is_array($def['type'])) {
             static $form_counter = array();
+            if ($this->reset_counter) {
+                $form_counter = array();
+                $this->reset_counter = false;
+            }
+
             if (isset($form_counter[$action]) === false) {
                 $form_counter[$action] = array();
             }
@@ -351,7 +387,7 @@ class Ethna_ViewClass
 
     // {{{ getFormBlock
     /**
-     *  եॿ(type="form")
+     *  フォームタグを取得する(type="form")
      *
      *  @access protected
      */
@@ -368,13 +404,13 @@ class Ethna_ViewClass
 
     // {{{ _getSelectorOptions
     /**
-     *  select, radio, checkbox 
+     *  select, radio, checkbox の選択肢を取得する
      *
      *  @access protected
      */
     function _getSelectorOptions(&$af, $def, $params)
     {
-        // $params, $def νĴ٤
+        // $params, $def の順で調べる
         $source = null;
         if (isset($params['option'])) {
             $source = $params['option'];
@@ -382,18 +418,18 @@ class Ethna_ViewClass
             $source = $def['option'];
         }
 
-        // ̤ or ѤߤξϤΤޤ
+        // 未定義 or 定義済みの場合はそのまま
         if ($source === null) {
             return null;
         } else if (is_array($source)) {
             return $source;
         }
         
-        // 
+        // 選択肢を取得
         $options = null;
         $split = array_map("trim", explode(',', $source));
         if (count($split) === 1) {
-            // եफ
+            // アクションフォームから取得
             $method_or_property = $split[0];
             if (method_exists($af, $method_or_property)) {
                 $options = $af->$method_or_property();
@@ -401,7 +437,7 @@ class Ethna_ViewClass
                 $options = $af->$method_or_property;
             }
         } else {
-            // ޥ͡㤫
+            // マネージャから取得
             $mgr =& $this->backend->getManager($split[0]);
             $attr_list = $mgr->getAttrList($split[1]);
             if (is_array($attr_list)) {
@@ -424,7 +460,7 @@ class Ethna_ViewClass
 
     // {{{ _getFormInput_Button
     /**
-     *  եॿ(type="button")
+     *  フォームタグを取得する(type="button")
      *
      *  @access protected
      */
@@ -442,7 +478,7 @@ class Ethna_ViewClass
                 $params['value'] = $def['name'];
             }
         }
-        if (is_array($params['value'])) {
+        if (isset($params['value']) && is_array($params['value'])) {
             $params['value'] = $params['value'][0];
         }
 
@@ -452,7 +488,7 @@ class Ethna_ViewClass
 
     // {{{ _getFormInput_Checkbox
     /**
-     *  åܥå(type="check")
+     *  チェックボックスタグを取得する(type="check")
      *
      *  @access protected
      */
@@ -465,14 +501,14 @@ class Ethna_ViewClass
             $params['name'] = $name;
         }
 
-        // ץΰ(alist)
+        // オプションの一覧(alist)を取得
         if (isset($def['option']) && is_array($def['option'])) {
             $options = $def['option'];
         } else {
             $options = array();
         }
 
-        // defaultͤ
+        // default値の設定
         if (isset($params['default'])) {
             $current_value = $params['default'];
         } else if (isset($def['default'])) {
@@ -482,11 +518,11 @@ class Ethna_ViewClass
         }
         $current_value = array_map('strval', to_array($current_value));
 
-        // Υѥ졼
+        // タグのセパレータ
         if (isset($params['separator'])) {
             $separator = $params['separator'];
         } else {
-            $separator = '';
+            $separator = "\n";
         }
 
         $ret = array();
@@ -506,7 +542,7 @@ class Ethna_ViewClass
             $input_tag = $this->_getFormInput_Html('input', $params);
 
             // <label for="id">..</label>
-            $ret[] = $this->_getFormInput_Html('label', array('id' => $params['id']),
+            $ret[] = $this->_getFormInput_Html('label', array('for' => $params['id']),
                                                $input_tag . $value, false);
         }
 
@@ -516,7 +552,7 @@ class Ethna_ViewClass
 
     // {{{ _getFormInput_File
     /**
-     *  եॿ(type="file")
+     *  フォームタグを取得する(type="file")
      *
      *  @access protected
      */
@@ -536,7 +572,7 @@ class Ethna_ViewClass
 
     // {{{ _getFormInput_Hidden
     /**
-     *  եॿ(type="hidden")
+     *  フォームタグを取得する(type="hidden")
      *
      *  @access protected
      */
@@ -574,7 +610,7 @@ class Ethna_ViewClass
 
     // {{{ _getFormInput_Password
     /**
-     *  եॿ(type="password")
+     *  フォームタグを取得する(type="password")
      *
      *  @access protected
      */
@@ -606,10 +642,8 @@ class Ethna_ViewClass
             $params['value'] = $value;
         }
 
-        // maxlength
-        if (isset($def['max']) && $def['max']) {
-            $params['maxlength'] = $def['max'];
-        }
+        //   maxlength と フォーム定義のmax連携はサポートしない
+        //   @see http://sourceforge.jp/ticket/browse.php?group_id=1343&tid=16325
 
         return $this->_getFormInput_Html('input', $params);
     }
@@ -617,7 +651,7 @@ class Ethna_ViewClass
 
     // {{{ _getFormInput_Radio
     /**
-     *  饸ܥ󥿥(type="radio")
+     *  ラジオボタンタグを取得する(type="radio")
      *
      *  @access protected
      */
@@ -630,14 +664,14 @@ class Ethna_ViewClass
             $params['name'] = $name;
         }
 
-        // ץΰ(alist)
+        // オプションの一覧(alist)を取得
         if (isset($def['option']) && is_array($def['option'])) {
             $options = $def['option'];
         } else {
             $options = array();
         }
 
-        // defaultͤ
+        // default値の設定
         if (isset($params['default'])) {
             $current_value = $params['default'];
         } else if (isset($def['default'])) {
@@ -646,11 +680,11 @@ class Ethna_ViewClass
             $current_value = null;
         }
 
-        // Υѥ졼
+        // タグのセパレータ
         if (isset($params['separator'])) {
             $separator = $params['separator'];
         } else {
-            $separator = '';
+            $separator = "\n";
         }
 
         $ret = array();
@@ -670,7 +704,7 @@ class Ethna_ViewClass
             $input_tag = $this->_getFormInput_Html('input', $params);
 
             // <label for="id">..</label>
-            $ret[] = $this->_getFormInput_Html('label', array('id' => $params['id']),
+            $ret[] = $this->_getFormInput_Html('label', array('for' => $params['id']),
                                                $input_tag . $value, false);
         }
 
@@ -680,7 +714,7 @@ class Ethna_ViewClass
 
     // {{{ _getFormInput_Select
     /**
-     *  쥯ȥܥå(type="select")
+     *  セレクトボックスタグを取得する(type="select")
      *
      *  @access protected
      */
@@ -692,49 +726,56 @@ class Ethna_ViewClass
             $params['name'] = $name;
         }
 
-        // ץΰ(alist)
+        // オプションの一覧(alist)を取得
         if (isset($def['option']) && is_array($def['option'])) {
             $options = $def['option'];
         } else {
             $options = array();
         }
 
-        // defaultͤ
+        // default値の設定
         if (isset($params['default'])) {
             $current_value = $params['default'];
         } else if (isset($def['default'])) {
             $current_value = $def['default'];
         } else {
-            $current_value = null;
+            $current_value = array();
         }
+        $current_value = array_map('strval', to_array($current_value));
 
-        // Υѥ졼
+        // タグのセパレータ
         if (isset($params['separator'])) {
             $separator = $params['separator'];
         } else {
-            $separator = '';
+            $separator = "\n";
         }
 
-        // selectȤ
+        // selectタグの中身を作る
         $contents = array();
         $selected = false;
         foreach ($options as $key => $value) {
             $attr = array('value' => $key);
-            if ($selected === false && strcmp($current_value, $key) === 0) {
+            $def['_form_counter'] = empty($def['_form_counter']) ? 0 : $def['_form_counter'];
+            if (isset($params['multiple']) &&
+                    in_array((string)$key, $current_value, true) ||
+               !isset($params['multiple']) && $selected === false &&
+                    strcmp($current_value[$def['_form_counter']], $key) === 0) {
                 $attr['selected'] = 'selected';
                 $selected = true;
             }
             $contents[] = $this->_getFormInput_Html('option', $attr, $value);
         }
 
-        // ȥ
+        // 空エントリ
         if (isset($params['emptyoption'])) {
             $attr = array('value' => '');
             if ($selected === false) {
                 $attr['selected'] = 'selected';
             }
-            array_unshift($contents, $this->_getFormInput_Html('option', $attr,
-                                                               $params['emptyoption']));
+            array_unshift($contents,
+                          $this->_getFormInput_Html('option',
+                                                    $attr,
+                                                    $params['emptyoption']));
             unset($params['emptyoption']);
         }
 
@@ -745,7 +786,7 @@ class Ethna_ViewClass
 
     // {{{ _getFormInput_Submit
     /**
-     *  եॿ(type="submit")
+     *  フォームタグを取得する(type="submit")
      *
      *  @access protected
      */
@@ -772,7 +813,7 @@ class Ethna_ViewClass
 
     // {{{ _getFormInput_Textarea
     /**
-     *  եॿ(textarea)
+     *  フォームタグを取得する(textarea)
      *
      *  @access protected
      */
@@ -788,7 +829,6 @@ class Ethna_ViewClass
         $element = '';
         if (isset($params['value'])) {
             $element = $params['value'];
-            unset($params['value']);
         } else if (isset($params['default'])) {
             $element = $params['default'];
         } else if (isset($def['default'])) {
@@ -800,8 +840,6 @@ class Ethna_ViewClass
             } else {
                 $element = '';
             }
-        } else {
-            $params['value'] = $element;
         }
 
         return $this->_getFormInput_Html('textarea', $params, $element);
@@ -810,7 +848,7 @@ class Ethna_ViewClass
 
     // {{{ _getFormInput_Text
     /**
-     *  եॿ(type="text")
+     *  フォームタグを取得する(type="text")
      *
      *  @access protected
      */
@@ -845,10 +883,8 @@ class Ethna_ViewClass
             $params['value'] = $value;
         }
 
-        // maxlength
-        if (isset($def['max']) && $def['max']) {
-            $params['maxlength'] = $def['max'];
-        }
+        //   maxlength と フォーム定義のmax連携はサポートしない
+        //   @see http://sourceforge.jp/ticket/browse.php?group_id=1343&tid=16325
 
         return $this->_getFormInput_Html('input', $params);
     }
@@ -856,13 +892,13 @@ class Ethna_ViewClass
 
     // {{{ _getFormInput_Html
     /**
-     *  HTML
+     *  HTMLタグを取得する
      *
      *  @access protected
      */
     function _getFormInput_Html($tag, $attr, $element = null, $escape_element = true)
     {
-        // פʥѥ᡼Ͼä
+        // 不要なパラメータは消す
         foreach ($this->helper_parameter_keys as $key) {
             unset($attr[$key]);
         }
@@ -891,27 +927,12 @@ class Ethna_ViewClass
 
     // {{{ _getRenderer
     /**
-     *  饪֥Ȥ
+     *  レンダラオブジェクトを取得する
      *
      *  @access protected
-     *  @return object  Ethna_Renderer  饪֥
+     *  @return object  Ethna_Renderer  レンダラオブジェクト
      */
     function &_getRenderer()
-    {
-        $_ret_object =& $this->_getTemplateEngine();
-        return $_ret_object;
-    }
-    // }}}
-
-    // {{{ _getTemplateEngine
-    /**
-     *  饪֥Ȥ(Τ_getRenderer()礵ͽ)
-     *
-     *  @access protected
-     *  @return object  Ethna_Renderer  饪֥
-     *  @obsolete
-     */
-    function &_getTemplateEngine()
     {
         $c =& $this->backend->getController();
         $renderer =& $c->getRenderer();
@@ -929,9 +950,11 @@ class Ethna_ViewClass
             $renderer->setPropByRef('session', $tmp_session);
         }
         $renderer->setProp('script',
-            htmlspecialchars(basename($_SERVER['PHP_SELF']), ENT_QUOTES));
+            htmlspecialchars(basename($_SERVER['SCRIPT_NAME']), ENT_QUOTES));
         $renderer->setProp('request_uri',
-            htmlspecialchars($_SERVER['REQUEST_URI'], ENT_QUOTES));
+            isset($_SERVER['REQUEST_URI'])
+            ? htmlspecialchars($_SERVER['REQUEST_URI'], ENT_QUOTES)
+            : '');
         $renderer->setProp('config', $this->config->get());
 
         return $renderer;
@@ -940,10 +963,10 @@ class Ethna_ViewClass
 
     // {{{ _setDefault
     /**
-     *  ͤꤹ
+     *  共通値を設定する
      *
      *  @access protected
-     *  @param  object  Ethna_Renderer  饪֥
+     *  @param  object  Ethna_Renderer  レンダラオブジェクト
      */
     function _setDefault(&$renderer)
     {
