@@ -3,18 +3,18 @@
 /**
  *  Ethna_Plugin_Cachemanager_Memcache.php
  *
- *  - Point CutȻפä
- *  - å奭ˤ250ʸޤǤѤǤʤΤդƲ
+ *  - Point Cutしたいと思った！
+ *  - キャッシュキーには250文字までしか使用できないので注意して下さい
  *
- *  @todo   ͡ॹڡ/å奭ĹΥ顼ϥɥ
+ *  @todo   ネームスペース/キャッシュキー長のエラーハンドリング
  *
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @package    Ethna
- *  @version    $Id: Ethna_Plugin_Cachemanager_Memcache.php 483 2007-10-30 14:56:00Z cocoitiban $
+ *  @version    $Id$
  */
 
 /**
- *  åޥ͡㥯饹(memcache)
+ *  キャッシュマネージャクラス(memcache版)
  *
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @access     public
@@ -24,16 +24,16 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
 {
     /**#@+  @access private */
 
-    /** @var    object  MemCache    MemCache֥ */
+    /** @var    object  MemCache    MemCacheオブジェクト */
     var $memcache = null;
 
-    /** @var bool ̥ե饰 */
+    /** @var bool 圧縮フラグ */
     var $compress = true;
 
     /**#@-*/
 
     /**
-     *  Ethna_Plugin_Cachemanager_Memcache饹Υ󥹥ȥ饯
+     *  Ethna_Plugin_Cachemanager_Memcacheクラスのコンストラクタ
      *
      *  @access public
      */
@@ -44,7 +44,7 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
     }
 
     /**
-     *  memcacheå奪֥Ȥ
+     *  memcacheキャッシュオブジェクトを生成、取得する
      *
      *  @access protected
      */
@@ -69,10 +69,10 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
         $this->memcache_pool["$host:$port"] =& new MemCache();
 
         while ($retry > 0) {
-            if ($this->config->get('memcache_use_connect')) {
-                $r = $this->memcache_pool["$host:$port"]->connect($host, $port, $timeout);
-            } else {
+            if ($this->config->get('memcache_use_pconnect')) {
                 $r = $this->memcache_pool["$host:$port"]->pconnect($host, $port, $timeout);
+            } else {
+                $r = $this->memcache_pool["$host:$port"]->connect($host, $port, $timeout);
             }
             if ($r) {
                 break;
@@ -90,10 +90,10 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
     }
 
     /**
-     *  memcache³
+     *  memcache接続情報を取得する
      *
      *  @access protected
-     *  @todo   $cache_key$indexˡѹǤ褦ˤ
+     *  @todo   $cache_keyから$indexを決める方法を変更できるようにする
      */
     function _getMemcacheInfo($cache_key, $namespace)
     {
@@ -112,7 +112,7 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
             return array($default_memcache_host, $default_memcache_port);
         }
 
-        // namespace/cache_key³
+        // namespace/cache_keyで接続先を決定
         $n = count($memcache_info[$namespace]);
 
         $index = $cache_key % $n;
@@ -130,18 +130,18 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
     }
 
     /**
-     *  åꤵ줿ͤ
+     *  キャッシュに設定された値を取得する
      *
-     *  åͤꤵƤϥå
-     *  ͤȤʤ롣å̵ͤlifetime
-     *  ᤮Ƥ硢顼ȯPEAR_Error
-     *  ֥ȤͤȤʤ롣
+     *  キャッシュに値が設定されている場合はキャッシュ値
+     *  が戻り値となる。キャッシュに値が無い場合やlifetime
+     *  を過ぎている場合、エラーが発生した場合はEthna_Error
+     *  オブジェクトが戻り値となる。
      *
      *  @access public
-     *  @param  string  $key        å奭
-     *  @param  int     $lifetime   åͭ
-     *  @param  string  $namespace  å͡ॹڡ
-     *  @return array   å
+     *  @param  string  $key        キャッシュキー
+     *  @param  int     $lifetime   キャッシュ有効期間
+     *  @param  string  $namespace  キャッシュネームスペース
+     *  @return array   キャッシュ値
      */
     function get($key, $lifetime = null, $namespace = null)
     {
@@ -164,7 +164,7 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
         $time = $value['time'];
         $data = $value['data'];
 
-        // 饤եå
+        // ライフタイムチェック
         if (is_null($lifetime) == false) {
             if (($time+$lifetime) < time()) {
                 return Ethna::raiseError('lifetime expired', E_CACHE_EXPIRED);
@@ -175,12 +175,12 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
     }
 
     /**
-     *  åκǽ
+     *  キャッシュの最終更新日時を取得する
      *
      *  @access public
-     *  @param  string  $key        å奭
-     *  @param  string  $namespace  å͡ॹڡ
-     *  @return int     ǽ(unixtime)
+     *  @param  string  $key        キャッシュキー
+     *  @param  string  $namespace  キャッシュネームスペース
+     *  @return int     最終更新日時(unixtime)
      */
     function getLastModified($key, $namespace = null)
     {
@@ -202,28 +202,28 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
     }
 
     /**
-     *  ͤå夵Ƥ뤫ɤ
+     *  値がキャッシュされているかどうかを取得する
      *
      *  @access public
-     *  @param  string  $key        å奭
-     *  @param  int     $lifetime   åͭ
-     *  @param  string  $namespace  å͡ॹڡ
+     *  @param  string  $key        キャッシュキー
+     *  @param  int     $lifetime   キャッシュ有効期間
+     *  @param  string  $namespace  キャッシュネームスペース
      */
     function isCached($key, $lifetime = null, $namespace = null)
     {
         $r = $this->get($key, $lifetime, $namespace);
 
-        return PEAR::isError($r) ? false: true;
+        return Ethna::isError($r) ? false: true;
     }
 
     /**
-     *  åͤꤹ
+     *  キャッシュに値を設定する
      *
      *  @access public
-     *  @param  string  $key        å奭
-     *  @param  mixed   $value      å
-     *  @param  int     $timestamp  åǽ(unixtime)
-     *  @param  string  $namespace  å͡ॹڡ
+     *  @param  string  $key        キャッシュキー
+     *  @param  mixed   $value      キャッシュ値
+     *  @param  int     $timestamp  キャッシュ最終更新時刻(unixtime)
+     *  @param  string  $namespace  キャッシュネームスペース
      */
     function set($key, $value, $timestamp = null, $namespace = null)
     {
@@ -244,11 +244,11 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
     }
 
     /**
-     *  åͤ
+     *  キャッシュ値を削除する
      *
      *  @access public
-     *  @param  string  $key        å奭
-     *  @param  string  $namespace  å͡ॹڡ
+     *  @param  string  $key        キャッシュキー
+     *  @param  string  $namespace  キャッシュネームスペース
      */
     function clear($key, $namespace = null)
     {
@@ -268,13 +268,13 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
     }
 
     /**
-     *  åǡå
+     *  キャッシュデータをロックする
      *
      *  @access public
-     *  @param  string  $key        å奭
-     *  @param  int     $timeout    åॢ
-     *  @param  string  $namespace  å͡ॹڡ
-     *  @return bool    true: false:
+     *  @param  string  $key        キャッシュキー
+     *  @param  int     $timeout    ロックタイムアウト
+     *  @param  string  $namespace  キャッシュネームスペース
+     *  @return bool    true:成功 false:失敗
      */
     function lock($key, $timeout = 5, $namespace = null)
     {
@@ -283,7 +283,7 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
             return Ethna::raiseError('memcache server not available', E_CACHE_LOCK_ERROR);
         }
 
-        // åѥåǡѤ
+        // ロック用キャッシュデータを利用する
         $namespace = is_null($namespace) ? $this->namespace : $namespace;
         $cache_key = "lock::" . $this->_getCacheKey($namespace, $key);
         $lock_lifetime = 30;
@@ -305,12 +305,12 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
     }
 
     /**
-     *  åǡΥå
+     *  キャッシュデータのロックを解除する
      *
      *  @access public
-     *  @param  string  $key        å奭
-     *  @param  string  $namespace  å͡ॹڡ
-     *  @return bool    true: false:
+     *  @param  string  $key        キャッシュキー
+     *  @param  string  $namespace  キャッシュネームスペース
+     *  @return bool    true:成功 false:失敗
      */
     function unlock($key, $namespace = null)
     {
@@ -326,13 +326,13 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
     }
 
     /**
-     *  ͡ॹڡ饭å奭
+     *  ネームスペースからキャッシュキーを生成する
      *
      *  @access private
      */
     function _getCacheKey($namespace, $key)
     {
-        // ˽...
+        // 少し乱暴だけど...
         $key = str_replace(":", "_", $key);
         $cache_key = $namespace . "::" . $key;
         if (strlen($cache_key) > 250) {
@@ -342,12 +342,12 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
     }
 
     /**
-     * ̥ե饰ΩƤ
+     * 圧縮フラグを立てる
      *
-     * MySQLʤɤĤλҥ饹ͭ
+     * MySQLなどいくつかの子クラスで有効
      * 
      * @access public
-     * @param bool $flag ե饰
+     * @param bool $flag フラグ
      */
     function setCompress($flag) {
         $this->compress = $flag;
