@@ -6,14 +6,14 @@
  *  @author     Keita Arai <cocoiti@comio.info>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Plugin_Csrf_Session.php 395 2006-11-09 12:58:16Z cocoitiban $
+ *  @version    $Id$
  */
 
 // {{{ Ethna_Plugin_Csrf_Session
 /**
- *  CSRFк
+ *  CSRF対策
  *
- *  CSRFкȡѤк뤿Υ
+ *  CSRF対策をトークンを用いて対策するためのコード
  *
  *  @author     Keita Arai <cocoiti@comio.info>
  *  @access     public
@@ -25,31 +25,31 @@ class Ethna_Plugin_Csrf_Session extends Ethna_Plugin_Csrf
      *  @access private
      */
 
-    /** @var    object  Ethna_Session    å󥪥֥ */
+    /** @var    object  Ethna_Session    セッションオブジェクト */
     var $session;
     
     /**#@-*/
 
 
     /**
-     *  Ethna_Plugin_CsrfΥ󥹥ȥ饯
+     *  Ethna_Plugin_Csrfのコンストラクタ
      *
      *  @access public
-     *  @param  object  Ethna_Controller    &$controller    ȥ饪֥
+     *  @param  object  Ethna_Controller    &$controller    コントローラオブジェクト
      */
     function Ethna_Plugin_Csrf_Session(&$controller)
     {
         parent::Ethna_Plugin_Csrf($controller);
 
-        // ֥Ȥ
+        // オブジェクトの設定
         $this->session =& $this->controller->getSession();
     }
     
     /**
-     *  ȡViewȥե˥åȤ
+     *  トークンをViewとローカルファイルにセットする
      *
      *  @access public
-     *  @return boolean  Ԥ
+     *  @return boolean  成功か失敗か
      */
     function set()
     {
@@ -69,10 +69,10 @@ class Ethna_Plugin_Csrf_Session extends Ethna_Plugin_Csrf
     }
 
     /**
-     *  ȡID
+     *  トークンIDを取得する
      *
      *  @access public
-     *  @return string ȡID֤
+     *  @return string トークンIDを返す。
      */
     function get()
     {
@@ -84,7 +84,7 @@ class Ethna_Plugin_Csrf_Session extends Ethna_Plugin_Csrf
     }
 
     /**
-     *  ȡID
+     *  トークンIDを削除する
      *
      *  @access public
      */
@@ -93,7 +93,7 @@ class Ethna_Plugin_Csrf_Session extends Ethna_Plugin_Csrf
         if (! $this->session->isStart()) {
             $this->session->start();
         }
-        $this->session->remove($this->token_name, $token);        
+        $this->session->remove($this->token_name);        
     }
 }
 // }}}
