@@ -6,12 +6,12 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Plugin_Generator_ViewTest.php 411 2006-11-17 02:32:32Z ichii386 $
+ *  @version    $Id$
  */
 
 // {{{ Ethna_Plugin_Generator_ViewTest
 /**
- *  ȥ饹
+ *  スケルトン生成クラス
  *
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @access     public
@@ -20,12 +20,12 @@
 class Ethna_Plugin_Generator_ViewTest extends Ethna_Plugin_Generator
 {
     /**
-     *  ӥ塼ѥƥȤΥȥ
+     *  ビュー用テストのスケルトンを生成する
      *
      *  @access public
-     *  @param  string  $forward_name   ӥ塼̾
-     *  @param  string  $skelton        ȥե̾
-     *  @return true|Ethna_Error        true: Ethna_Error:
+     *  @param  string  $forward_name   ビュー名
+     *  @param  string  $skelton        スケルトンファイル名
+     *  @return true|Ethna_Error        true:成功 Ethna_Error:失敗
      */
     function &generate($forward_name, $skelton = null, $gateway = GATEWAY_WWW)
     {
@@ -49,6 +49,16 @@ class Ethna_Plugin_Generator_ViewTest extends Ethna_Plugin_Generator
         $macro['view_class'] = $view_class;
         $macro['view_path'] = $view_path;
 
+        // original view script existence check.
+        $original_view_path = $this->ctl->getDefaultViewPath($forward_name);
+        $original_view_entity = $view_dir . $original_view_path;
+        if (!file_exists($original_view_entity)) {
+            printf("\n");
+            printf("[!!!!warning!!!!] original view script was not found.\n");
+            printf("[!!!!warning!!!!] You must generate it by the following command :\n");
+            printf("[!!!!warning!!!!] ethna add-view %s\n\n", $forward_name);
+        } 
+
         // user macro
         $user_macro = $this->_getUserMacro();
         $macro = array_merge($macro, $user_macro);
