@@ -8,7 +8,7 @@
  *  @package    Ethna
  */
 
-require_once ETHNA_BASE . '/class/Plugin/Handle/Ethna_Plugin_Handle_AddAction.php';
+require_once ETHNA_BASE . '/class/Plugin/Handle/Ethna_Plugin_Handle_AddView.php';
 
 // {{{ Ethna_Plugin_Handle_AddTemplate
 /**
@@ -18,7 +18,7 @@ require_once ETHNA_BASE . '/class/Plugin/Handle/Ethna_Plugin_Handle_AddAction.ph
  *  @access     public
  *  @package    Ethna
  */
-class Ethna_Plugin_Handle_AddTemplate extends Ethna_Plugin_Handle_AddAction
+class Ethna_Plugin_Handle_AddTemplate extends Ethna_Plugin_Handle_AddView
 {
     /**
      *  add template 
@@ -27,7 +27,13 @@ class Ethna_Plugin_Handle_AddTemplate extends Ethna_Plugin_Handle_AddAction
      */
     function perform()
     {
-        $r =& $this->_getopt(array('basedir=', 'skelfile='));
+        $r =& $this->_getopt(
+                  array('basedir=',
+                        'skelfile=',
+                        'locale=',
+                        'encoding=',
+                  )
+              ); 
         if (Ethna::isError($r)) {
             return $r;
         }
@@ -35,10 +41,16 @@ class Ethna_Plugin_Handle_AddTemplate extends Ethna_Plugin_Handle_AddAction
 
         // template
         $template = array_shift($arg_list);
+        if ($template == null) {
+            return Ethna::raiseError('template name isn\'t set.', 'usage');
+        }
+        $r =& Ethna_Controller::checkViewName($template); // XXX: use checkViewName().
+        if (Ethna::isError($r)) {
+            return $r;
+        }
 
         // add template
-        $ret =& $this->_perform('Template', $template, $opt_list);
-
+        $ret =& $this->_performTemplate($template, $opt_list);
         return $ret;
     }
 
@@ -51,7 +63,7 @@ class Ethna_Plugin_Handle_AddTemplate extends Ethna_Plugin_Handle_AddAction
     {
         return <<<EOS
 add new template to project:
-    {$this->id} [-b|--basedir=dir] [-s|--skelfile=file] [template]
+    {$this->id} [-b|--basedir=dir] [-s|--skelfile=file] [-l|--locale=locale] [-e|--encoding] [template]
 
 EOS;
     }
@@ -62,7 +74,7 @@ EOS;
     function getUsage()
     {
         return <<<EOS
-ethna {$this->id} [-b|--basedir=dir] [-s|--skelfile=file] [template]
+ethna {$this->id} [-b|--basedir=dir] [-s|--skelfile=file] [-l|--locale=locale] [-e|--encoding] [template]
 EOS;
     }
 }
