@@ -6,10 +6,10 @@
  *  @author     ICHII Takashi <ichii386@schweetheart.jp>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Plugin_Validator_File.php 460 2007-04-11 13:12:30Z cocoitiban $
+ *  @version    $Id$
  */
 
-// UPLOAD_ERR_* ̤ξ
+// UPLOAD_ERR_* が未定義の場合
 if (defined('UPLOAD_ERR_OK') == false) { // PHP 4.3.0
     define('UPLOAD_ERR_OK', 0);
 }
@@ -34,7 +34,7 @@ if (defined('UPLOAD_ERR_CANT_WRITE') == false) { // PHP 5.1.0
 
 // {{{ Ethna_Plugin_Validator_File
 /**
- *  եåץ饰
+ *  ファイルチェックプラグイン
  *
  *  @author     ICHII Takashi <ichii386@schweetheart.jp>
  *  @access     public
@@ -42,17 +42,17 @@ if (defined('UPLOAD_ERR_CANT_WRITE') == false) { // PHP 5.1.0
  */
 class Ethna_Plugin_Validator_File extends Ethna_Plugin_Validator
 {
-    /** @var    bool    뤫ե饰 */
+    /** @var    bool    配列を受け取るかフラグ */
     var $accept_array = false;
 
     /**
-     *  åץɤ줿եΥåԤ
-     *  XXX: ץ饰Υ顼ɤ
+     *  アップロードされたファイルのチェックを行う
+     *  XXX: プラグインのエラーコードを修正する
      *
      *  @access public
-     *  @param  string  $name       ե̾
-     *  @param  mixed   $var        ե
-     *  @param  array   $params     ץ饰Υѥ᡼
+     *  @param  string  $name       フォームの名前
+     *  @param  mixed   $var        フォームの値
+     *  @param  array   $params     プラグインのパラメータ
      */
     function &validate($name, $var, $params)
     {
@@ -61,32 +61,32 @@ class Ethna_Plugin_Validator_File extends Ethna_Plugin_Validator
             return $true;
         }
 
-        // ⤽⥢åץɤƤʤϥå
+        // そもそもアップロードされていない場合はスキップ
         if ($var['error'] == UPLOAD_ERR_NO_FILE) {
             return $true;
         }
 
 
-        // 顼ɤθ
+        // エラーコードの検査
         $msg = '';
         switch ($var['error']) {
         case UPLOAD_ERR_INI_SIZE: 
-            $msg = 'åץɤ줿եϡphp.ini  upload_max_filesize ǥ쥯ƥ֤ͤĶƤޤ';
+            $msg = _et("Uploaded file size exceeds php.ini's upload_max_filesize directive.");
             break;
         case UPLOAD_ERR_FORM_SIZE:
-            $msg = 'åץɤ줿եϡHTML եǻꤵ줿 MAX_FILE_SIZE ĶƤޤ';
+            $msg = _et('Uploaded File size exceeds MAX_FILE_SIZE specified in HTML Form.');
             break;
         case UPLOAD_ERR_PARTIAL:
-            $msg= 'åץɤ줿եϰΤߤåץɤƤޤ';
+            $msg= _et('File was only uploaded patially.');
             break;
         case UPLOAD_ERR_NO_FILE:
-            $msg = 'եϥåץɤޤǤ';
+            $msg = _et('File was not uploaded.');
             break;
         case UPLOAD_ERR_NO_TMP_DIR:
-            $msg = 'ƥݥեޤ';
+            $msg = _et('Temporary folder was not found.');
             break;
         case UPLOAD_ERR_CANT_WRITE:
-            $msg= 'ǥؤν񤭹ߤ˼Ԥޤ';
+            $msg= _et('Could not write uploaded file to disk.');
             break;
         }
         if ($msg != '') {
@@ -97,25 +97,24 @@ class Ethna_Plugin_Validator_File extends Ethna_Plugin_Validator
         }
 
 
-        // tmp_name θ
+        // tmp_name の検査
         if (isset($var['tmp_name']) == false || is_uploaded_file($var['tmp_name']) == false) {
             if (isset($params['error'])) {
                 $msg = $params['error'];
             } else {
-                $msg = 'tmp_name Ǥ';
+                $msg = _et('invalid tmp_name.');
             }
             return Ethna::raiseNotice($msg, E_FORM_WRONGTYPE_FILE);
         }
 
-
-        // size θ
+        // size の検査
         if (isset($params['size_max'])) {
             $st = stat($var['tmp_name']);
             if ($st[7] > $this->_getSizeAsBytes($params['size_max'])) {
                 if (isset($params['error'])) {
                     $msg = $params['error'];
                 } else {
-                    $msg = 'ե륵%sʲˤƤ';
+                    $msg = _et('Uploaded file size must be less than %s.');
                 }
                 return Ethna::raiseNotice($msg, E_FORM_WRONGTYPE_FILE, array($params['size_max']));
             }
@@ -126,14 +125,14 @@ class Ethna_Plugin_Validator_File extends Ethna_Plugin_Validator
                 if (isset($params['error'])) {
                     $msg = $params['error'];
                 } else {
-                    $msg = 'ե륵%sʾˤƤ';
+                    $msg = _et('Uploaded file size must be more than %s.');
                 }
                 return Ethna::raiseNotice($msg, E_FORM_WRONGTYPE_FILE, array($params['size_min']));
             }
         }
 
 
-        // type θ
+        // type の検査
         if (isset($params['type'])) {
             $type_list = to_array($params['type']);
             $posted_mime = explode('/', $var['type'], 2);
@@ -150,13 +149,13 @@ class Ethna_Plugin_Validator_File extends Ethna_Plugin_Validator
                 if (isset($params['error'])) {
                     $msg = $params['error'];
                 } else {
-                    $msg = 'ե륿פޤ';
+                    $msg = _et('Invalid file type.');
                 }
                 return Ethna::raiseNotice($msg, E_FORM_WRONGTYPE_FILE);
             }
         }
 
-        // name(ե̾)θ
+        // name(ファイル名)の検査
         if (isset($params['name'])) {
             $test = ($params['name']{0} == '/')
                 ? preg_match($params['name'], $var['name'])
@@ -165,7 +164,7 @@ class Ethna_Plugin_Validator_File extends Ethna_Plugin_Validator
                 if (isset($params['error'])) {
                     $msg = $params['error'];
                 } else {
-                    $msg = 'ե̾ޤ';
+                    $msg = _et('Invalid file name.');
                 }
                 return Ethna::raiseNotice($msg, E_FORM_WRONGTYPE_FILE);
             }
