@@ -6,12 +6,12 @@
  *  @author     ICHII Takashi <ichii386@schweetheart.jp>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Plugin_Validator_Regexp.php 318 2006-08-11 10:26:00Z ichii386 $
+ *  @version    $Id$
  */
 
 // {{{ Ethna_Plugin_Validator_Regexp
 /**
- *  ɽˤХǡץ饰
+ *  正規表現によるバリデータプラグイン
  *
  *  @author     ICHII Takashi <ichii386@schweetheart.jp>
  *  @access     public
@@ -19,16 +19,16 @@
  */
 class Ethna_Plugin_Validator_Regexp extends Ethna_Plugin_Validator
 {
-    /** @var    bool    뤫ե饰 */
+    /** @var    bool    配列を受け取るかフラグ */
     var $accept_array = false;
 
     /**
-     *  ɽˤեͤΥåԤ
+     *  正規表現によるフォーム値のチェックを行う
      *
      *  @access public
-     *  @param  string  $name       ե̾
-     *  @param  mixed   $var        ե
-     *  @param  array   $params     ץ饰Υѥ᡼
+     *  @param  string  $name       フォームの名前
+     *  @param  mixed   $var        フォームの値
+     *  @param  array   $params     プラグインのパラメータ
      */
     function &validate($name, $var, $params)
     {
@@ -43,7 +43,7 @@ class Ethna_Plugin_Validator_Regexp extends Ethna_Plugin_Validator
             if (isset($params['error'])) {
                 $msg = $params['error'];
             } else {
-                $msg = "{form}ϤƤ";
+                $msg = _et('Please input {form} properly.');
             }
             return Ethna::raiseNotice($msg, E_FORM_REGEXP);
         }
