@@ -6,12 +6,12 @@
  *  @author     ICHII Takashi <ichii386@schweetheart.jp>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Plugin_Validator_Type.php 298 2006-07-19 05:22:39Z fujimoto $
+ *  @version    $Id$
  */
 
 // {{{ Ethna_Plugin_Validator_Type
 /**
- *  ץåץ饰
+ *  タイプチェックプラグイン
  *
  *  @author     ICHII Takashi <ichii386@schweetheart.jp>
  *  @access     public
@@ -19,16 +19,16 @@
  */
 class Ethna_Plugin_Validator_Type extends Ethna_Plugin_Validator
 {
-    /** @var    bool    뤫ե饰 */
+    /** @var    bool    配列を受け取るかフラグ */
     var $accept_array = false;
 
     /**
-     *  եͤηåԤ
+     *  フォーム値の型チェックを行う
      *
      *  @access public
-     *  @param  string  $name       ե̾
-     *  @param  mixed   $var        ե
-     *  @param  array   $params     ץ饰Υѥ᡼
+     *  @param  string  $name       フォームの名前
+     *  @param  mixed   $var        フォームの値
+     *  @param  array   $params     プラグインのパラメータ
      */
     function &validate($name, $var, $params)
     {
@@ -45,7 +45,7 @@ class Ethna_Plugin_Validator_Type extends Ethna_Plugin_Validator
                         if (isset($params['error'])) {
                             $msg = $params['error'];
                         } else {
-                            $msg = "{form}ˤϿ()ϤƲ";
+                            $msg = _et('Please input integer value to {form}.');
                         }
                         return Ethna::raiseNotice($msg, E_FORM_WRONGTYPE_INT);
                     }
@@ -56,7 +56,7 @@ class Ethna_Plugin_Validator_Type extends Ethna_Plugin_Validator
                         if (isset($params['error'])) {
                             $msg = $params['error'];
                         } else {
-                            $msg = "{form}ˤϿ()ϤƲ";
+                            $msg = _et('Please input float value to {form}.');
                         }
                         return Ethna::raiseNotice($msg, E_FORM_WRONGTYPE_FLOAT);
                     }
@@ -67,7 +67,7 @@ class Ethna_Plugin_Validator_Type extends Ethna_Plugin_Validator
                         if (isset($params['error'])) {
                             $msg = $params['error'];
                         } else {
-                            $msg = "{form}ˤ1ޤ0ΤϤǤޤ";
+                            $msg = _et('You can input 0 or 1 to {form}.');
                         }
                         return Ethna::raiseNotice($msg, E_FORM_WRONGTYPE_BOOLEAN);
                     }
@@ -79,7 +79,7 @@ class Ethna_Plugin_Validator_Type extends Ethna_Plugin_Validator
                         if (isset($params['error'])) {
                             $msg = $params['error'];
                         } else {
-                            $msg = "{form}ˤդϤƲ";
+                            $msg = _et('Please input valid datetime to {form}.');
                         }
                         return Ethna::raiseNotice($msg, E_FORM_WRONGTYPE_DATETIME);
                     }
@@ -91,4 +91,5 @@ class Ethna_Plugin_Validator_Type extends Ethna_Plugin_Validator
     }
 }
 // }}}
+
 ?>
