@@ -6,14 +6,13 @@
  *  @author     Kazuhiro Hosoi <hosoi@gree.co.jp>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Renderer_Smarty.php 453 2007-01-17 18:38:51Z ichii386 $
+ *  @version    $Id$
  */
 require_once 'Smarty/Smarty.class.php';
-require_once ETHNA_BASE . '/class/Ethna_SmartyPlugin.php';
 
 // {{{ Ethna_Renderer_Smarty
 /**
- *  Smarty饯饹MojaviΤޤ͡
+ *  Smartyレンダラクラス（Mojaviのまね）
  *
  *  @author     Kazuhiro Hosoi <hosoi@gree.co.jp>
  *  @access     public
@@ -25,7 +24,7 @@ class Ethna_Renderer_Smarty extends Ethna_Renderer
     var $compile_dir;
     
     /**
-     *  Ethna_Renderer_Smarty饹Υ󥹥ȥ饯
+     *  Ethna_Renderer_Smartyクラスのコンストラクタ
      *
      *  @access public
      */
@@ -35,6 +34,8 @@ class Ethna_Renderer_Smarty extends Ethna_Renderer
         
         $this->engine =& new Smarty;
         
+        // ディレクトリ関連は Controllerによって実行時に設定
+        // TODO: iniファイルによって上書き可にするかは要検討
         $template_dir = $controller->getTemplatedir();
         $compile_dir = $controller->getDirectory('template_c');
 
@@ -44,59 +45,33 @@ class Ethna_Renderer_Smarty extends Ethna_Renderer
         $this->engine->compile_dir = $this->compile_dir;
         $this->engine->compile_id = md5($this->template_dir);
 
-        // ФäƤߤ
+        //  デリミタは Ethna_Config を見る
+        $smarty_config = isset($this->config['smarty'])
+                       ? $this->config['smarty']
+                       : array();
+        if (array_key_exists('left_delimiter', $smarty_config)) {
+            $this->engine->left_delimiter = $smarty_config['left_delimiter'];
+        }
+        if (array_key_exists('right_delimiter', $smarty_config)) {
+            $this->engine->right_delimiter = $smarty_config['right_delimiter'];
+        }
+
+        // コンパイルディレクトリは必須なので一応がんばってみる
         if (is_dir($this->engine->compile_dir) === false) {
             Ethna_Util::mkdir($this->engine->compile_dir, 0755);
         }
 
-        $this->engine->plugins_dir = array_merge(array(SMARTY_DIR . 'plugins'),
-                                                 $controller->getDirectory('plugins'));
-
-        $this->_setDefaultPlugin();
+        $this->engine->plugins_dir = array_merge(
+            $controller->getDirectory('plugins'),
+            array(ETHNA_BASE . '/class/Plugin/Smarty', SMARTY_DIR . 'plugins')
+        );
     }
     
     /**
-     *  ǥեȤ.
+     *  ビューを出力する
      *
-     *  @access public
-     */
-    function _setDefaultPlugin()
-    {
-        // default modifiers
-        $this->setPlugin('number_format','modifier','smarty_modifier_number_format');
-        $this->setPlugin('strftime','modifier','smarty_modifier_strftime');
-        $this->setPlugin('count','modifier','smarty_modifier_count');
-        $this->setPlugin('join','modifier','smarty_modifier_join');
-        $this->setPlugin('filter','modifier', 'smarty_modifier_filter');
-        $this->setPlugin('unique','modifier','smarty_modifier_unique');
-        $this->setPlugin('wordwrap_i18n','modifier','smarty_modifier_wordwrap_i18n');
-        $this->setPlugin('truncate_i18n','modifier','smarty_modifier_truncate_i18n');
-        $this->setPlugin('i18n','modifier','smarty_modifier_i18n');
-        $this->setPlugin('checkbox','modifier','smarty_modifier_checkbox');
-        $this->setPlugin('select','modifier','smarty_modifier_select');
-        $this->setPlugin('form_value','modifier','smarty_modifier_form_value');
-
-        // default functions
-        $this->setPlugin('is_error','function','smarty_function_is_error');
-        $this->setPlugin('message','function','smarty_function_message');
-        $this->setPlugin('uniqid','function','smarty_function_uniqid');
-        $this->setPlugin('select','function','smarty_function_select');
-        $this->setPlugin('checkbox_list','function','smarty_function_checkbox_list');
-        $this->setPlugin('form_name','function','smarty_function_form_name');
-        $this->setPlugin('form_input','function','smarty_function_form_input');
-        $this->setPlugin('form_submit','function','smarty_function_form_submit');
-        $this->setPlugin('url','function','smarty_function_url');
-        $this->setPlugin('csrfid','function','smarty_function_csrfid');
-
-        // default blocks
-        $this->setPlugin('form','block','smarty_block_form');       
-    }
-
-    /**
-     *  ӥ塼Ϥ
-     *
-     *  @param  string  $template   ƥץ졼̾
-     *  @param  bool    $capture    true ʤнϤɽ֤
+     *  @param  string  $template   テンプレート名
+     *  @param  bool    $capture    true ならば出力を表示せずに返す
      *
      *  @access public
      */
@@ -124,11 +99,11 @@ class Ethna_Renderer_Smarty extends Ethna_Renderer
     }
     
     /**
-     * ƥץ졼ѿ
+     * テンプレート変数を取得する
      * 
-     *  @param string $name  ѿ̾
+     *  @param string $name  変数名
      *
-     *  @return mixedѿ
+     *  @return mixed　変数
      *
      *  @access public
      */
@@ -143,9 +118,9 @@ class Ethna_Renderer_Smarty extends Ethna_Renderer
     }
 
     /**
-     *  ƥץ졼ѿ
+     *  テンプレート変数を削除する
      * 
-     *  @param name    ѿ̾
+     *  @param name    変数名
      * 
      *  @access public
      */
@@ -155,7 +130,7 @@ class Ethna_Renderer_Smarty extends Ethna_Renderer
     }
 
     /**
-     *  ƥץ졼ѿƤ
+     *  テンプレート変数に配列を割り当てる
      * 
      *  @param array $array
      * 
@@ -167,7 +142,7 @@ class Ethna_Renderer_Smarty extends Ethna_Renderer
     }
 
     /**
-     *  ƥץ졼ѿ򻲾ȤȤƳƤ
+     *  テンプレート変数に配列を参照として割り当てる
      * 
      *  @param array $array
      * 
@@ -179,10 +154,10 @@ class Ethna_Renderer_Smarty extends Ethna_Renderer
     }
 
     /**
-     *  ƥץ졼ѿƤ
+     *  テンプレート変数を割り当てる
      * 
-     *  @param string $name ѿ̾
-     *  @param mixed $value 
+     *  @param string $name 変数名
+     *  @param mixed $value 値
      * 
      *  @access public
      */
@@ -192,10 +167,10 @@ class Ethna_Renderer_Smarty extends Ethna_Renderer
     }
 
     /**
-     *  ƥץ졼ѿ˻ȤƤ
+     *  テンプレート変数に参照を割り当てる
      * 
-     *  @param string $name ѿ̾
-     *  @param mixed $value 
+     *  @param string $name 変数名
+     *  @param mixed $value 値
      * 
      *  @access public
      */
@@ -205,40 +180,40 @@ class Ethna_Renderer_Smarty extends Ethna_Renderer
     }
 
     /**
-     *  ץ饰򥻥åȤ
+     *  プラグインをセットする
      * 
-     *  @param string $nameץ饰̾
-     *  @param string $type ץ饰󥿥
-     *  @param mixed $plugin ץ饰
+     *  @param string $name　プラグイン名
+     *  @param string $type プラグインタイプ
+     *  @param mixed $plugin プラグイン本体
      * 
      *  @access public
      */
     function setPlugin($name, $type, $plugin) 
     {
-        //ץ饰ؿ̵ͭå
+        //プラグイン関数の有無をチェック
         if (is_callable($plugin) === false) {
             return Ethna::raiseWarning('Does not exists.');
         }
 
-        //ץ饰μå
+        //プラグインの種類をチェック
         $register_method = 'register_' . $type;
         if (method_exists($this->engine, $register_method) === false) {
             return Ethna::raiseWarning('This plugin type does not exist');
         }
 
-        // ե륿̾ʤϿ
+        // フィルタは名前なしで登録
         if ($type === 'prefilter' || $type === 'postfilter' || $type === 'outputfilter') {
             parent::setPlugin($name, $type, $plugin);
             $this->engine->$register_method($plugin);
             return;
         }
         
-        // ץ饰̾å
+        // プラグインの名前をチェック
         if ($name === '') {
             return Ethna::raiseWarning('Please set plugin name');
         }
        
-        // ץ饰Ͽ
+        // プラグインを登録する
         parent::setPlugin($name, $type, $plugin);
         $this->engine->$register_method($name, $plugin);
     }
