@@ -5,12 +5,12 @@
  *
  *  @author     {$author}
  *  @package    {$project_id}
- *  @version    $Id: app.actionform.php,v 1.1 2006/08/22 15:52:26 fujimoto Exp $
+ *  @version    $Id$
  */
 
 // {{{ {$project_id}_ActionForm
 /**
- *  ե९饹
+ *  ActionForm class.
  *
  *  @author     {$author}
  *  @package    {$project_id}
@@ -22,20 +22,17 @@ class {$project_id}_ActionForm extends Ethna_ActionForm
      *  @access private
      */
 
-    /** @var    array   ե(ǥե) */
+    /** @var    array   form definition (default) */
     var $form_template = array();
 
-    /** @var    bool    Хǡ˥ץ饰Ȥե饰 */
-    var $use_validator_plugin = true;
-
     /**#@-*/
 
     /**
-     *  ե͸ڤΥ顼Ԥ
+     *  Error handling of form input validation.
      *
      *  @access public
-     *  @param  string      $name   ե̾
-     *  @param  int         $code   顼
+     *  @param  string      $name   form item name.
+     *  @param  int         $code   error code.
      */
     function handleError($name, $code)
     {
@@ -43,11 +40,11 @@ class {$project_id}_ActionForm extends Ethna_ActionForm
     }
 
     /**
-     *  եƥץ졼Ȥꤹ
+     *  setter method for form template.
      *
      *  @access protected
-     *  @param  array   $form_template  եͥƥץ졼
-     *  @return array   եͥƥץ졼
+     *  @param  array   $form_template  form template
+     *  @return array   form template after setting.
      */
     function _setFormTemplate($form_template)
     {
@@ -55,7 +52,7 @@ class {$project_id}_ActionForm extends Ethna_ActionForm
     }
 
     /**
-     *  եꤹ
+     *  setter method for form definition.
      *
      *  @access protected
      */
@@ -66,4 +63,5 @@ class {$project_id}_ActionForm extends Ethna_ActionForm
 
 }
 // }}}
+
 ?>
