@@ -4,11 +4,11 @@
  *
  *  @author     {$author}
  *  @package    {$project_id}
- *  @version    $Id: skel.action_test.php 503 2008-04-25 04:06:08Z mumumu-org $
+ *  @version    $Id$
  */
 
 /**
- *  {$action_name}եΥƥȥ
+ *  {$action_name} Form testcase.
  *
  *  @author     {$author}
  *  @access     public
@@ -18,46 +18,46 @@ class {$action_form}_TestCase extends Ethna_UnitTestCase
 {
     /**
      *  @access private
-     *  @var    string  ̾
+     *  @var    string  Action name.
      */
     var $action_name = '{$action_name}';
 
     /**
-     *    ƥȤν
+     *  initialize test.
      *
-     *    @access public
+     *  @access public
      */
     function setUp()
     {
-        $this->createActionForm();  // եκ
+        $this->createActionForm();  // create ActionForm.
     }
 
     /**
-     *    ƥȤθ
+     *  clean up testcase.
      *
-     *    @access public
+     *  @access public
      */
     function tearDown()
     {
     }
 
     /**
-     *  {$action_name}եΥץƥȥ
+     *  {$action_name} ActionForm sample testcase.
      *
      *  @access public
      */
     function test_formSample()
     {
         /*
-        // ե
+        // setting form input.
         $this->af->set('id', 1);
 
-        // {$action_name}ե͸
+        // {$action_name} ActionForm input validation.
         $this->assertEqual($this->af->validate(), 0);
         */
 
         /**
-         *  TODO: ƥȥ򵭽ҤƲ
+         *  TODO: write test case! :)
          *  @see http://simpletest.org/en/first_test_tutorial.html
          *  @see http://simpletest.org/en/unit_test_documentation.html
          */
@@ -66,7 +66,7 @@ class {$action_form}_TestCase extends Ethna_UnitTestCase
 }
 
 /**
- *  {$action_name}Υƥȥ
+ *  {$action_name} Action testcase.
  *
  *  @author     {$author}
  *  @access     public
@@ -76,63 +76,64 @@ class {$action_class}_TestCase extends Ethna_UnitTestCase
 {
     /**
      *  @access private
-     *  @var    string  ̾
+     *  @var    string  Action name.
      */
     var $action_name = '{$action_name}';
 
     /**
-     *    ƥȤν
+     * initialize test.
      *
-     *    @access public
+     * @access public
      */
     function setUp()
     {
-        $this->createActionForm();  // եκ
-        $this->createActionClass(); // 󥯥饹κ
+        $this->createActionForm();  // create ActionForm.
+        $this->createActionClass(); // create ActionClass.
 
-        $this->session->start();            // åγ
+        $this->session->start();    // start session.
     }
 
     /**
-     *    ƥȤθ
+     *  clean up testcase.
      *
-     *    @access public
+     *  @access public
      */
     function tearDown()
     {
-        $this->session->destroy();      // å˴
+        $this->session->destroy();   // destroy session.
     }
 
     /**
-     *  {$action_name}󥯥饹Υץƥȥ
+     *  {$action_name} ActionClass sample testcase.
      *
      *  @access public
      */
     function test_actionSample()
     {
         /*
-        // ե
+        // setting form input.
         $this->af->set('id', 1);
 
-        // {$action_name}¹ǧڽ
+        // Authentication before processing {$action_name} Action.
         $forward_name = $this->ac->authenticate();
         $this->assertNull($forward_name);
 
-        // {$action_name}
+        // {$action_name} Action preprocess.
         $forward_name = $this->ac->prepare();
         $this->assertNull($forward_name);
 
-        // {$action_name}μ
+        // {$action_name} Action implementation.
         $forward_name = $this->ac->perform();
         $this->assertEqual($forward_name, '{$action_name}');
         */
 
         /**
-         *  TODO: ƥȥ򵭽ҤƲ
+         *  TODO: write test case! :)
          *  @see http://simpletest.org/en/first_test_tutorial.html
          *  @see http://simpletest.org/en/unit_test_documentation.html
          */
         $this->fail('No Test! write Test!');
     }
 }
+
 ?>
