@@ -4,17 +4,17 @@
  *
  *  @author     {$author}
  *  @package    {$project_id}
- *  @version    $Id: skel.app_manager.php 387 2006-11-06 14:31:24Z cocoitiban $
+ *  @version    $Id$
  */
 
 /**
- *  {$app_manager}Manager
+ *  {$app_manager}
  *
  *  @author     {$author}
  *  @access     public
  *  @package    {$project_id}
  */
-class {$app_manager}Manager extends Ethna_AppManager
+class {$app_manager} extends Ethna_AppManager
 {
 }
 ?>
