@@ -4,11 +4,11 @@
  *
  *  @author     {$author}
  *  @package    {$project_id}
- *  @version    $Id: skel.view_test.php 503 2008-04-25 04:06:08Z mumumu-org $
+ *  @version    $Id$
  */
 
 /**
- *  {$forward_name}ӥ塼μ
+ *  {$forward_name} view implementation.
  *
  *  @author     {$author}
  *  @access     public
@@ -18,48 +18,48 @@ class {$view_class}_TestCase extends Ethna_UnitTestCase
 {
     /**
      *  @access private
-     *  @var    string  ӥ塼̾
+     *  @var    string  view name.
      */
     var $forward_name = '{$forward_name}';
 
     /**
-     *    ƥȤν
+     * initialize test.
      *
-     *    @access public
+     * @access public
      */
     function setUp()
     {
-        $this->createPlainActionForm(); // եκ
-        $this->createViewClass();       // ӥ塼κ
+        $this->createPlainActionForm(); // create ActionForm
+        $this->createViewClass();       // create View.
     }
 
     /**
-     *    ƥȤθ
+     *  clean up testcase.
      *
-     *    @access public
+     *  @access public
      */
     function tearDown()
     {
     }
 
     /**
-     *  {$forward_name}Υץƥȥ
+     *  {$forward_name} preprocess sample testcase.
      *
      *  @access public
      */
     function test_viewSample()
     {
         /*
-        // ե
+        // setting form input. 
         $this->af->set('id', 1);
 
-        // {$forward_name}
+        // {$forward_name} preprocess.
         $this->vc->preforward();
         $this->assertNull($this->af->get('data'));
         */
 
         /**
-         *  TODO: ƥȥ򵭽ҤƲ
+         *  TODO: write test case! :)
          *  @see http://simpletest.org/en/first_test_tutorial.html
          *  @see http://simpletest.org/en/unit_test_documentation.html
          */
