@@ -6,10 +6,8 @@
  *  @author halt feits <halt.feits@gmail.com>
  */
 
-//error_reporting(E_ALL);
-
 /**
- *  Ethna_ViewClass饹Υƥȥ
+ *  Ethna_ViewClassクラスのテストケース
  *
  *  @package Ethna
  *  @author halt feits <halt.feits@gmail.com>
@@ -194,18 +192,18 @@ class Ethna_ViewClass_Test extends Ethna_UnitTestBase
             );
         $params = array();
 
-        // valueʤ
+        // valueなし
         $this->viewclass->af->setDef($name, $def);
         $result = $this->viewclass->getFormInput('btn', null, $params);
         $this->assertTrue(strpos($result, 'value') === false);
 
-        // defaultϻꤷƤ̵̣
+        // defaultは指定しても無意味
         $params['default'] = 'hoge';
         $this->viewclass->af->setDef($name, $def);
         $result = $this->viewclass->getFormInput('btn', null, $params);
         $this->assertTrue(strpos($result, 'value') === false);
 
-        // value
+        // valueを指定
         $params['value'] = 'fuga';
         $this->viewclass->af->setDef($name, $def);
         $result = $this->viewclass->getFormInput('btn', null, $params);
@@ -228,19 +226,19 @@ class Ethna_ViewClass_Test extends Ethna_UnitTestBase
 <label for="chkbx_2"><input type="checkbox" name="chkbx[]" value="2" id="chkbx_2" checked="checked" />2</label>
 EOS;
 
-        // def  default  int(2)  check
+        // def の default 指定で int(2) に check
         $this->viewclass->af->setDef($name, $def);
         $result = $this->viewclass->getFormInput('chkbx', null, $params);
         $this->assertEqual($result, $expected);
 
-        // params  default  int(2)  check
+        // params の default 指定で int(2) に check
         $def['default'] = 1;
-        $params['default'] = 2; // paramsͥ
+        $params['default'] = 2; // paramsが優先
         $this->viewclass->af->setDef($name, $def);
         $result = $this->viewclass->getFormInput('chkbx', null, $params);
         $this->assertEqual($result, $expected);
 
-        // params  default  string(1) "2"  check
+        // params の default 指定で string(1) "2" に check
         $params['default'] = '2';
         $this->viewclass->af->setDef($name, $def);
         $result = $this->viewclass->getFormInput('chkbx', null, $params);
@@ -253,26 +251,26 @@ EOS;
         $def = array();
         $params = array();
 
-        // defaultvalueʤȤ
+        // defaultもvalueもないとき
         $this->viewclass->af->setDef($name, $def);
         $result = $this->viewclass->getFormInput('testform', null, $params);
         $this->assertTrue(strpos($result, 'value=""'));
 
-        // defaultȤ
+        // defaultがあるとき
         $params['default'] = 'hoge';
         unset($params['value']);
         $this->viewclass->af->setDef($name, $def);
         $result = $this->viewclass->getFormInput('testform', null, $params);
         $this->assertTrue(strpos($result, 'value="hoge"'));
 
-        // valueȤ
+        // valueがあるとき
         unset($params['default']);
         $params['value'] = 'fuga';
         $this->viewclass->af->setDef($name, $def);
         $result = $this->viewclass->getFormInput('testform', null, $params);
         $this->assertTrue(strpos($result, 'value="fuga"'));
 
-        // default, valueξȤ: valueͥ
+        // default, value両方があるとき: valueが優先
         $params['default'] = 'hogefuga';
         $params['value'] = 'foobar';
         $this->viewclass->af->setDef($name, $def);
